(***********************************************************************

                    Mathematica-Compatible Notebook

This notebook can be used on any computer system with Mathematica 4.0,
MathReader 4.0, or any compatible application. The data for the notebook 
starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do one of 
the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing the 
word CacheID, otherwise Mathematica-compatible applications may try to 
use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
***********************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    303244,       8480]*)
(*NotebookOutlinePosition[    304321,       8515]*)
(*  CellTagsIndexPosition[    304277,       8511]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["superEDC Manual", "Title",
  Evaluatable->False,
  CellHorizontalScrolling->False,
  TextAlignment->Center],

Cell["version 1.5.0 - May 2013", "Text",
  TextAlignment->Center,
  TextJustification->0,
  FontFamily->"Times",
  FontSize->14,
  FontSlant->"Italic"],

Cell[TextData[{
  StyleBox["\n",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  ButtonBox["S. Bonanos",
    ButtonData:>{
      URL[ "http://www.inp.demokritos.gr/~sbonano/SB.html"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox["\n",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["\n",
    FontWeight->"Bold"],
  StyleBox[ButtonBox["Institute of Nuclear Physics",
    ButtonData:>{
      URL[ "http://www.inp.demokritos.gr/"], None},
    ButtonStyle->"Hyperlink"],
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[",  ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[ButtonBox["NCSR \"Demokritos\"",
    ButtonData:>{
      URL[ "http://www.demokritos.gr/index_muk.asp"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[", \nAghia Paraskevi 15310, Greece. ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["\n",
    FontSize->14,
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox["\n",
    FontWeight->"Bold"],
  "Please send comments, suggestions, bug reports to:  ",
  ButtonBox["sbonano@inp.demokritos.gr",
    ButtonData:>{
      URL[ "mailto:sbonano@inp.demokritos.gr"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[" \t",
    FontWeight->"Bold"]
}], "Text",
  TextAlignment->Center,
  TextJustification->0,
  FontFamily->"Times",
  FontSize->16]
}, Closed]],

Cell[TextData[{
  "\n\tThis manual describes the use of the new functions introduced in ",
  StyleBox["superEDC",
    FontWeight->"Bold"],
  ", which is a modification of the Exterior Differential Calculus (",
  ButtonBox["EDC",
    ButtonData:>{
      URL[ "http://www.inp.demokritos.gr/~sbonano/EDC/"], None},
    ButtonStyle->"Hyperlink"],
  StyleBox[") ",
    FontWeight->"Bold"],
  "package allowing the operations of exterior calculus to act on expressions \
containing anticommuting (Grassmann) variables. It is intended for Grassmann \
algebra and Superalgebra caculations. ",
  StyleBox["All functions defined in the ",
    FontSlant->"Italic"],
  StyleBox["matrixEDC",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" package, except ",
    FontSlant->"Italic"],
  StyleBox["interiorProduct",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[" and ",
    FontSlant->"Italic"],
  StyleBox["LieDcartan",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  StyleBox[", can still be used.",
    FontSlant->"Italic"],
  " For a description of those functions refer to the notebook ",
  StyleBox["EDCmanual.nb",
    FontWeight->"Bold"],
  " which can be downloaded ",
  ButtonBox["here",
    ButtonData:>{
      URL[ "http://www.inp.demokritos.gr/~sbonano/EDC/"], None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[TextData[{
  "\t",
  StyleBox["Installation",
    FontSlant->"Italic"],
  ": The file ",
  StyleBox["superEDC.m",
    FontWeight->"Bold"],
  " must be placed in one of the directories that ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " looks at when searching for extra packages (e.g., /Applications/",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  "/AddOns/AutoLoad). Such directories can be found by evaluating the command \
",
  StyleBox["$Path",
    FontWeight->"Bold"],
  ":"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    \($Path\)], "Input"],

Cell[TextData[{
  "The notebook ",
  StyleBox["superEDCpalette.nb",
    FontWeight->"Bold"],
  " is a palette for entering the new functions defined in ",
  StyleBox["superEDC",
    FontWeight->"Bold"],
  "."
}], "Text",
  FontSize->16],

Cell[TextData[{
  "\tThere are 6 sections in this manual: 3 in part I and 3 in part II. They \
contain definitions and examples of increasing complexity.  ",
  StyleBox["As some calculations depend on previously defined quantities, it \
is best if all cells in this notebook are evaluated in the order that they \
appear, after evaluating first the following command (",
    FontSlant->"Italic"],
  StyleBox["<<superEDC.m",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[").",
    FontSlant->"Italic"]
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    \(<< superEDC.m\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \($superEDCversion\)], "Input"],

Cell[BoxData[
    \(150\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["Part I: Grassmann Algebra", "Subtitle",
  Evaluatable->False,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[TextData[{
  "1. ",
  StyleBox["Notation and Basic operations:",
    FontSlant->"Italic"],
  " Wedge, d"
}], "Section",
  Evaluatable->False,
  FontSize->18],

Cell[TextData[{
  "\tJust as in ",
  ButtonBox["EDC",
    ButtonData:>{
      URL[ "http://www.inp.demokritos.gr/~sbonano/EDC/"], None},
    ButtonStyle->"Hyperlink"],
  ",  any symbols can be used to denote differential forms or matrices. \
However, in ",
  StyleBox["superEDC",
    FontWeight->"Bold"],
  ", a specific notation for Grassmann variables must be used: all Grassmann \
variables must have ",
  "Head",
  " \"gv\". For example, the following symbols denote Grassmann variables:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(GVnames = {gv[1], \ gv[a[1]], \ gv[b[1, 2]], \ 
        gv[{u[1]}, x, y, z]}\)], "Input"],

Cell[BoxData[
    \({gv[1], gv[a[1]], gv[b[1, 2]], gv[{u[1]}, x, y, z]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The last corresponds to the Grassmann field ",
  StyleBox["u[1][x,y,z]",
    FontFamily->"Courier"],
  " --  a function of the coordinates {x, y, z}. Notice that, in this case, \
the first argument of ",
  StyleBox["gv",
    FontFamily->"Courier"],
  "  ",
  StyleBox["must",
    FontSlant->"Italic"],
  " be a ",
  StyleBox["List",
    FontWeight->"Bold"],
  " (containing the name) to distinguish it from the coordinates. "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell["\<\
\tGrassmann products are antisymmetric and are computed using \
Wedge. Wedge orders products of Grassmann variables alphabetically:  \
\>", \
"Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \({gv[1]\[Wedge]gv[1], gv[2]\[Wedge]gv[1], \ 
      gv[b[2]]\[Wedge]gv[a[1]]\[Wedge]gv[b[1]]}\)], "Input"],

Cell[BoxData[
    \({0, \(-\((gv[1]\[Wedge]gv[2])\)\), 
      gv[a[1]]\[Wedge]gv[b[1]]\[Wedge]gv[b[2]]}\)], "Output"]
}, Open  ]],

Cell["\<\
Wedge is also used to multiply general expressions containing \
Grassmann variables:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[a[0] + a[1] gv[1]\[Wedge]gv[3] + a[2] gv[2]\[Wedge]gv[4], 
      b[0] + b[1] gv[1]\[Wedge]gv[3] + b[2] gv[2]\[Wedge]gv[4]]\)], "Input"],

Cell[BoxData[
    \(a[0]\ b[0] + a[1]\ b[0]\ gv[1]\[Wedge]gv[3] + 
      a[0]\ b[1]\ gv[1]\[Wedge]gv[3] + a[2]\ b[0]\ gv[2]\[Wedge]gv[4] + 
      a[0]\ b[2]\ gv[2]\[Wedge]gv[4] - 
      a[2]\ b[1]\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4] - 
      a[1]\ b[2]\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\)], "Output"]
}, Open  ]],

Cell["and reWrite combines terms with identical Wedge products:", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[%]\)], "Input"],

Cell[BoxData[
    \(a[0]\ b[
          0] + \((a[1]\ b[0] + a[0]\ b[1])\)\ gv[1]\[Wedge]gv[
            3] + \((a[2]\ b[0] + a[0]\ b[2])\)\ gv[2]\[Wedge]gv[
            4] + \((\(-a[2]\)\ b[1] - a[1]\ b[2])\)\ gv[1]\[Wedge]gv[
            2]\[Wedge]gv[3]\[Wedge]gv[4]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tAs in EDC, the exterior diffrential operator ",
  StyleBox["d",
    FontWeight->"Bold"],
  " treats all symbols as variables: "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(d[GVnames]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{\(d[gv[1]]\), ",", \(d[gv[a[1]]]\), ",", \(d[gv[b[1, 2]]]\), 
        ",", 
        RowBox[{
          RowBox[{\(d[x]\), "\[Wedge]", 
            RowBox[{
              SuperscriptBox["gv", 
                TagBox[\(({0}, 1, 0, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \({u[1]}, x, y, z\), "]"}]}], 
          "+", 
          RowBox[{\(d[y]\), "\[Wedge]", 
            RowBox[{
              SuperscriptBox["gv", 
                TagBox[\(({0}, 0, 1, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \({u[1]}, x, y, z\), "]"}]}], 
          "+", 
          RowBox[{\(d[z]\), "\[Wedge]", 
            RowBox[{
              SuperscriptBox["gv", 
                TagBox[\(({0}, 0, 0, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \({u[1]}, x, y, z\), 
              "]"}]}]}]}], "}"}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "giving Grassmann-valued differential forms. Wedge treats these correctly \
as Grassmann 1-forms (",
  StyleBox["d[gv[1]]",
    FontFamily->"Courier"],
  ") and new Grassmann variables (",
  Cell[BoxData[
      RowBox[{
        SuperscriptBox["gv", 
          TagBox[\(({0}, 1, 0, 0)\),
            Derivative],
          MultilineFunction->None], "[", \({u[1]}, x, y, z\), "]"}]]],
  "), even though they don't have Head=gv:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[d[gv[b[1, 2]]], d[gv[1]]]\)], "Input"],

Cell[BoxData[
    \(d[gv[1]]\[Wedge]d[gv[b[1, 2]]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"Wedge", "[", 
      RowBox[{
        RowBox[{
          SuperscriptBox["gv", 
            TagBox[\(({0}, 1, 0, 0)\),
              Derivative],
            MultilineFunction->None], "[", \({u[1]}, x, y, z\), "]"}], 
        ",", \(gv[1]\)}], "]"}]], "Input"],

Cell[BoxData[
    RowBox[{"-", 
      RowBox[{"(", 
        RowBox[{\(gv[1]\), "\[Wedge]", 
          RowBox[{
            SuperscriptBox["gv", 
              TagBox[\(({0}, 1, 0, 0)\),
                Derivative],
              MultilineFunction->None], "[", \({u[1]}, x, y, z\), "]"}]}], 
        ")"}]}]], "Output"]
}, Open  ]],

Cell["\<\
One can define symbolic Grassmann p-forms by assigning their \
differential-form degree using the EDC function FormDegree:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    \(FormDegree[gv[A[_]]] = 1; \nFormDegree[gv[B[_]]] = 2; \)], "Input"],

Cell["\<\
Now the symbols gv[A[1]], gv[A[2]] behave as Grassmann 1-forms and \
gv[B[_]] as Grassmann 2-forms: \
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[gv[A[2]], gv[A[1]]]\)], "Input"],

Cell[BoxData[
    \(gv[A[1]]\[Wedge]gv[A[2]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[d[gv[A[1]]], gv[A[1]]]\)], "Input"],

Cell[BoxData[
    \(\(-\((gv[A[1]]\[Wedge]d[gv[A[1]]])\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[gv[B[1]], gv[B[1]]]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[gv[B[1]], gv[A[1]]]\)], "Input"],

Cell[BoxData[
    \(\(-\((gv[A[1]]\[Wedge]gv[B[1]])\)\)\)], "Output"]
}, Open  ]],

Cell["\<\
Wedge applies the following rule for commuting two quantities: 
Wedge[B, A]=(-1)^(FD[A]*FD[B]+GP[A]*GP[B])Wedge[A, B],
where FD[A] is the diffrential-form degreeof A and GP[A] is the Grassmann \
parity of A.\
\>", "Text",
  Evaluatable->False,
  FontSize->16]
}, Closed]],

Cell["", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[{
  "2. ",
  StyleBox["Definitions and Auxiliary Functions:",
    FontSlant->"Italic"],
  " Even and Odd Expressions, body / soul, EvenGrassQ, GrassParity"
}], "Section",
  Evaluatable->False,
  FontSize->18],

Cell["\<\
\tLet us define a general expression containing Grassmann variables\
\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(GVexpr = 
      a[0] + a[1]\ gv[1] + a[2]\ gv[2] + a[3]\ gv[3] + 
        b[1, 2]\ gv[1]\[Wedge]gv[2] + b[1, 3]\ gv[1]\[Wedge]gv[3] + 
        b[2, 3]\ gv[2]\[Wedge]gv[3] + 
        c[3]\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\)], "Input"],

Cell[BoxData[
    \(a[0] + a[1]\ gv[1] + a[2]\ gv[2] + a[3]\ gv[3] + 
      b[1, 2]\ gv[1]\[Wedge]gv[2] + b[1, 3]\ gv[1]\[Wedge]gv[3] + 
      b[2, 3]\ gv[2]\[Wedge]gv[3] + 
      c[3]\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The two functions ",
  StyleBox["body",
    FontWeight->"Bold"],
  "[x_] and ",
  StyleBox["soul",
    FontWeight->"Bold"],
  "[x_] give the part of x_ that is independent of / dependent on gv[_] \
terms:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(body[GVexpr]\)], "Input"],

Cell[BoxData[
    \(a[0]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(soul[GVexpr]\)], "Input"],

Cell[BoxData[
    \(a[1]\ gv[1] + a[2]\ gv[2] + a[3]\ gv[3] + b[1, 2]\ gv[1]\[Wedge]gv[2] + 
      b[1, 3]\ gv[1]\[Wedge]gv[3] + b[2, 3]\ gv[2]\[Wedge]gv[3] + 
      c[3]\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The Grassmann parity of an expression is 0 (1) if it contains only even \
(odd) products of Grassmann variables. Otherwise it has mixed parity. \
Expressions having terms of the same parity will be called ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  ". The two functions EvenGrassQ[x_] and GrassParity[x_] give True/False and \
0/1 on homogeneous even/odd expressions, or print \"mixed parity\" warnings:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[GVexpr]\)], "Input"],

Cell[BoxData[
    \("Mixed parity entries."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrassParity[GVexpr]\)], "Input"],

Cell[BoxData[
    \("Mixed parity entries."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[body[GVexpr]]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(evenGVexpr = Plus @@ Select[List @@ GVexpr, EvenGrassQ]\)], "Input"],

Cell[BoxData[
    \(a[0] + b[1, 2]\ gv[1]\[Wedge]gv[2] + b[1, 3]\ gv[1]\[Wedge]gv[3] + 
      b[2, 3]\ gv[2]\[Wedge]gv[3]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(oddGVexpr = 
      Plus @@ Select[List @@ GVexpr, EvenGrassQ[#] === False &]\)], "Input"],

Cell[BoxData[
    \(a[1]\ gv[1] + a[2]\ gv[2] + a[3]\ gv[3] + 
      c[3]\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[evenGVexpr]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[oddGVexpr]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrassParity[evenGVexpr]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrassParity[oddGVexpr]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "There is no separate test for odd Grassmann expressions: if ",
  StyleBox["EvenGrassQ[x]",
    FontFamily->"Courier"],
  " returns ",
  StyleBox["False",
    FontFamily->"Courier"],
  ", then ",
  StyleBox["x",
    FontFamily->"Courier"],
  " is odd. The Grassmann parity of 0 is not defined:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[0]\)], "Input"],

Cell[BoxData[
    \("Test fails on zero arguments."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrassParity[0]\)], "Input"],

Cell[BoxData[
    \("Test fails on zero arguments."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note:",
    FontSlant->"Italic"],
  " Even though the basic functions defined in superEDC (Wedge, d, \
wedgePower, wedgeD) work on any expressions containing Grassmann variables, \
those acting on matrices (wedgeDet, wedgeInverse and all super-Functions) are \
meaningful only on ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " matrices. An ",
  StyleBox["ordinary",
    FontSlant->"Italic"],
  " matrix is homogeneous if all its elements are either even or odd (apart \
from 0 elements). For the definition of a homogeneous supermatrix see section \
4 below. "
}], "Text",
  Evaluatable->False,
  FontSize->16]
}, Closed]],

Cell[TextData[StyleBox["",
  FontSlant->"Italic"]], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[{
  "3. ",
  StyleBox["wedgeFunctions:",
    FontSlant->"Italic"],
  " Wedge, wedgePower, wedgeInverse, wedgeDet, wedgeAdjoint, wedgeD, \
wedgeMatrixExp"
}], "Section",
  Evaluatable->False,
  FontSize->18],

Cell[TextData[{
  "\tAll ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " functions that involve multiplications (Times, Dot, Power, Det, Inverse, \
D, ...) must be redefined to take into account the presence of Grassmann \
variables. In addition to ",
  StyleBox["Wedge",
    FontFamily->"Courier"],
  ", which has been redefined to treat expressions containing Grassmann \
variables correctly and generalizes both Times and Dot, ",
  StyleBox["superEDC",
    FontWeight->"Bold"],
  " introduces the new functions ",
  StyleBox["wedgePower",
    FontFamily->"Courier"],
  ", ",
  StyleBox["wedgeDet",
    FontFamily->"Courier"],
  ", ",
  StyleBox["wedgeInverse",
    FontFamily->"Courier"],
  ", ",
  StyleBox["wedgeD",
    FontFamily->"Courier"],
  " and ",
  StyleBox["wedgeMatrixExp",
    FontFamily->"Courier"],
  " which generalize Power, Det, Inverse, D and MatrixExp, allowing them to \
act on expressions containing Grassmann variables. This section describes the \
syntax and use of these new functions."
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[TextData[{
  StyleBox["Important note:",
    FontSlant->"Italic"],
  " Matrices must be given as nested lists, i.e., without using \
\"MatrixForm\" on them. "
}], "Text",
  Evaluatable->False,
  FontSize->16,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell["Wedge", "Subsection",
  FontSize->16],

Cell["\<\
\tLet us define an even 3x3 matrix and an odd vector depending on \
Grassmann variables:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mat = 
      Array[mm, {3, 3}] + 
        Array[nn[#1, #2] gv[u[#1]]\[Wedge]gv[u[#2]] &, {3, 3}]\)], "Input"],

Cell[BoxData[
    \({{mm[1, 1], mm[1, 2] + nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]], 
        mm[1, 3] + nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]]}, {mm[2, 1] - 
          nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]], mm[2, 2], 
        mm[2, 3] + nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]]}, {mm[3, 1] - 
          nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]], 
        mm[3, 2] - nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]], mm[3, 3]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[Mat]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Vec = \(gv[p[#]] &\) /@ {1, 2, 3}\)], "Input"],

Cell[BoxData[
    \({gv[p[1]], gv[p[2]], gv[p[3]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GrassParity[Vec]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RotateLeft[Vec]\)], "Input"],

Cell[BoxData[
    \({gv[p[2]], gv[p[3]], gv[p[1]]}\)], "Output"]
}, Open  ]],

Cell["\tWedge on Lists acts like Dot (inner product):", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[Vec, %]\)], "Input"],

Cell[BoxData[
    \(gv[p[1]]\[Wedge]gv[p[2]] - gv[p[1]]\[Wedge]gv[p[3]] + 
      gv[p[2]]\[Wedge]gv[p[3]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[Mat, Vec]\)], "Input"],

Cell[BoxData[
    \({gv[p[1]]\ mm[1, 1] + gv[p[2]]\ mm[1, 2] + gv[p[3]]\ mm[1, 3] + 
        nn[1, 2]\ gv[p[2]]\[Wedge]gv[u[1]]\[Wedge]gv[u[2]] + 
        nn[1, 3]\ gv[p[3]]\[Wedge]gv[u[1]]\[Wedge]gv[u[3]], 
      gv[p[1]]\ mm[2, 1] + gv[p[2]]\ mm[2, 2] + gv[p[3]]\ mm[2, 3] - 
        nn[2, 1]\ gv[p[1]]\[Wedge]gv[u[1]]\[Wedge]gv[u[2]] + 
        nn[2, 3]\ gv[p[3]]\[Wedge]gv[u[2]]\[Wedge]gv[u[3]], 
      gv[p[1]]\ mm[3, 1] + gv[p[2]]\ mm[3, 2] + gv[p[3]]\ mm[3, 3] - 
        nn[3, 1]\ gv[p[1]]\[Wedge]gv[u[1]]\[Wedge]gv[u[3]] - 
        nn[3, 2]\ gv[p[2]]\[Wedge]gv[u[2]]\[Wedge]gv[u[3]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[%, Vec]\)], "Input"],

Cell[BoxData[
    \(\(-mm[1, 2]\)\ gv[p[1]]\[Wedge]gv[p[2]] + 
      mm[2, 1]\ gv[p[1]]\[Wedge]gv[p[2]] - 
      mm[1, 3]\ gv[p[1]]\[Wedge]gv[p[3]] + 
      mm[3, 1]\ gv[p[1]]\[Wedge]gv[p[3]] - 
      mm[2, 3]\ gv[p[2]]\[Wedge]gv[p[3]] + 
      mm[3, 2]\ gv[p[2]]\[Wedge]gv[p[3]] - 
      nn[1, 2]\ gv[p[1]]\[Wedge]gv[p[2]]\[Wedge]gv[u[1]]\[Wedge]gv[u[2]] - 
      nn[2, 1]\ gv[p[1]]\[Wedge]gv[p[2]]\[Wedge]gv[u[1]]\[Wedge]gv[u[2]] - 
      nn[1, 3]\ gv[p[1]]\[Wedge]gv[p[3]]\[Wedge]gv[u[1]]\[Wedge]gv[u[3]] - 
      nn[3, 1]\ gv[p[1]]\[Wedge]gv[p[3]]\[Wedge]gv[u[1]]\[Wedge]gv[u[3]] - 
      nn[2, 3]\ gv[p[2]]\[Wedge]gv[p[3]]\[Wedge]gv[u[2]]\[Wedge]gv[u[3]] - 
      nn[3, 2]\ gv[p[2]]\[Wedge]gv[p[3]]\[Wedge]gv[u[2]]\[Wedge]gv[
            u[3]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[Mat, Mat]\)], "Input"],

Cell[BoxData[
    \({{mm[1, 1]\^2 + mm[1, 2]\ mm[2, 1] + mm[1, 3]\ mm[3, 1] + 
          mm[2, 1]\ nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]] - 
          mm[1, 2]\ nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]] + 
          mm[3, 1]\ nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]] - 
          mm[1, 3]\ nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]], 
        mm[1, 1]\ mm[1, 2] + mm[1, 2]\ mm[2, 2] + mm[1, 3]\ mm[3, 2] + 
          mm[1, 1]\ nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]] + 
          mm[2, 2]\ nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]] + 
          mm[3, 2]\ nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]] - 
          mm[1, 3]\ nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]], 
        mm[1, 1]\ mm[1, 3] + mm[1, 2]\ mm[2, 3] + mm[1, 3]\ mm[3, 3] + 
          mm[2, 3]\ nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]] + 
          mm[1, 1]\ nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]] + 
          mm[3, 3]\ nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]] + 
          mm[1, 2]\ nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]]}, {mm[1, 1]\ mm[2, 
              1] + mm[2, 1]\ mm[2, 2] + mm[2, 3]\ mm[3, 1] - 
          mm[1, 1]\ nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]] - 
          mm[2, 2]\ nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]] - 
          mm[2, 3]\ nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]] + 
          mm[3, 1]\ nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]], 
        mm[1, 2]\ mm[2, 1] + mm[2, 2]\^2 + mm[2, 3]\ mm[3, 2] + 
          mm[2, 1]\ nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]] - 
          mm[1, 2]\ nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]] + 
          mm[3, 2]\ nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]] - 
          mm[2, 3]\ nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]], 
        mm[1, 3]\ mm[2, 1] + mm[2, 2]\ mm[2, 3] + mm[2, 3]\ mm[3, 3] - 
          mm[1, 3]\ nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]] + 
          mm[2, 1]\ nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]] + 
          mm[2, 2]\ nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]] + 
          mm[3, 3]\ nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]]}, {mm[1, 1]\ mm[3, 
              1] + mm[2, 1]\ mm[3, 2] + mm[3, 1]\ mm[3, 3] - 
          mm[3, 2]\ nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]] - 
          mm[1, 1]\ nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]] - 
          mm[3, 3]\ nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]] - 
          mm[2, 1]\ nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]], 
        mm[1, 2]\ mm[3, 1] + mm[2, 2]\ mm[3, 2] + mm[3, 2]\ mm[3, 3] + 
          mm[3, 1]\ nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]] - 
          mm[1, 2]\ nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]] - 
          mm[2, 2]\ nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]] - 
          mm[3, 3]\ nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]], 
        mm[1, 3]\ mm[3, 1] + mm[2, 3]\ mm[3, 2] + mm[3, 3]\^2 + 
          mm[3, 1]\ nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]] - 
          mm[1, 3]\ nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]] + 
          mm[3, 2]\ nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]] - 
          mm[2, 3]\ nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]]}}\)], "Output"]
}, Open  ]],

Cell["\<\
\tWedge between a List and a scalar multiplies with Wedge or Times \
as appropriate:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[Vec, mm[1, 1]]\)], "Input"],

Cell[BoxData[
    \({gv[p[1]]\ mm[1, 1], gv[p[2]]\ mm[1, 1], 
      gv[p[3]]\ mm[1, 1]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[Vec, gv[p[1]]]\)], "Input"],

Cell[BoxData[
    \({0, \(-\((gv[p[1]]\[Wedge]gv[p[2]])\)\), \(-\((gv[p[1]]\[Wedge]gv[
              p[3]])\)\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[Mat, mm[1, 1]]\)], "Input"],

Cell[BoxData[
    \({{mm[1, 1]\^2, 
        mm[1, 1]\ \((mm[1, 2] + nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]])\), 
        mm[1, 1]\ \((mm[1, 3] + nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]])\)}, {mm[
            1, 1]\ \((mm[2, 1] - nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]])\), 
        mm[1, 1]\ mm[2, 2], 
        mm[1, 1]\ \((mm[2, 3] + nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]])\)}, {mm[
            1, 1]\ \((mm[3, 1] - nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]])\), 
        mm[1, 1]\ \((mm[3, 2] - nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]])\), 
        mm[1, 1]\ mm[3, 3]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[Mat, gv[p[1]]]\)], "Input"],

Cell[BoxData[
    \({{gv[p[1]]\ mm[1, 1], 
        gv[p[1]]\ mm[1, 2] + 
          nn[1, 2]\ gv[p[1]]\[Wedge]gv[u[1]]\[Wedge]gv[u[2]], 
        gv[p[1]]\ mm[1, 3] + 
          nn[1, 3]\ gv[p[1]]\[Wedge]gv[u[1]]\[Wedge]gv[u[3]]}, {gv[p[1]]\ mm[
              2, 1] - nn[2, 1]\ gv[p[1]]\[Wedge]gv[u[1]]\[Wedge]gv[u[2]], 
        gv[p[1]]\ mm[2, 2], 
        gv[p[1]]\ mm[2, 3] + 
          nn[2, 3]\ gv[p[1]]\[Wedge]gv[u[2]]\[Wedge]gv[u[3]]}, {gv[p[1]]\ mm[
              3, 1] - nn[3, 1]\ gv[p[1]]\[Wedge]gv[u[1]]\[Wedge]gv[u[3]], 
        gv[p[1]]\ mm[3, 2] - 
          nn[3, 2]\ gv[p[1]]\[Wedge]gv[u[2]]\[Wedge]gv[u[3]], 
        gv[p[1]]\ mm[3, 3]}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["wedgePower", "Subsection",
  FontSize->16],

Cell[TextData[{
  "\tThe function ",
  StyleBox["wedgePower[x_, n_]",
    FontFamily->"Courier"],
  " gives the ",
  StyleBox["n",
    FontFamily->"Courier"],
  "th power of the expression ",
  StyleBox["x",
    FontFamily->"Courier"],
  ", where  ",
  StyleBox["x",
    FontFamily->"Courier"],
  " can be either a scalar or a (square) matrix. When ",
  StyleBox["x",
    FontFamily->"Courier"],
  " is a matrix, ",
  StyleBox["n",
    FontFamily->"Courier"],
  " must be a non-negative integer; otherwise it can be any rational number. \
Thus ",
  StyleBox["wedgePower",
    FontFamily->"Courier"],
  " generalizes both ",
  StyleBox["Power",
    FontFamily->"Courier"],
  " and ",
  StyleBox["MatrixPower",
    FontFamily->"Courier"],
  ":"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgePower[
      1 + a\ gv[1]\[Wedge]gv[4] + b\ gv[2]\[Wedge]gv[5] + 
        c\ gv[3]\[Wedge]gv[6], 3]\)], "Input"],

Cell[BoxData[
    \(1 + 3\ a\ gv[1]\[Wedge]gv[4] + 3\ b\ gv[2]\[Wedge]gv[5] + 
      3\ c\ gv[3]\[Wedge]gv[6] - 
      6\ a\ b\ gv[1]\[Wedge]gv[2]\[Wedge]gv[4]\[Wedge]gv[5] - 
      6\ a\ c\ gv[1]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]gv[6] - 
      6\ b\ c\ gv[2]\[Wedge]gv[3]\[Wedge]gv[5]\[Wedge]gv[6] - 
      6\ a\ b\ c\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]gv[
            5]\[Wedge]gv[6]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgePower[Mat, 2]\)], "Input"],

Cell[BoxData[
    \({{mm[1, 1]\^2 + mm[1, 2]\ mm[2, 1] + 
          mm[1, 3]\ mm[3, 
              1] + \((mm[2, 1]\ nn[1, 2] - mm[1, 2]\ nn[2, 1])\)\ gv[
                u[1]]\[Wedge]gv[u[2]] + \((mm[3, 1]\ nn[1, 3] - 
                mm[1, 3]\ nn[3, 1])\)\ gv[u[1]]\[Wedge]gv[u[3]], 
        mm[1, 1]\ mm[1, 2] + mm[1, 2]\ mm[2, 2] + 
          mm[1, 3]\ mm[3, 2] + \((mm[1, 1] + mm[2, 2])\)\ nn[1, 
              2]\ gv[u[1]]\[Wedge]gv[u[2]] + 
          mm[3, 2]\ nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]] - 
          mm[1, 3]\ nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]], 
        mm[1, 1]\ mm[1, 3] + mm[1, 2]\ mm[2, 3] + mm[1, 3]\ mm[3, 3] + 
          mm[2, 3]\ nn[1, 
              2]\ gv[u[1]]\[Wedge]gv[u[2]] + \((mm[1, 1] + mm[3, 3])\)\ nn[1, 
              3]\ gv[u[1]]\[Wedge]gv[u[3]] + 
          mm[1, 2]\ nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]]}, {mm[1, 1]\ mm[2, 
              1] + mm[2, 1]\ mm[2, 2] + 
          mm[2, 3]\ mm[3, 1] - \((mm[1, 1] + mm[2, 2])\)\ nn[2, 
              1]\ gv[u[1]]\[Wedge]gv[u[2]] - 
          mm[2, 3]\ nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]] + 
          mm[3, 1]\ nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]], 
        mm[1, 2]\ mm[2, 1] + mm[2, 2]\^2 + 
          mm[2, 3]\ mm[3, 
              2] + \((mm[2, 1]\ nn[1, 2] - mm[1, 2]\ nn[2, 1])\)\ gv[
                u[1]]\[Wedge]gv[u[2]] + \((mm[3, 2]\ nn[2, 3] - 
                mm[2, 3]\ nn[3, 2])\)\ gv[u[2]]\[Wedge]gv[u[3]], 
        mm[1, 3]\ mm[2, 1] + mm[2, 2]\ mm[2, 3] + mm[2, 3]\ mm[3, 3] - 
          mm[1, 3]\ nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]] + 
          mm[2, 1]\ nn[1, 
              3]\ gv[u[1]]\[Wedge]gv[u[3]] + \((mm[2, 2] + mm[3, 3])\)\ nn[2, 
              3]\ gv[u[2]]\[Wedge]gv[u[3]]}, {mm[1, 1]\ mm[3, 1] + 
          mm[2, 1]\ mm[3, 2] + mm[3, 1]\ mm[3, 3] - 
          mm[3, 2]\ nn[2, 
              1]\ gv[u[1]]\[Wedge]gv[u[2]] - \((mm[1, 1] + mm[3, 3])\)\ nn[3, 
              1]\ gv[u[1]]\[Wedge]gv[u[3]] - 
          mm[2, 1]\ nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]], 
        mm[1, 2]\ mm[3, 1] + mm[2, 2]\ mm[3, 2] + mm[3, 2]\ mm[3, 3] + 
          mm[3, 1]\ nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]] - 
          mm[1, 2]\ nn[3, 
              1]\ gv[u[1]]\[Wedge]gv[u[3]] - \((mm[2, 2] + mm[3, 3])\)\ nn[3, 
              2]\ gv[u[2]]\[Wedge]gv[u[3]], 
        mm[1, 3]\ mm[3, 1] + mm[2, 3]\ mm[3, 2] + 
          mm[3, 3]\^2 + \((mm[3, 1]\ nn[1, 3] - mm[1, 3]\ nn[3, 1])\)\ gv[
                u[1]]\[Wedge]gv[u[3]] + \((mm[3, 2]\ nn[2, 3] - 
                mm[2, 3]\ nn[3, 2])\)\ gv[u[2]]\[Wedge]gv[u[3]]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgePower[Mat, 0]\)], "Input"],

Cell[BoxData[
    \({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}\)], "Output"]
}, Open  ]],

Cell["\<\
\tNegative or fractional powers are defined for scalars but not for \
matrices:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgePower[
      C0 + a\ gv[1]\[Wedge]gv[4] + b\ gv[2]\[Wedge]gv[5] + 
        c\ gv[3]\[Wedge]gv[6], \(-2\)/5]\)], "Input"],

Cell[BoxData[
    \(1\/C0\^\(2/5\) - \(2\ a\ gv[1]\[Wedge]gv[4]\)\/\(5\ C0\^\(7/5\)\) - \(2\
\ b\ gv[2]\[Wedge]gv[5]\)\/\(5\ C0\^\(7/5\)\) - \(2\ c\ \
gv[3]\[Wedge]gv[6]\)\/\(5\ C0\^\(7/5\)\) - \(14\ a\ b\ gv[1]\[Wedge]gv[2]\
\[Wedge]gv[4]\[Wedge]gv[5]\)\/\(25\ C0\^\(12/5\)\) - \(14\ a\ c\ \
gv[1]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]gv[6]\)\/\(25\ C0\^\(12/5\)\) - \(14\ \
b\ c\ gv[2]\[Wedge]gv[3]\[Wedge]gv[5]\[Wedge]gv[6]\)\/\(25\ C0\^\(12/5\)\) + \
\(168\ a\ b\ c\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]gv[5]\
\[Wedge]gv[6]\)\/\(125\ C0\^\(17/5\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgePower[
      C0 + a\ gv[1]\[Wedge]gv[4] + b\ gv[2]\[Wedge]gv[5] + 
        c\ gv[3]\[Wedge]gv[6], 2/5]\)], "Input"],

Cell[BoxData[
    \(C0\^\(2/5\) + \(2\ a\ gv[1]\[Wedge]gv[4]\)\/\(5\ C0\^\(3/5\)\) + \(2\ b\
\ gv[2]\[Wedge]gv[5]\)\/\(5\ C0\^\(3/5\)\) + \(2\ c\ \
gv[3]\[Wedge]gv[6]\)\/\(5\ C0\^\(3/5\)\) + \(6\ a\ b\ gv[1]\[Wedge]gv[2]\
\[Wedge]gv[4]\[Wedge]gv[5]\)\/\(25\ C0\^\(8/5\)\) + \(6\ a\ c\ \
gv[1]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]gv[6]\)\/\(25\ C0\^\(8/5\)\) + \(6\ b\ \
c\ gv[2]\[Wedge]gv[3]\[Wedge]gv[5]\[Wedge]gv[6]\)\/\(25\ C0\^\(8/5\)\) - \(48\
\ a\ b\ c\ \
gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]gv[5]\[Wedge]gv[6]\)\/\(\
125\ C0\^\(13/5\)\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[%%, %]\)], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgePower[Mat, \(-1\)]\)], "Input"],

Cell[BoxData[
    \(wedgePower[{{mm[1, 1], mm[1, 2] + nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]], 
          mm[1, 3] + nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]]}, {mm[2, 1] - 
            nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]], mm[2, 2], 
          mm[2, 3] + nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]]}, {mm[3, 1] - 
            nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]], 
          mm[3, 2] - nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]], 
          mm[3, 3]}}, \(-1\)]\)], "Output"]
}, Open  ]],

Cell["\<\
Negative inregral powers of invertible matrices can, of course, be \
computed by first inverting them using wedgeInverse.\
\>", "Text",
  Evaluatable->False,
  FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell["wedgeInverse", "Subsection",
  FontSize->16],

Cell[TextData[{
  "\tThe function ",
  StyleBox["wedgeInverse[x_]",
    FontFamily->"Courier"],
  " gives the Inverse of the ",
  StyleBox["ordinary",
    FontSlant->"Italic"],
  " (square) matrix ",
  StyleBox["x",
    FontFamily->"Courier"],
  ", if it exists. (For supermatrices ",
  StyleBox["superInverse",
    FontFamily->"Courier"],
  " must be used -- see section 5 below). It generalizes ",
  StyleBox["Inverse:",
    FontFamily->"Courier"]
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mat0 = Mat /. mm[i_, j_] \[RuleDelayed] 0 /; i =!= j\)], "Input"],

Cell[BoxData[
    \({{mm[1, 1], nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]], 
        nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]]}, {\(-nn[2, 1]\)\ gv[
              u[1]]\[Wedge]gv[u[2]], mm[2, 2], 
        nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]]}, {\(-nn[3, 1]\)\ gv[
              u[1]]\[Wedge]gv[u[3]], \(-nn[3, 2]\)\ gv[u[2]]\[Wedge]gv[u[3]], 
        mm[3, 3]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeInverse[Mat0]\)], "Input"],

Cell[BoxData[
    \({{1\/mm[1, 1], \(-\(\(nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]]\)\/\(mm[1, 
                  1]\ mm[2, 2]\)\)\), \(-\(\(nn[1, 
                  3]\ gv[u[1]]\[Wedge]gv[u[3]]\)\/\(mm[1, 1]\ mm[3, 
                  3]\)\)\)}, {\(nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]]\)\/\(mm[1, \
1]\ mm[2, 2]\), 
        1\/mm[2, 2], \(-\(\(nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]]\)\/\(mm[2, 
                  2]\ mm[3, 
                  3]\)\)\)}, {\(nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]]\)\/\(mm[1, \
1]\ mm[3, 3]\), \(nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]]\)\/\(mm[2, 2]\ mm[3, \
3]\), 1\/mm[3, 3]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[Wedge[%, Mat0]]\)], "Input"],

Cell[BoxData[
    \({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(%% /. gv[__] \[Rule] 0\)], "Input"],

Cell[BoxData[
    \({{1\/mm[1, 1], 0, 0}, {0, 1\/mm[2, 2], 0}, {0, 0, 
        1\/mm[3, 3]}}\)], "Output"]
}, Open  ]],

Cell["\tOnly even matrices with non-zero body are invertible:", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[Mat\[Wedge]gv[u[3]]]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeInverse[Mat\[Wedge]gv[u[3]]]\)], "Input"],

Cell[BoxData[
    \("Not invertible"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeInverse[soul[Mat]]\)], "Input"],

Cell[BoxData[
    \("Not invertible"\)], "Print"]
}, Open  ]],

Cell["", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[TextData[{
  "\tThe operator ",
  StyleBox["d",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  has been redefined to act correctly on expressions containing Grassmann \
variables or fields. As in EDC, it treats all symbols as variables. The \
following lines verify that the matrix ",
  Cell[BoxData[
      \(GG = Mat1\^\(-1\)\[Wedge]d[Mat1]\)]],
  " satisfies ",
  Cell[BoxData[
      \(d[GG] + GG\[Wedge]GG = 0\)]],
  ", where Mat1 is Mat0 with one Grassmann field."
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mat1 = Mat0 /. gv[u[3]] \[Rule] gv[{u[3]}, x, y, z]\)], "Input"],

Cell[BoxData[
    \({{mm[1, 1], nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]], 
        nn[1, 3]\ gv[u[1]]\[Wedge]gv[{u[3]}, x, y, z]}, {\(-nn[2, 1]\)\ gv[
              u[1]]\[Wedge]gv[u[2]], mm[2, 2], 
        nn[2, 3]\ gv[u[2]]\[Wedge]gv[{u[3]}, x, y, z]}, {\(-nn[3, 1]\)\ gv[
              u[1]]\[Wedge]gv[{u[3]}, x, y, z], \(-nn[3, 2]\)\ gv[
              u[2]]\[Wedge]gv[{u[3]}, x, y, z], mm[3, 3]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(GG = reWrite[wedgeInverse[Mat1]\[Wedge]d[Mat1]]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{\(d[mm[1, 1]]\/mm[1, 1]\), ",", 
            
            RowBox[{\(\(nn[1, 2]\ gv[u[1]]\[Wedge]d[gv[u[2]]]\)\/mm[1, 1]\), 
              "-", \(\(nn[1, 2]\ gv[u[2]]\[Wedge]d[gv[u[1]]]\)\/mm[1, 1]\), 
              "-", \(\(nn[1, 
                      2]\ d[mm[2, 2]]\[Wedge]gv[u[1]]\[Wedge]gv[u[2]]\)\/\(mm[
                      1, 1]\ mm[2, 2]\)\), 
              "+", \(\(d[nn[1, 2]]\[Wedge]gv[u[1]]\[Wedge]gv[u[2]]\)\/mm[1, 
                    1]\), "-", 
              FractionBox[
                RowBox[{\(nn[1, 3]\), " ", \(nn[3, 2]\), " ", 
                  
                  RowBox[{\(d[x]\), "\[Wedge]", \(gv[u[1]]\), 
                    "\[Wedge]", \(gv[u[2]]\), 
                    "\[Wedge]", \(gv[{u[3]}, x, y, z]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 1, 0, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[1, 1]\ mm[3, 3]\)], "-", 
              FractionBox[
                RowBox[{\(nn[1, 3]\), " ", \(nn[3, 2]\), " ", 
                  
                  RowBox[{\(d[y]\), "\[Wedge]", \(gv[u[1]]\), 
                    "\[Wedge]", \(gv[u[2]]\), 
                    "\[Wedge]", \(gv[{u[3]}, x, y, z]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 1, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[1, 1]\ mm[3, 3]\)], "-", 
              FractionBox[
                RowBox[{\(nn[1, 3]\), " ", \(nn[3, 2]\), " ", 
                  
                  RowBox[{\(d[z]\), "\[Wedge]", \(gv[u[1]]\), 
                    "\[Wedge]", \(gv[u[2]]\), 
                    "\[Wedge]", \(gv[{u[3]}, x, y, z]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 0, 1)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[1, 1]\ mm[3, 3]\)]}], ",", 
            
            RowBox[{\(-\(\(nn[1, 
                        3]\ gv[{u[3]}, x, y, z]\[Wedge]d[gv[u[1]]]\)\/mm[1, 
                      1]\)\), "+", 
              FractionBox[
                RowBox[{\(nn[1, 3]\), " ", 
                  RowBox[{\(d[x]\), "\[Wedge]", \(gv[u[1]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 1, 0, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[1, 1]\)], "+", 
              FractionBox[
                RowBox[{\(nn[1, 3]\), " ", 
                  RowBox[{\(d[y]\), "\[Wedge]", \(gv[u[1]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 1, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[1, 1]\)], "+", 
              FractionBox[
                RowBox[{\(nn[1, 3]\), " ", 
                  RowBox[{\(d[z]\), "\[Wedge]", \(gv[u[1]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 0, 1)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[1, 1]\)], 
              "-", \(\(nn[1, 
                      3]\ d[mm[3, 3]]\[Wedge]gv[u[1]]\[Wedge]gv[{u[3]}, x, y, 
                        z]\)\/\(mm[1, 1]\ mm[3, 3]\)\), 
              "+", \(\(d[nn[1, 3]]\[Wedge]gv[u[1]]\[Wedge]gv[{u[3]}, x, y, 
                      z]\)\/mm[1, 1]\), 
              "+", \(\(nn[1, 2]\ nn[2, 
                      3]\ gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[{u[3]}, x, y, 
                        z]\[Wedge]d[gv[u[2]]]\)\/\(mm[1, 1]\ mm[2, 2]\)\)}]}],
           "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            
            RowBox[{\(-\(\(nn[2, 1]\ gv[u[1]]\[Wedge]d[gv[u[2]]]\)\/mm[2, 
                      2]\)\), 
              "+", \(\(nn[2, 1]\ gv[u[2]]\[Wedge]d[gv[u[1]]]\)\/mm[2, 2]\), 
              "+", \(\(nn[2, 
                      1]\ d[mm[1, 1]]\[Wedge]gv[u[1]]\[Wedge]gv[u[2]]\)\/\(mm[
                      1, 1]\ mm[2, 2]\)\), 
              "-", \(\(d[nn[2, 1]]\[Wedge]gv[u[1]]\[Wedge]gv[u[2]]\)\/mm[2, 
                    2]\), "+", 
              FractionBox[
                RowBox[{\(nn[2, 3]\), " ", \(nn[3, 1]\), " ", 
                  
                  RowBox[{\(d[x]\), "\[Wedge]", \(gv[u[1]]\), 
                    "\[Wedge]", \(gv[u[2]]\), 
                    "\[Wedge]", \(gv[{u[3]}, x, y, z]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 1, 0, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[2, 2]\ mm[3, 3]\)], "+", 
              FractionBox[
                RowBox[{\(nn[2, 3]\), " ", \(nn[3, 1]\), " ", 
                  
                  RowBox[{\(d[y]\), "\[Wedge]", \(gv[u[1]]\), 
                    "\[Wedge]", \(gv[u[2]]\), 
                    "\[Wedge]", \(gv[{u[3]}, x, y, z]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 1, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[2, 2]\ mm[3, 3]\)], "+", 
              FractionBox[
                RowBox[{\(nn[2, 3]\), " ", \(nn[3, 1]\), " ", 
                  
                  RowBox[{\(d[z]\), "\[Wedge]", \(gv[u[1]]\), 
                    "\[Wedge]", \(gv[u[2]]\), 
                    "\[Wedge]", \(gv[{u[3]}, x, y, z]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 0, 1)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[2, 2]\ mm[3, 3]\)]}], 
            ",", \(d[mm[2, 2]]\/mm[2, 2]\), ",", 
            
            RowBox[{\(-\(\(nn[2, 
                        3]\ gv[{u[3]}, x, y, z]\[Wedge]d[gv[u[2]]]\)\/mm[2, 
                      2]\)\), "+", 
              FractionBox[
                RowBox[{\(nn[2, 3]\), " ", 
                  RowBox[{\(d[x]\), "\[Wedge]", \(gv[u[2]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 1, 0, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[2, 2]\)], "+", 
              FractionBox[
                RowBox[{\(nn[2, 3]\), " ", 
                  RowBox[{\(d[y]\), "\[Wedge]", \(gv[u[2]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 1, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[2, 2]\)], "+", 
              FractionBox[
                RowBox[{\(nn[2, 3]\), " ", 
                  RowBox[{\(d[z]\), "\[Wedge]", \(gv[u[2]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 0, 1)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[2, 2]\)], 
              "-", \(\(nn[2, 
                      3]\ d[mm[3, 3]]\[Wedge]gv[u[2]]\[Wedge]gv[{u[3]}, x, y, 
                        z]\)\/\(mm[2, 2]\ mm[3, 3]\)\), 
              "+", \(\(d[nn[2, 3]]\[Wedge]gv[u[2]]\[Wedge]gv[{u[3]}, x, y, 
                      z]\)\/mm[2, 2]\), 
              "-", \(\(nn[1, 3]\ nn[2, 
                      1]\ gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[{u[3]}, x, y, 
                        z]\[Wedge]d[gv[u[1]]]\)\/\(mm[1, 1]\ mm[2, 2]\)\)}]}],
           "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            
            RowBox[{\(\(nn[3, 
                      1]\ gv[{u[3]}, x, y, z]\[Wedge]d[gv[u[1]]]\)\/mm[3, 
                    3]\), "-", 
              FractionBox[
                RowBox[{\(nn[3, 1]\), " ", 
                  RowBox[{\(d[x]\), "\[Wedge]", \(gv[u[1]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 1, 0, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[3, 3]\)], "-", 
              FractionBox[
                RowBox[{\(nn[3, 1]\), " ", 
                  RowBox[{\(d[y]\), "\[Wedge]", \(gv[u[1]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 1, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[3, 3]\)], "-", 
              FractionBox[
                RowBox[{\(nn[3, 1]\), " ", 
                  RowBox[{\(d[z]\), "\[Wedge]", \(gv[u[1]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 0, 1)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[3, 3]\)], 
              "+", \(\(nn[3, 
                      1]\ d[mm[1, 1]]\[Wedge]gv[u[1]]\[Wedge]gv[{u[3]}, x, y, 
                        z]\)\/\(mm[1, 1]\ mm[3, 3]\)\), 
              "-", \(\(d[nn[3, 1]]\[Wedge]gv[u[1]]\[Wedge]gv[{u[3]}, x, y, 
                      z]\)\/mm[3, 3]\), 
              "-", \(\(nn[2, 1]\ nn[3, 
                      2]\ gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[{u[3]}, x, y, 
                        z]\[Wedge]d[gv[u[2]]]\)\/\(mm[2, 2]\ mm[3, 3]\)\)}], 
            ",", 
            
            RowBox[{\(\(nn[3, 
                      2]\ gv[{u[3]}, x, y, z]\[Wedge]d[gv[u[2]]]\)\/mm[3, 
                    3]\), "-", 
              FractionBox[
                RowBox[{\(nn[3, 2]\), " ", 
                  RowBox[{\(d[x]\), "\[Wedge]", \(gv[u[2]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 1, 0, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[3, 3]\)], "-", 
              FractionBox[
                RowBox[{\(nn[3, 2]\), " ", 
                  RowBox[{\(d[y]\), "\[Wedge]", \(gv[u[2]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 1, 0)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[3, 3]\)], "-", 
              FractionBox[
                RowBox[{\(nn[3, 2]\), " ", 
                  RowBox[{\(d[z]\), "\[Wedge]", \(gv[u[2]]\), "\[Wedge]", 
                    RowBox[{
                      SuperscriptBox["gv", 
                        TagBox[\(({0}, 0, 0, 1)\),
                          Derivative],
                        MultilineFunction->None], "[", \({u[3]}, x, y, z\), 
                      "]"}]}]}], \(mm[3, 3]\)], 
              "+", \(\(nn[3, 
                      2]\ d[mm[2, 2]]\[Wedge]gv[u[2]]\[Wedge]gv[{u[3]}, x, y, 
                        z]\)\/\(mm[2, 2]\ mm[3, 3]\)\), 
              "-", \(\(d[nn[3, 2]]\[Wedge]gv[u[2]]\[Wedge]gv[{u[3]}, x, y, 
                      z]\)\/mm[3, 3]\), 
              "+", \(\(nn[1, 2]\ nn[3, 
                      1]\ gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[{u[3]}, x, y, 
                        z]\[Wedge]d[gv[u[1]]]\)\/\(mm[1, 1]\ mm[3, 3]\)\)}], 
            ",", \(d[mm[3, 3]]\/mm[3, 3]\)}], "}"}]}], "}"}]], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[d[GG] + GG\[Wedge]GG] // Timing\)], "Input"],

Cell[BoxData[
    \({7.883333333333333`\ Second, {{0, 0, 0}, {0, 0, 0}, {0, 0, 
          0}}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["wedgeDet, wedgeAdjoint", "Subsection",
  FontSize->16],

Cell[TextData[{
  "\[FilledSmallCircle]\tThe function ",
  StyleBox["wedgeDet[x_]",
    FontFamily->"Courier"],
  " gives the Determinant of the ",
  StyleBox["ordinary",
    FontSlant->"Italic"],
  " (square) matrix ",
  StyleBox["x",
    FontFamily->"Courier"],
  ". (For a supermatrix see ",
  StyleBox["Berezinian",
    FontFamily->"Courier"],
  ", below).  It generalizes ",
  StyleBox["Det:",
    FontFamily->"Courier"]
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeDet[Mat]\)], "Input"],

Cell[BoxData[
    \(\(-mm[1, 3]\)\ mm[2, 2]\ mm[3, 1] + mm[1, 2]\ mm[2, 3]\ mm[3, 1] + 
      mm[1, 3]\ mm[2, 1]\ mm[3, 2] - mm[1, 1]\ mm[2, 3]\ mm[3, 2] - 
      mm[1, 2]\ mm[2, 1]\ mm[3, 3] + 
      mm[1, 1]\ mm[2, 2]\ mm[3, 
          3] + \((mm[2, 3]\ mm[3, 1]\ nn[1, 2] - 
            mm[2, 1]\ mm[3, 3]\ nn[1, 2] - mm[1, 3]\ mm[3, 2]\ nn[2, 1] + 
            mm[1, 2]\ mm[3, 3]\ nn[2, 1])\)\ gv[u[1]]\[Wedge]gv[
            u[2]] + \((\(-mm[2, 2]\)\ mm[3, 1]\ nn[1, 3] + 
            mm[2, 1]\ mm[3, 2]\ nn[1, 3] + mm[1, 3]\ mm[2, 2]\ nn[3, 1] - 
            mm[1, 2]\ mm[2, 3]\ nn[3, 1])\)\ gv[u[1]]\[Wedge]gv[
            u[3]] + \((mm[1, 2]\ mm[3, 1]\ nn[2, 3] - 
            mm[1, 1]\ mm[3, 2]\ nn[2, 3] - mm[1, 3]\ mm[2, 1]\ nn[3, 2] + 
            mm[1, 1]\ mm[2, 3]\ nn[3, 2])\)\ gv[u[2]]\[Wedge]gv[
            u[3]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  "\t",
  StyleBox["Note",
    FontSlant->"Italic"],
  ": ",
  StyleBox["wedgeDet[x_]",
    FontFamily->"Courier"],
  " is defined recursively by its expansion in terms of the first row of ",
  StyleBox["x",
    FontFamily->"Courier"],
  ". Equivalent definitions in terms of other row (or column) expansions \
gives the same result for even matrices, but ",
  StyleBox["different",
    FontSlant->"Italic"],
  " results for odd matrices. ",
  StyleBox["Thus ",
    FontSlant->"Italic"],
  StyleBox["wedgeDet",
    FontFamily->"Courier",
    FontSlant->"Italic"],
  StyleBox["  should not be used on odd (or mixed parity) matrices as it is \
not well-defined.",
    FontSlant->"Italic"],
  " It is meant for even matrices that may contain (even products of) \
Grassmann variables."
}], "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(odd22 = {{gv[p[1]] - gv[p[2]]\[Wedge]gv[p[3]]\[Wedge]gv[p[4]], 
          gv[p[2]] - gv[p[1]]\[Wedge]gv[p[3]]\[Wedge]gv[p[4]]}, {gv[p[3]] - 
            gv[p[1]]\[Wedge]gv[p[2]]\[Wedge]gv[p[4]], 
          gv[p[4]] - gv[p[1]]\[Wedge]gv[p[2]]\[Wedge]gv[p[3]]}}\)], "Input"],

Cell[BoxData[
    \({{gv[p[1]] - gv[p[2]]\[Wedge]gv[p[3]]\[Wedge]gv[p[4]], 
        gv[p[2]] - gv[p[1]]\[Wedge]gv[p[3]]\[Wedge]gv[p[4]]}, {gv[p[3]] - 
          gv[p[1]]\[Wedge]gv[p[2]]\[Wedge]gv[p[4]], 
        gv[p[4]] - gv[p[1]]\[Wedge]gv[p[2]]\[Wedge]gv[p[3]]}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  StyleBox["wedgeDet",
    FontFamily->"Courier"],
  " uses the first row expansion definition. Different expansions give \
different results:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeDet[odd22]\)], "Input"],

Cell[BoxData[
    \(gv[p[1]]\[Wedge]gv[p[4]] - gv[p[2]]\[Wedge]gv[p[3]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(Wedge[odd22[\([1, 1]\)], odd22[\([2, 2]\)]]\), 
      "-", \(Wedge[odd22[\([1, 2]\)], odd22[\([2, 1]\)]]\), 
      RowBox[{"(*", 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\(first\ row\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \(gv[p[1]]\[Wedge]gv[p[4]] - gv[p[2]]\[Wedge]gv[p[3]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(Wedge[odd22[\([1, 1]\)], odd22[\([2, 2]\)]]\), 
      "-", \(Wedge[odd22[\([2, 1]\)], odd22[\([1, 2]\)]]\), 
      RowBox[{"(*", 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\(first\ column\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \(gv[p[1]]\[Wedge]gv[p[4]] + gv[p[2]]\[Wedge]gv[p[3]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(-Wedge[odd22[\([2, 1]\)], odd22[\([1, 2]\)]]\), 
      "+", \(Wedge[odd22[\([2, 2]\)], odd22[\([1, 1]\)]]\), 
      RowBox[{"(*", 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\(second\ row\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \(\(-\((gv[p[1]]\[Wedge]gv[p[4]])\)\) + 
      gv[p[2]]\[Wedge]gv[p[3]]\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[TextData[{
  "\[FilledSmallCircle]\tUsing ",
  StyleBox["wedgeDet",
    FontFamily->"Courier"],
  ", the function ",
  StyleBox["wedgeAdjoint[x_]",
    FontFamily->"Courier"],
  " constructs the adjoint (=transpose of the matrix of cofactors) of the \
(square) matrix ",
  StyleBox["x",
    FontFamily->"Courier"],
  ":"
}], "Text",
  FontSize->16],

Cell[BoxData[
    \(\(adjMat = wedgeAdjoint[Mat];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[adjMat\[Wedge]Mat - wedgeDet[Mat] IdentityMatrix[3]]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[adjMat - wedgeDet[Mat]\[Wedge]wedgeInverse[Mat]]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell["", "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["wedgeD", "Subsection",
  FontSize->16],

Cell[TextData[{
  "\tThe function ",
  StyleBox["wedgeD[x_,y_]",
    FontFamily->"Courier"],
  " generalizes the derivative operator ",
  StyleBox["D[x_,y_]",
    FontFamily->"Courier"],
  " when ",
  StyleBox["x",
    FontFamily->"Courier"],
  " contains Grassmann variables, or when ",
  StyleBox["y",
    FontFamily->"Courier"],
  " is a Grassmann variable",
  StyleBox[":",
    FontFamily->"Courier"]
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(expr = 
      gv[{v[1]}, x, y] - 
        gv[u[2]]\[Wedge]gv[{v[1]}, x, y]\[Wedge]gv[{v[2]}, x, y]\)], "Input"],

Cell[BoxData[
    \(gv[{v[1]}, x, y] - 
      gv[u[2]]\[Wedge]gv[{v[1]}, x, y]\[Wedge]gv[{v[2]}, x, y]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe ordinary ",
  StyleBox["D",
    FontWeight->"Bold"],
  " gives a wrong answer (Wedge is replaced by Times):"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(D[expr, x]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{
        SuperscriptBox["gv", 
          TagBox[\(({0}, 1, 0)\),
            Derivative],
          MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}], "-", 
      RowBox[{\(gv[u[2]]\), " ", \(gv[{v[2]}, x, y]\), " ", 
        RowBox[{
          SuperscriptBox["gv", 
            TagBox[\(({0}, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}]}], "-", 
      RowBox[{\(gv[u[2]]\), " ", \(gv[{v[1]}, x, y]\), " ", 
        RowBox[{
          SuperscriptBox["gv", 
            TagBox[\(({0}, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \({v[2]}, x, y\), 
          "]"}]}]}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeD[expr, x]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"-", 
        RowBox[{"(", 
          
          RowBox[{\(gv[u[2]]\), "\[Wedge]", \(gv[{v[1]}, x, y]\), "\[Wedge]", 
            
            RowBox[{
              SuperscriptBox["gv", 
                TagBox[\(({0}, 1, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \({v[2]}, x, y\), "]"}]}], 
          ")"}]}], "+", 
      RowBox[{\(gv[u[2]]\), "\[Wedge]", \(gv[{v[2]}, x, y]\), "\[Wedge]", 
        RowBox[{
          SuperscriptBox["gv", 
            TagBox[\(({0}, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}]}], "+", 
      RowBox[{
        SuperscriptBox["gv", 
          TagBox[\(({0}, 1, 0)\),
            Derivative],
          MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}]}]], "Output"]
}, Open  ]],

Cell["\<\
\tWedge treats derivatives of Grassmann fields correctly and puts \
them last:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Wedge[%, gv[u[1]]]\)], "Input"],

Cell[BoxData[
    RowBox[{
      RowBox[{"-", 
        RowBox[{"(", 
          RowBox[{\(gv[u[1]]\), "\[Wedge]", 
            RowBox[{
              SuperscriptBox["gv", 
                TagBox[\(({0}, 1, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}]}], 
          ")"}]}], "+", 
      RowBox[{\(gv[u[1]]\), "\[Wedge]", \(gv[u[2]]\), 
        "\[Wedge]", \(gv[{v[1]}, x, y]\), "\[Wedge]", 
        RowBox[{
          SuperscriptBox["gv", 
            TagBox[\(({0}, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \({v[2]}, x, y\), "]"}]}], "-", 
      RowBox[{\(gv[u[1]]\), "\[Wedge]", \(gv[u[2]]\), 
        "\[Wedge]", \(gv[{v[2]}, x, y]\), "\[Wedge]", 
        RowBox[{
          SuperscriptBox["gv", 
            TagBox[\(({0}, 1, 0)\),
              Derivative],
            MultilineFunction->None], "[", \({v[1]}, x, y\), 
          "]"}]}]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  "\twedge",
  StyleBox["D",
    FontWeight->"Bold"],
  " allows differentiation w.r.t. Grassmann variables and ",
  StyleBox["acts from the left",
    FontSlant->"Italic"],
  " (note sign):"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeD[expr, gv[{v[1]}, x, y]]\)], "Input"],

Cell[BoxData[
    \(1 + gv[u[2]]\[Wedge]gv[{v[2]}, x, y]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeD[gv[u[1]]\[Wedge]gv[u[2]], gv[u[2]]]\)], "Input"],

Cell[BoxData[
    \(\(-gv[u[1]]\)\)], "Output"]
}, Open  ]],

Cell["\tDerivatives w.r.t odd variables anticommute:", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeD[wedgeD[gv[u[1]]\[Wedge]gv[u[2]], gv[u[2]]], gv[u[1]]] + 
      wedgeD[wedgeD[gv[u[1]]\[Wedge]gv[u[2]], gv[u[1]]], gv[u[2]]]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe following expression does not vanish identically because ",
  StyleBox["d",
    FontWeight->"Bold"],
  " treats all symbols as variables:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[
      d[x]\[Wedge]wedgeD[expr, x] + d[y]\[Wedge]wedgeD[expr, y] - 
        d[expr]]\)], "Input"],

Cell[BoxData[
    \(gv[{v[1]}, x, y]\[Wedge]gv[{v[2]}, x, y]\[Wedge]d[gv[u[2]]]\)], "Output"]
}, Open  ]],

Cell[TextData[
"\tThe total differential includes derivatives w.r.t. all variables (i.e., \
gv[u[2]] also in  this case) and is defined as d[F[vars]]=Sum[d[vars[[i]]]\
\[Wedge]wedgeD[FF[vars], vars[[i]]], {i, Length[vars]}]."], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[
      d[x]\[Wedge]wedgeD[expr, x] + d[y]\[Wedge]wedgeD[expr, y] + 
        d[gv[u[2]]]\[Wedge]wedgeD[expr, gv[u[2]]] - d[expr]]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tNote that, while the ordering of d[x] and wedgeD[F, x] is not important \
for ordinary variables x, this is not so for Grassmann variables: d[gv[k]]\
\[Wedge]wedgeD[evenExpr, gv[k]] equals ",
  StyleBox["minus",
    FontSlant->"Italic"],
  " wedgeD[evenExpr, gv[k]]\[Wedge]d[gv[k]], where \"evenExpr\" is an even \
expression. ",
  StyleBox["superEDC uses the ordering convention d[F]=d[x]\[Wedge]wedgeD[F, \
x]",
    FontSlant->"Italic"]
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(d[gv[u[1]]]\[Wedge]wedgeD[Mat[\([1, 2]\)], \ gv[u[1]]]\)], "Input"],

Cell[BoxData[
    \(\(-nn[1, 2]\)\ gv[u[2]]\[Wedge]d[gv[u[1]]]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeD[Mat[\([1, 2]\)], \ gv[u[1]]]\[Wedge]d[gv[u[1]]]\)], "Input"],

Cell[BoxData[
    \(nn[1, 2]\ gv[u[2]]\[Wedge]d[gv[u[1]]]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox["wedgeD",
    FontWeight->"Bold"],
  " can act on matrices. For higher derivatives, ",
  StyleBox["wedgeD",
    FontWeight->"Bold"],
  " is called the same way as ",
  StyleBox["D",
    FontWeight->"Bold"],
  ":"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    \(\(MM = {{gv[u[1]]\[Wedge]gv[{v[2]}, x, y] + \(dd[1]\)[x, y], 
            gv[{v[1]}, x, y]\[Wedge]gv[{v[2]}, x, y]}, {gv[
                u[2]]\[Wedge]gv[{v[1]}, x, y], 
            gv[u[1]]\[Wedge]gv[u[2]] + \(dd[2]\)[x, y]}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeD[MM, {x, 2}]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{\(gv[u[1]]\), "\[Wedge]", 
                RowBox[{
                  SuperscriptBox["gv", 
                    TagBox[\(({0}, 2, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \({v[2]}, x, y\), "]"}]}], 
              "+", 
              RowBox[{
                SuperscriptBox[\(dd[1]\), 
                  TagBox[\((2, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \(x, y\), "]"}]}], ",", 
            RowBox[{
              RowBox[{\(gv[{v[1]}, x, y]\), "\[Wedge]", 
                RowBox[{
                  SuperscriptBox["gv", 
                    TagBox[\(({0}, 2, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \({v[2]}, x, y\), "]"}]}], 
              "-", 
              RowBox[{\(gv[{v[2]}, x, y]\), "\[Wedge]", 
                RowBox[{
                  SuperscriptBox["gv", 
                    TagBox[\(({0}, 2, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}]}], 
              "+", 
              RowBox[{"2", " ", 
                RowBox[{
                  RowBox[{
                    SuperscriptBox["gv", 
                      TagBox[\(({0}, 1, 0)\),
                        Derivative],
                      MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}], 
                  "\[Wedge]", 
                  RowBox[{
                    SuperscriptBox["gv", 
                      TagBox[\(({0}, 1, 0)\),
                        Derivative],
                      MultilineFunction->None], "[", \({v[2]}, x, y\), 
                    "]"}]}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{\(gv[u[2]]\), "\[Wedge]", 
              RowBox[{
                SuperscriptBox["gv", 
                  TagBox[\(({0}, 2, 0)\),
                    Derivative],
                  MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}]}], 
            ",", 
            RowBox[{
              SuperscriptBox[\(dd[2]\), 
                TagBox[\((2, 0)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}]}], "}"}]}], 
      "}"}]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeD[MM, x, x] === %\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeD[MM, x, y]\)], "Input"],

Cell[BoxData[
    RowBox[{"{", 
      RowBox[{
        RowBox[{"{", 
          RowBox[{
            RowBox[{
              RowBox[{\(gv[u[1]]\), "\[Wedge]", 
                RowBox[{
                  SuperscriptBox["gv", 
                    TagBox[\(({0}, 1, 1)\),
                      Derivative],
                    MultilineFunction->None], "[", \({v[2]}, x, y\), "]"}]}], 
              "+", 
              RowBox[{
                SuperscriptBox[\(dd[1]\), 
                  TagBox[\((1, 1)\),
                    Derivative],
                  MultilineFunction->None], "[", \(x, y\), "]"}]}], ",", 
            RowBox[{
              RowBox[{\(gv[{v[1]}, x, y]\), "\[Wedge]", 
                RowBox[{
                  SuperscriptBox["gv", 
                    TagBox[\(({0}, 1, 1)\),
                      Derivative],
                    MultilineFunction->None], "[", \({v[2]}, x, y\), "]"}]}], 
              "-", 
              RowBox[{\(gv[{v[2]}, x, y]\), "\[Wedge]", 
                RowBox[{
                  SuperscriptBox["gv", 
                    TagBox[\(({0}, 1, 1)\),
                      Derivative],
                    MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}]}], 
              "+", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["gv", 
                    TagBox[\(({0}, 0, 1)\),
                      Derivative],
                    MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}], 
                "\[Wedge]", 
                RowBox[{
                  SuperscriptBox["gv", 
                    TagBox[\(({0}, 1, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \({v[2]}, x, y\), "]"}]}], 
              "+", 
              RowBox[{
                RowBox[{
                  SuperscriptBox["gv", 
                    TagBox[\(({0}, 1, 0)\),
                      Derivative],
                    MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}], 
                "\[Wedge]", 
                RowBox[{
                  SuperscriptBox["gv", 
                    TagBox[\(({0}, 0, 1)\),
                      Derivative],
                    MultilineFunction->None], "[", \({v[2]}, x, y\), 
                  "]"}]}]}]}], "}"}], ",", 
        RowBox[{"{", 
          RowBox[{
            RowBox[{\(gv[u[2]]\), "\[Wedge]", 
              RowBox[{
                SuperscriptBox["gv", 
                  TagBox[\(({0}, 1, 1)\),
                    Derivative],
                  MultilineFunction->None], "[", \({v[1]}, x, y\), "]"}]}], 
            ",", 
            RowBox[{
              SuperscriptBox[\(dd[2]\), 
                TagBox[\((1, 1)\),
                  Derivative],
                MultilineFunction->None], "[", \(x, y\), "]"}]}], "}"}]}], 
      "}"}]], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["wedgeMatrixExp", "Subsection",
  FontSize->16],

Cell[TextData[{
  "\tThe function wedgeMatrixExp",
  StyleBox["[x_]",
    FontFamily->"Courier"],
  " generalizes the function ",
  StyleBox["MatrixExp[x_]",
    FontFamily->"Courier"],
  ", giving the exponential of the matrix ",
  StyleBox["x",
    FontFamily->"Courier"],
  ", when ",
  StyleBox["x",
    FontFamily->"Courier"],
  "  is one of the following:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
  " (1)  ",
  StyleBox["x",
    FontFamily->"Courier"],
  "  contains no Grassmann variables (soul[x]=0 matrix), in which case the \
result is just MatrixExp[x]:"
}], "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeMatrixExp[{{a, 0}, {0, b}}]\)], "Input"],

Cell[BoxData[
    \({{\[ExponentialE]\^a, 0}, {0, \[ExponentialE]\^b}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeMatrixExp[{{1, a}, {a, 1}}]\)], "Input"],

Cell[BoxData[
    \({{\[ExponentialE]\^\(1 - a\)\/2 + \[ExponentialE]\^\(1 + a\)\/2, \(-\(\
\[ExponentialE]\^\(1 - a\)\/2\)\) + \[ExponentialE]\^\(1 + a\)\/2}, {\(-\(\
\[ExponentialE]\^\(1 - a\)\/2\)\) + \[ExponentialE]\^\(1 + a\)\/2, \
\[ExponentialE]\^\(1 - a\)\/2 + \[ExponentialE]\^\(1 + a\)\/2}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeMatrixExp[{{1, \(-a\)}, {a, 1}}]\)], "Input"],

Cell[BoxData[
    \({{\[ExponentialE]\ Cos[a], \(-\[ExponentialE]\)\ Sin[
            a]}, {\[ExponentialE]\ Sin[a], \[ExponentialE]\ Cos[
            a]}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  " (2)  ",
  StyleBox["x",
    FontFamily->"Courier"],
  "  is an ",
  StyleBox["explicit",
    FontSlant->"Italic"],
  " matrix, ",
  StyleBox["all nonzero elements of which",
    FontSlant->"Italic"],
  " are Grassmann variables (body[x]=0 matrix):"
}], "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(explicitMat = {\(a[#] gv[#] &\) /@ {1, 2, 3}, \(b[#] gv[#] &\) /@ {1, 
            2, 3}, \(c[#] gv[#] &\) /@ {1, 2, 3}}\)], "Input"],

Cell[BoxData[
    \({{a[1]\ gv[1], a[2]\ gv[2], a[3]\ gv[3]}, {b[1]\ gv[1], b[2]\ gv[2], 
        b[3]\ gv[3]}, {c[1]\ gv[1], c[2]\ gv[2], c[3]\ gv[3]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(wedgeMatrixExp[explicitMat]\),
      FontFamily->"Courier"]], "Input"],

Cell[BoxData[
    \({{1 + a[1]\ gv[1] + 
          1\/2\ \((\(-a[2]\)\ b[1]\ gv[1]\[Wedge]gv[2] - 
                a[3]\ c[1]\ gv[1]\[Wedge]gv[3])\) + 
          1\/6\ \((a[2]\ b[3]\ c[1] - a[3]\ b[1]\ c[2])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3], 
        a[2]\ gv[2] + 
          1\/2\ \((a[1]\ a[2]\ gv[1]\[Wedge]gv[2] - 
                a[3]\ c[2]\ gv[2]\[Wedge]gv[3])\) + 
          1\/6\ a[3]\ \((a[2]\ c[1] - a[1]\ c[2])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3], 
        a[3]\ gv[3] + 
          1\/2\ \((a[1]\ a[3]\ gv[1]\[Wedge]gv[3] + 
                a[2]\ b[3]\ gv[2]\[Wedge]gv[3])\) - 
          1\/6\ a[2]\ \((a[3]\ b[1] - a[1]\ b[3])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3]}, {b[1]\ gv[1] + 
          1\/2\ \((\(-b[1]\)\ b[2]\ gv[1]\[Wedge]gv[2] - 
                b[3]\ c[1]\ gv[1]\[Wedge]gv[3])\) + 
          1\/6\ b[3]\ \((b[2]\ c[1] - b[1]\ c[2])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3], 
        1 + b[2]\ gv[2] + 
          1\/2\ \((a[2]\ b[1]\ gv[1]\[Wedge]gv[2] - 
                b[3]\ c[2]\ gv[2]\[Wedge]gv[3])\) + 
          1\/6\ \((a[2]\ b[3]\ c[1] - a[3]\ b[1]\ c[2])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3], 
        b[3]\ gv[3] + 
          1\/2\ \((a[3]\ b[1]\ gv[1]\[Wedge]gv[3] + 
                b[2]\ b[3]\ gv[2]\[Wedge]gv[3])\) - 
          1\/6\ b[1]\ \((a[3]\ b[2] - a[2]\ b[3])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3]}, {c[1]\ gv[1] + 
          1\/2\ \((\(-b[1]\)\ c[2]\ gv[1]\[Wedge]gv[2] - 
                c[1]\ c[3]\ gv[1]\[Wedge]gv[3])\) + 
          1\/6\ c[2]\ \((b[3]\ c[1] - b[1]\ c[3])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3], 
        c[2]\ gv[2] + 
          1\/2\ \((a[2]\ c[1]\ gv[1]\[Wedge]gv[2] - 
                c[2]\ c[3]\ gv[2]\[Wedge]gv[3])\) - 
          1\/6\ c[1]\ \((a[3]\ c[2] - a[2]\ c[3])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3], 
        1 + c[3]\ gv[3] + 
          1\/2\ \((a[3]\ c[1]\ gv[1]\[Wedge]gv[3] + 
                b[3]\ c[2]\ gv[2]\[Wedge]gv[3])\) + 
          1\/6\ \((a[2]\ b[3]\ c[1] - a[3]\ b[1]\ c[2])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(wedgeMatrixExp[\(-explicitMat\)]\),
      FontFamily->"Courier"]], "Input"],

Cell[BoxData[
    \({{1 - a[1]\ gv[1] + 
          1\/2\ \((\(-a[2]\)\ b[1]\ gv[1]\[Wedge]gv[2] - 
                a[3]\ c[1]\ gv[1]\[Wedge]gv[3])\) + 
          1\/6\ \((\(-a[2]\)\ b[3]\ c[1] + a[3]\ b[1]\ c[2])\)\ gv[
                1]\[Wedge]gv[2]\[Wedge]gv[3], \(-a[2]\)\ gv[2] + 
          1\/2\ \((a[1]\ a[2]\ gv[1]\[Wedge]gv[2] - 
                a[3]\ c[2]\ gv[2]\[Wedge]gv[3])\) - 
          1\/6\ a[3]\ \((a[2]\ c[1] - a[1]\ c[2])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3], \(-a[3]\)\ gv[3] + 
          1\/2\ \((a[1]\ a[3]\ gv[1]\[Wedge]gv[3] + 
                a[2]\ b[3]\ gv[2]\[Wedge]gv[3])\) + 
          1\/6\ a[2]\ \((a[3]\ b[1] - a[1]\ b[3])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3]}, {\(-b[1]\)\ gv[1] + 
          1\/2\ \((\(-b[1]\)\ b[2]\ gv[1]\[Wedge]gv[2] - 
                b[3]\ c[1]\ gv[1]\[Wedge]gv[3])\) - 
          1\/6\ b[3]\ \((b[2]\ c[1] - b[1]\ c[2])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3], 
        1 - b[2]\ gv[2] + 
          1\/2\ \((a[2]\ b[1]\ gv[1]\[Wedge]gv[2] - 
                b[3]\ c[2]\ gv[2]\[Wedge]gv[3])\) + 
          1\/6\ \((\(-a[2]\)\ b[3]\ c[1] + a[3]\ b[1]\ c[2])\)\ gv[
                1]\[Wedge]gv[2]\[Wedge]gv[3], \(-b[3]\)\ gv[3] + 
          1\/2\ \((a[3]\ b[1]\ gv[1]\[Wedge]gv[3] + 
                b[2]\ b[3]\ gv[2]\[Wedge]gv[3])\) + 
          1\/6\ b[1]\ \((a[3]\ b[2] - a[2]\ b[3])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3]}, {\(-c[1]\)\ gv[1] + 
          1\/2\ \((\(-b[1]\)\ c[2]\ gv[1]\[Wedge]gv[2] - 
                c[1]\ c[3]\ gv[1]\[Wedge]gv[3])\) - 
          1\/6\ c[2]\ \((b[3]\ c[1] - b[1]\ c[3])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3], \(-c[2]\)\ gv[2] + 
          1\/2\ \((a[2]\ c[1]\ gv[1]\[Wedge]gv[2] - 
                c[2]\ c[3]\ gv[2]\[Wedge]gv[3])\) + 
          1\/6\ c[1]\ \((a[3]\ c[2] - a[2]\ c[3])\)\ gv[1]\[Wedge]gv[
                2]\[Wedge]gv[3], 
        1 - c[3]\ gv[3] + 
          1\/2\ \((a[3]\ c[1]\ gv[1]\[Wedge]gv[3] + 
                b[3]\ c[2]\ gv[2]\[Wedge]gv[3])\) + 
          1\/6\ \((\(-a[2]\)\ b[3]\ c[1] + a[3]\ b[1]\ c[2])\)\ gv[
                1]\[Wedge]gv[2]\[Wedge]gv[3]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Factor[Wedge[%%, %]]\)], "Input"],

Cell[BoxData[
    \({{1, 0, 0}, {0, 1, 0}, {0, 0, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(explicitMat /. gv[__] \[Rule] 0\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0}, {0, 0, 0}, {0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell["\<\
wedgeMatrixExp uses the power series expansion of the exponential, \
which is necessarily finite due to the antisymmetry of the Grassmann \
variables, to evaluate such expressions. That's why it cannot handle matrices \
with elements that have both ordinary and Grassmann variables:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(Mat\)], "Input"],

Cell[BoxData[
    \({{mm[1, 1], mm[1, 2] + nn[1, 2]\ gv[u[1]]\[Wedge]gv[u[2]], 
        mm[1, 3] + nn[1, 3]\ gv[u[1]]\[Wedge]gv[u[3]]}, {mm[2, 1] - 
          nn[2, 1]\ gv[u[1]]\[Wedge]gv[u[2]], mm[2, 2], 
        mm[2, 3] + nn[2, 3]\ gv[u[2]]\[Wedge]gv[u[3]]}, {mm[3, 1] - 
          nn[3, 1]\ gv[u[1]]\[Wedge]gv[u[3]], 
        mm[3, 2] - nn[3, 2]\ gv[u[2]]\[Wedge]gv[u[3]], mm[3, 3]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeMatrixExp[Mat]\)], "Input"],

Cell[BoxData[
    \("Cannot exponentiate sums of ordinary and Grassmann matrices"\)], \
"Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  " (3)  ",
  StyleBox["x",
    FontFamily->"Courier"],
  "  is an ",
  StyleBox["implicit",
    FontSlant->"Italic"],
  " matrix, ",
  StyleBox["all nonzero elements of which",
    FontSlant->"Italic"],
  " are Grassmann variables (body[x]=0 matrix):"
}], "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell["\tWe will declare the symbols A[_] to denote matrices:", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeclareMatrixForms[{0, A[_], A[_]}]\)], "Input"],

Cell[BoxData[
    \("Define GrassParity and ordering rule for symbolic matrices and gv[] \
variables!"\)], "Output",
  FontSize->16,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \("OK"\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "This warning is printed because superEDC does not have predefined rules \
for ordering symbolic matrices and Grassmann variables. Such rules ",
  StyleBox["must",
    FontSlant->"Italic"],
  " be given by the user. For example (see also the example in section 6):"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    \(GrassParity[A[_]] = 0; \nWedge[A[x_], gv[y_]] := Wedge[gv[y], A[x]]\)], 
  "Input"],

Cell[BoxData[
    \( (*\(\(*\)\(\ \)\(More\)\(\ \)\(generally : \ \ \
\[IndentingNewLine]Wedge[A[x_], 
              gv[y_]]\)\) := \((\(-1\))\)^\((GrassParity[A[x]]*
                  GrassParity[gv[y]] + FormDegree[A[x]]*FormDegree[gv[y]])\) 
          Wedge[gv[y], A[x]]; \ \[IndentingNewLine]Also, \ 
      if\ needed, \ \(Wedge[A[x_], 
            d[gv[y_]]] := \((\(-1\))\)^\((GrassParity[A[x]]*
                    GrassParity[gv[y]] + 
                  FormDegree[A[x]]*FormDegree[d[gv[y]]])\) 
            Wedge[d[gv[y]], A[x]];\)\ **) \)], "Input",
  FontColor->GrayLevel[0.666667]],

Cell[CellGroupData[{

Cell[BoxData[
    \(implicitMat = A[0] + Sum[gv[i]\[Wedge]A[i], {i, 4}]\)], "Input"],

Cell[BoxData[
    \(A[0] + gv[1]\[Wedge]A[1] + gv[2]\[Wedge]A[2] + gv[3]\[Wedge]A[3] + 
      gv[4]\[Wedge]A[4]\)], "Output"]
}, Open  ]],

Cell["\<\
This is a sum of an ordinary matrix (A[0]) and a Grassmann \
part.\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(wedgeMatrixExp[%]\),
      FontFamily->"Courier"]], "Input"],

Cell[BoxData[
    \("Cannot exponentiate sums of ordinary and Grassmann matrices"\)], \
"Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"symbolicExponentiation", "=", 
      StyleBox[\(wedgeMatrixExp[soul[implicitMat]]\),
        FontFamily->"Courier"]}]], "Input"],

Cell[BoxData[
    \(1 + gv[1]\[Wedge]A[1] + gv[2]\[Wedge]A[2] + gv[3]\[Wedge]A[3] + 
      gv[4]\[Wedge]A[4] + 
      1\/2\ \((gv[1]\[Wedge]gv[2]\[Wedge]A[1]\[Wedge]A[2] - 
            gv[1]\[Wedge]gv[2]\[Wedge]A[2]\[Wedge]A[1] + 
            gv[1]\[Wedge]gv[3]\[Wedge]A[1]\[Wedge]A[3] - 
            gv[1]\[Wedge]gv[3]\[Wedge]A[3]\[Wedge]A[1] + 
            gv[1]\[Wedge]gv[4]\[Wedge]A[1]\[Wedge]A[4] - 
            gv[1]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[1] + 
            gv[2]\[Wedge]gv[3]\[Wedge]A[2]\[Wedge]A[3] - 
            gv[2]\[Wedge]gv[3]\[Wedge]A[3]\[Wedge]A[2] + 
            gv[2]\[Wedge]gv[4]\[Wedge]A[2]\[Wedge]A[4] - 
            gv[2]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[2] + 
            gv[3]\[Wedge]gv[4]\[Wedge]A[3]\[Wedge]A[4] - 
            gv[3]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[3])\) + 
      1\/6\ \((gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]A[1]\[Wedge]A[
                2]\[Wedge]A[3] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]A[1]\[Wedge]A[3]\[Wedge]A[
                2] - gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]A[2]\[Wedge]A[
                1]\[Wedge]A[3] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]A[2]\[Wedge]A[3]\[Wedge]A[
                1] + gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]A[3]\[Wedge]A[
                1]\[Wedge]A[2] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]A[3]\[Wedge]A[2]\[Wedge]A[
                1] + gv[1]\[Wedge]gv[2]\[Wedge]gv[4]\[Wedge]A[1]\[Wedge]A[
                2]\[Wedge]A[4] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[4]\[Wedge]A[1]\[Wedge]A[4]\[Wedge]A[
                2] - gv[1]\[Wedge]gv[2]\[Wedge]gv[4]\[Wedge]A[2]\[Wedge]A[
                1]\[Wedge]A[4] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[4]\[Wedge]A[2]\[Wedge]A[4]\[Wedge]A[
                1] + gv[1]\[Wedge]gv[2]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[
                1]\[Wedge]A[2] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[2]\[Wedge]A[
                1] + gv[1]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[1]\[Wedge]A[
                3]\[Wedge]A[4] - 
            gv[1]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[1]\[Wedge]A[4]\[Wedge]A[
                3] - gv[1]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[3]\[Wedge]A[
                1]\[Wedge]A[4] + 
            gv[1]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[3]\[Wedge]A[4]\[Wedge]A[
                1] + gv[1]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[
                1]\[Wedge]A[3] - 
            gv[1]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[3]\[Wedge]A[
                1] + 
            gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[2]\[Wedge]A[3]\[Wedge]A[
                4] - gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[2]\[Wedge]A[
                4]\[Wedge]A[3] - 
            gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[3]\[Wedge]A[2]\[Wedge]A[
                4] + gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[3]\[Wedge]A[
                4]\[Wedge]A[2] + 
            gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[2]\[Wedge]A[
                3] - gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[
                3]\[Wedge]A[2])\) + 
      1\/24\ \((gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[
                1]\[Wedge]A[2]\[Wedge]A[3]\[Wedge]A[4] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[1]\[Wedge]A[
                2]\[Wedge]A[4]\[Wedge]A[3] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[1]\[Wedge]A[
                3]\[Wedge]A[2]\[Wedge]A[4] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[1]\[Wedge]A[
                3]\[Wedge]A[4]\[Wedge]A[2] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[1]\[Wedge]A[
                4]\[Wedge]A[2]\[Wedge]A[3] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[1]\[Wedge]A[
                4]\[Wedge]A[3]\[Wedge]A[2] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[2]\[Wedge]A[
                1]\[Wedge]A[3]\[Wedge]A[4] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[2]\[Wedge]A[
                1]\[Wedge]A[4]\[Wedge]A[3] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[2]\[Wedge]A[
                3]\[Wedge]A[1]\[Wedge]A[4] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[2]\[Wedge]A[
                3]\[Wedge]A[4]\[Wedge]A[1] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[2]\[Wedge]A[
                4]\[Wedge]A[1]\[Wedge]A[3] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[2]\[Wedge]A[
                4]\[Wedge]A[3]\[Wedge]A[1] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[3]\[Wedge]A[
                1]\[Wedge]A[2]\[Wedge]A[4] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[3]\[Wedge]A[
                1]\[Wedge]A[4]\[Wedge]A[2] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[3]\[Wedge]A[
                2]\[Wedge]A[1]\[Wedge]A[4] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[3]\[Wedge]A[
                2]\[Wedge]A[4]\[Wedge]A[1] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[3]\[Wedge]A[
                4]\[Wedge]A[1]\[Wedge]A[2] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[3]\[Wedge]A[
                4]\[Wedge]A[2]\[Wedge]A[1] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[
                1]\[Wedge]A[2]\[Wedge]A[3] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[
                1]\[Wedge]A[3]\[Wedge]A[2] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[
                2]\[Wedge]A[1]\[Wedge]A[3] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[
                2]\[Wedge]A[3]\[Wedge]A[1] - 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[
                3]\[Wedge]A[1]\[Wedge]A[2] + 
            gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[4]\[Wedge]A[4]\[Wedge]A[
                3]\[Wedge]A[2]\[Wedge]A[1])\)\)], "Output"]
}, Closed]],

Cell[TextData[{
  "The expansion stops at the 4th order -- higher orders will contain two \
equal gv[i] and therefore vanish. This is a symbolic matrix expression: the \
\"1\" stands for the IdentityMatrix. To substitute explicit matrices for the \
A[i] one must not use Replace (/.) but the EDC function ",
  StyleBox["toComponents",
    FontFamily->"Courier"],
  ":"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    \(\(explicitMatRules = {A[1] \[Rule] {{a, 0}, {0, 0}}, 
          A[2] \[Rule] {{0, b}, {0, 0}}, A[3] \[Rule] {{0, 0}, {c, 0}}, 
          A[4] \[Rule] {{0, 0}, {0, d}}};\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(toComponents[symbolicExponentiation, explicitMatRules]\)], "Input"],

Cell[BoxData[
    \({{1 + a\ gv[1] + 1\/2\ b\ c\ gv[2]\[Wedge]gv[3] + 
          1\/3\ a\ b\ c\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3] - 
          1\/6\ b\ c\ d\ gv[2]\[Wedge]gv[3]\[Wedge]gv[4], 
        b\ gv[2] + 1\/2\ a\ b\ gv[1]\[Wedge]gv[2] + 
          1\/2\ b\ d\ gv[2]\[Wedge]gv[4] + 
          1\/6\ a\ b\ d\ gv[1]\[Wedge]gv[2]\[Wedge]gv[4]}, {c\ gv[3] - 
          1\/2\ a\ c\ gv[1]\[Wedge]gv[3] - 1\/2\ c\ d\ gv[3]\[Wedge]gv[4] - 
          1\/6\ a\ c\ d\ gv[1]\[Wedge]gv[3]\[Wedge]gv[4], 
        1 + d\ gv[4] - 1\/2\ b\ c\ gv[2]\[Wedge]gv[3] + 
          1\/6\ a\ b\ c\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3] - 
          1\/3\ b\ c\ d\ gv[2]\[Wedge]gv[3]\[Wedge]gv[4]}}\)], "Output"]
}, Open  ]],

Cell["\<\
The result is the same if we exponentiate the explicit \
matrix:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(toComponents[soul[implicitMat], explicitMatRules]\)], "Input"],

Cell[BoxData[
    \({{a\ gv[1], b\ gv[2]}, {c\ gv[3], d\ gv[4]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"reWrite", "[", 
      StyleBox[\(wedgeMatrixExp[%]\),
        FontFamily->"Courier"], 
      StyleBox["]",
        FontFamily->"Courier"]}]], "Input"],

Cell[BoxData[
    \({{1 + a\ gv[1] + 1\/2\ b\ c\ gv[2]\[Wedge]gv[3] + 
          1\/3\ a\ b\ c\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3] - 
          1\/6\ b\ c\ d\ gv[2]\[Wedge]gv[3]\[Wedge]gv[4], 
        b\ gv[2] + 1\/2\ a\ b\ gv[1]\[Wedge]gv[2] + 
          1\/2\ b\ d\ gv[2]\[Wedge]gv[4] + 
          1\/6\ a\ b\ d\ gv[1]\[Wedge]gv[2]\[Wedge]gv[4]}, {c\ gv[3] - 
          1\/2\ a\ c\ gv[1]\[Wedge]gv[3] - 1\/2\ c\ d\ gv[3]\[Wedge]gv[4] - 
          1\/6\ a\ c\ d\ gv[1]\[Wedge]gv[3]\[Wedge]gv[4], 
        1 + d\ gv[4] - 1\/2\ b\ c\ gv[2]\[Wedge]gv[3] + 
          1\/6\ a\ b\ c\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3] - 
          1\/3\ b\ c\ d\ gv[2]\[Wedge]gv[3]\[Wedge]gv[4]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% - %%%\)], "Input"],

Cell[BoxData[
    \({{0, 0}, {0, 0}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  " (4)  ",
  StyleBox["x",
    FontFamily->"Courier"],
  "  is not a matrix; in this case the part depending on Grassmann variables \
is expanded:"
}], "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(evenExpr = 
      a[0] + a[1]\ gv[1]\[Wedge]gv[2] + a[2]\ gv[3]\[Wedge]gv[4]\)], "Input"],

Cell[BoxData[
    \(a[0] + a[1]\ gv[1]\[Wedge]gv[2] + a[2]\ gv[3]\[Wedge]gv[4]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    StyleBox[\(wedgeMatrixExp[%]\),
      FontFamily->"Courier"]], "Input"],

Cell[BoxData[
    \(\[ExponentialE]\^a[0]\ \((1 + a[1]\ gv[1]\[Wedge]gv[2] + 
          a[2]\ gv[3]\[Wedge]gv[4] + 
          a[1]\ a[2]\ gv[1]\[Wedge]gv[2]\[Wedge]gv[3]\[Wedge]gv[
                4])\)\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],

Cell["\<\

The user should familiarize him/herself with the gv[ ] notation and the use \
of these functions before reading the remaining sections on supermatrices / \
superFunctions. \
\>", "Text",
  Evaluatable->False,
  FontSize->16,
  FontSlant->"Italic"]
}, Closed]],

Cell["", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["Part II: Superalgebra", "Subtitle",
  Evaluatable->False,
  FontWeight->"Bold"],

Cell[CellGroupData[{

Cell[TextData[{
  "4. ",
  StyleBox["Supermatrix -vector definitions:",
    FontSlant->"Italic"],
  " SuperMatrix Construction, subMatTK, subMatDR, EvenGrassQ, GrassParity"
}], "Section",
  Evaluatable->False,
  FontSize->18],

Cell[CellGroupData[{

Cell["Preliminary Definitions", "Subsection",
  FontSize->16],

Cell[TextData[{
  "\tAll sums and all elements of an ",
  StyleBox["ordinary",
    FontSlant->"Italic"],
  " matrix are assumed to be either even or odd (i.e., apart from 0 elements, \
they contain only even or odd products of Grassmann variables). Supermatrices \
are assumed to be square, of dimensions (p+q)x(p+q), and ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  ": in block form, the Supermatrix S={{A, B},{C, D}} is even if the ordinary \
submatrices A (pxp) and D (qxq) are even and B (pxq) and C (qxp) are odd, and \
S is odd if A and D are odd and B and C even. Similarly a 1-dimensional list \
of (p+q) elements {A, B} is a homogeneous supervector, which is even (odd) if \
A is even (odd) and B is odd (even). All definitions and all terms in this \
manual agree with those in ",
  ButtonBox["http://en.wikipedia.org/wiki/Supermatrix",
    ButtonData:>{
      URL[ "http://en.wikipedia.org/wiki/Supermatrix"], None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[TextData[{
  StyleBox["Important note:",
    FontSlant->"Italic"],
  " Matrices must be given as nested lists, i.e., without using \
\"MatrixForm\" on them. "
}], "Text",
  Evaluatable->False,
  FontSize->16,
  FontWeight->"Bold"],

Cell[TextData[{
  "\tWe will construct typical even and odd matrices depending on 4 Grassmann \
variables. First we calculate the different Wedge products of order 2 and 3 \
of the basic 4 variables. ",
  StyleBox["Wedge",
    FontFamily->"Courier"],
  " on Grassmann variables automatically sorts them in alphabetical order."
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(fourGVfields = {gv[u[1]], \ gv[u[2]], gv[v[1]], \ gv[v[2]]}\)], "Input"],

Cell[BoxData[
    \({gv[u[1]], gv[u[2]], gv[v[1]], gv[v[2]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ord2prod = 
      Drop[Union[
          Flatten[Outer[Wedge, fourGVfields, 
                fourGVfields] /. \(-Wedge[a__]\) \[RuleDelayed] Wedge[a]]], 
        1]\)], "Input"],

Cell[BoxData[
    \({gv[u[1]]\[Wedge]gv[u[2]], gv[u[1]]\[Wedge]gv[v[1]], 
      gv[u[1]]\[Wedge]gv[v[2]], gv[u[2]]\[Wedge]gv[v[1]], 
      gv[u[2]]\[Wedge]gv[v[2]], gv[v[1]]\[Wedge]gv[v[2]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ord3prod = 
      Drop[Union[
          Flatten[Outer[Wedge, fourGVfields, 
                ord2prod] /. \(-Wedge[a__]\) \[RuleDelayed] Wedge[a]]], 
        1]\)], "Input"],

Cell[BoxData[
    \({gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
      gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
      gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
      gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox["AA",
    FontWeight->"Bold"],
  " and ",
  StyleBox["DD",
    FontWeight->"Bold"],
  ", defined below, are even (3x3) and (2x2) matrices having up to quadratic \
terms in Grassmann variables, while ",
  StyleBox["BB",
    FontWeight->"Bold"],
  " and ",
  StyleBox["CC",
    FontWeight->"Bold"],
  "  are odd (3x2) and (2x3) matrices having linear and cubic terms in \
Grassmann variables. They will be used later to construct the even \
Supermatrix SM={{A, B},{C, D}}."
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(AA = \(Array[a, {3, 3}] /. 
          a[i_, i_] \[RuleDelayed] \(aa[i]\)[x, y] + ord2prod[\([i]\)]\) /. 
        a[i_, j_] \[RuleDelayed] ord2prod[\([i + j]\)]\)], "Input"],

Cell[BoxData[
    \({{gv[u[1]]\[Wedge]gv[u[2]] + \(aa[1]\)[x, y], gv[u[1]]\[Wedge]gv[v[2]], 
        gv[u[2]]\[Wedge]gv[v[1]]}, {gv[u[1]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[1]] + \(aa[2]\)[x, y], 
        gv[u[2]]\[Wedge]gv[v[2]]}, {gv[u[2]]\[Wedge]gv[v[1]], 
        gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[2]] + \(aa[3]\)[x, y]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BB = 
      Array[b, {3, 2}] /. 
        b[i_, j_] \[RuleDelayed] 
          fourGVfields[\([6 - i - j]\)] + 
            ord3prod[\([i + j - 1]\)]\)], "Input"],

Cell[BoxData[
    \({{gv[v[2]] + gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
        gv[v[1]] + gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]]}, {gv[v[1]] + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]] + gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]]}, {gv[u[2]] + 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]] + gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CC = 
      Array[b, {2, 3}] /. 
        b[i_, j_] \[RuleDelayed] 
          fourGVfields[\([6 - i - j]\)] - 
            ord3prod[\([i + 3 - j]\)]\)], "Input"],

Cell[BoxData[
    \({{gv[v[2]] - gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[v[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]}, {gv[v[1]] - 
          gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[2]] - gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DD = \(Array[a, {2, 2}] /. 
          a[i_, i_] \[RuleDelayed] \(dd[i]\)[x, y] + 
              ord2prod[\([5 - 2  i]\)]\) /. 
        a[i_, j_] \[RuleDelayed] ord2prod[\([5 - i + j]\)]\)], "Input"],

Cell[BoxData[
    \({{gv[u[1]]\[Wedge]gv[v[2]] + \(dd[1]\)[x, y], 
        gv[v[1]]\[Wedge]gv[v[2]]}, {gv[u[2]]\[Wedge]gv[v[1]], 
        gv[u[1]]\[Wedge]gv[u[2]] + \(dd[2]\)[x, y]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ /@ {AA, BB, CC, DD}\)], "Input"],

Cell[BoxData[
    \({True, False, False, True}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
Supermatrix construction: SuperMatrix, EvenSuperMatrix, \
OddSuperMatrix\
\>", "Subsection",
  FontSize->16],

Cell[CellGroupData[{

Cell[TextData[{
  "\tThe function ",
  StyleBox["SuperMatrix[A_, B_, C_, D_]",
    FontFamily->"Courier"],
  " constructs the supermatrix with block form {{A, B},{C, D}}, provided that \
the given submatrices have compatible dimensions and Grassmann parities to \
give a homogeneous supermatrix."
}], "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SM", "=", \(SuperMatrix[AA, BB, CC, DD]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(even\ supermatrix\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({{gv[u[1]]\[Wedge]gv[u[2]] + \(aa[1]\)[x, y], gv[u[1]]\[Wedge]gv[v[2]], 
        gv[u[2]]\[Wedge]gv[v[1]], 
        gv[v[2]] + gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
        gv[v[1]] + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]]}, {gv[u[1]]\[Wedge]gv[
            v[2]], gv[u[1]]\[Wedge]gv[v[1]] + \(aa[2]\)[x, y], 
        gv[u[2]]\[Wedge]gv[v[2]], 
        gv[v[1]] + gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]] + 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]]}, {gv[u[2]]\[Wedge]gv[
            v[1]], gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[2]] + \(aa[3]\)[x, y], 
        gv[u[2]] + gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]] + gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]]}, {gv[v[2]] - 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[v[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
        gv[u[1]]\[Wedge]gv[v[2]] + \(dd[1]\)[x, y], 
        gv[v[1]]\[Wedge]gv[v[2]]}, {gv[v[1]] - 
          gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[2]] - gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]]\[Wedge]gv[v[1]], 
        gv[u[1]]\[Wedge]gv[u[2]] + \(dd[2]\)[x, y]}}\)], "Output"]
}, Open  ]],

Cell["\<\
\tIn most calculations we will use the simpler supermatrix \
SM0:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"SM0", "=", 
      RowBox[{"SM", 
        StyleBox["/.",
          FontColor->RGBColor[1, 0, 0]], 
        RowBox[{
          StyleBox[\(gv[v[2]]\),
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox["\[Rule]",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox["0",
            FontColor->RGBColor[1, 0, 0]], 
          RowBox[{"(*", " ", 
            StyleBox[\(even\ supermatrix\),
              FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]}]}]], "Input"],

Cell[BoxData[
    \({{gv[u[1]]\[Wedge]gv[u[2]] + \(aa[1]\)[x, y], 0, 
        gv[u[2]]\[Wedge]gv[v[1]], gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
        gv[v[1]]}, {0, gv[u[1]]\[Wedge]gv[v[1]] + \(aa[2]\)[x, y], 0, 
        gv[v[1]], gv[u[2]]}, {gv[u[2]]\[Wedge]gv[v[1]], 0, \(aa[3]\)[x, y], 
        gv[u[2]], gv[u[1]]}, {0, gv[v[1]], 
        gv[u[2]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], \(dd[1]\)[x, y], 
        0}, {gv[v[1]], gv[u[2]], gv[u[1]], gv[u[2]]\[Wedge]gv[v[1]], 
        gv[u[1]]\[Wedge]gv[u[2]] + \(dd[2]\)[x, y]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[SM0]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(gv[u[1]]\[Wedge]gv[u[2]] + \(aa[1]\)[x, y]\), 
              "0", \(gv[u[2]]\[Wedge]gv[v[1]]\), \(gv[u[1]]\[Wedge]gv[
                  u[2]]\[Wedge]gv[v[1]]\), \(gv[v[1]]\)},
            {"0", \(gv[u[1]]\[Wedge]gv[v[1]] + \(aa[2]\)[x, y]\), 
              "0", \(gv[v[1]]\), \(gv[u[2]]\)},
            {\(gv[u[2]]\[Wedge]gv[v[1]]\), 
              "0", \(\(aa[3]\)[x, y]\), \(gv[u[2]]\), \(gv[u[1]]\)},
            {
              "0", \(gv[v[1]]\), \(gv[u[2]] - 
                gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\), \(\(dd[1]\)[x, 
                y]\), "0"},
            {\(gv[v[1]]\), \(gv[u[2]]\), \(gv[
                u[1]]\), \(gv[u[2]]\[Wedge]gv[
                  v[1]]\), \(gv[u[1]]\[Wedge]gv[u[2]] + \(dd[2]\)[x, y]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MatrixForm[SM /. gv[__] \[Rule] 0]\)], "Input"],

Cell[BoxData[
    TagBox[
      RowBox[{"(", "\[NoBreak]", GridBox[{
            {\(\(aa[1]\)[x, y]\), "0", "0", "0", "0"},
            {"0", \(\(aa[2]\)[x, y]\), "0", "0", "0"},
            {"0", "0", \(\(aa[3]\)[x, y]\), "0", "0"},
            {"0", "0", "0", \(\(dd[1]\)[x, y]\), "0"},
            {"0", "0", "0", "0", \(\(dd[2]\)[x, y]\)}
            }], "\[NoBreak]", ")"}],
      (MatrixForm[ #]&)]], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(SuperMatrix[BB, AA, CC, DD]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(wrong\ dimensions\ and\ parities\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \("Incompatible dimensions or wrong Grassmann parities"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(SuperMatrix[AA, BB\[Wedge]gv[u[1]], CC, DD]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(wrong\ parities\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \("Incompatible dimensions or wrong Grassmann parities"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(SuperMatrix[AA, CC, BB, DD]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(wrong\ dimensions\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \("Incompatible dimensions or wrong Grassmann parities"\)], "Print"]
}, Open  ]],

Cell["\<\
\tMultiplying each submatrix by gv[u[1]] changes their \
parities:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(SM1 = 
        SuperMatrix[AA\[Wedge]gv[u[1]], BB\[Wedge]gv[u[1]], 
          CC\[Wedge]gv[u[1]], DD\[Wedge]gv[u[1]]]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(odd\ supermatrix\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({{gv[u[1]]\ \(aa[1]\)[x, y], 0, 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[
            v[1]], \(-\((gv[u[1]]\[Wedge]gv[v[2]])\)\), \(-\((gv[
                u[1]]\[Wedge]gv[v[1]])\)\)}, {0, gv[u[1]]\ \(aa[2]\)[x, y], 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[
            v[2]], \(-\((gv[u[1]]\[Wedge]gv[v[1]])\)\), \(-\((gv[
                u[1]]\[Wedge]gv[u[2]])\)\)}, {gv[u[1]]\[Wedge]gv[
            u[2]]\[Wedge]gv[v[1]], gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[1]]\ \(aa[3]\)[x, 
            y], \(-\((gv[u[1]]\[Wedge]gv[u[2]])\)\), \(-\((gv[u[1]]\[Wedge]gv[
                u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]])\)\)}, {\(-\((gv[
                u[1]]\[Wedge]gv[v[2]])\)\), \(-\((gv[u[1]]\[Wedge]gv[
                v[1]])\)\), \(-\((gv[u[1]]\[Wedge]gv[u[2]])\)\), 
        gv[u[1]]\ \(dd[1]\)[x, y], 
        gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[
            v[2]]}, {\(-\((gv[u[1]]\[Wedge]gv[v[1]])\)\) + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[
              v[2]], \(-\((gv[u[1]]\[Wedge]gv[u[2]])\)\), 0, 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
        gv[u[1]]\ \(dd[2]\)[x, y]}}\)], "Output"]
}, Open  ]],

Cell["\tA submatrix can be the zero matrix:", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"BB", 
      StyleBox["/.",
        FontColor->RGBColor[1, 0, 0]], 
      StyleBox[\(gv[__] \[Rule] 0\),
        FontColor->RGBColor[1, 0, 0]]}]], "Input"],

Cell[BoxData[
    \({{0, 0}, {0, 0}, {0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SuperMatrix[AA, %, CC, DD]\)], "Input"],

Cell[BoxData[
    \({{gv[u[1]]\[Wedge]gv[u[2]] + \(aa[1]\)[x, y], gv[u[1]]\[Wedge]gv[v[2]], 
        gv[u[2]]\[Wedge]gv[v[1]], 0, 0}, {gv[u[1]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[1]] + \(aa[2]\)[x, y], gv[u[2]]\[Wedge]gv[v[2]], 
        0, 0}, {gv[u[2]]\[Wedge]gv[v[1]], gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[2]] + \(aa[3]\)[x, y], 0, 
        0}, {gv[v[2]] - gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[v[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
        gv[u[1]]\[Wedge]gv[v[2]] + \(dd[1]\)[x, y], 
        gv[v[1]]\[Wedge]gv[v[2]]}, {gv[v[1]] - 
          gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[2]] - gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]]\[Wedge]gv[v[1]], 
        gv[u[1]]\[Wedge]gv[u[2]] + \(dd[2]\)[x, y]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(SuperMatrix[AA, BB, CC, DD\[Wedge]gv[u[1]]]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(wrong\ parities\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \("Incompatible dimensions or wrong Grassmann parities"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(SuperMatrix[DD, BB, CC, AA]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(wrong\ dimensions\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \("Incompatible dimensions or wrong Grassmann parities"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(SuperMatrix[DD, CC, BB, AA]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(this\ is\ a\ \((2 + 3)\) x \((2 + 3)\)\ supermatrix\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({{gv[u[1]]\[Wedge]gv[v[2]] + \(dd[1]\)[x, y], gv[v[1]]\[Wedge]gv[v[2]], 
        gv[v[2]] - gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[v[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]] - 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]}, {gv[u[2]]\[Wedge]gv[
            v[1]], gv[u[1]]\[Wedge]gv[u[2]] + \(dd[2]\)[x, y], 
        gv[v[1]] - gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[2]] - gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]]}, {gv[v[2]] + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
        gv[v[1]] + gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[u[2]] + \(aa[1]\)[x, y], gv[u[1]]\[Wedge]gv[v[2]], 
        gv[u[2]]\[Wedge]gv[v[1]]}, {gv[v[1]] + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]] + gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[2]], gv[u[1]]\[Wedge]gv[v[1]] + \(aa[2]\)[x, y], 
        gv[u[2]]\[Wedge]gv[v[2]]}, {gv[u[2]] + 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]] + gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[2]]\[Wedge]gv[v[1]], gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[2]] + \(aa[3]\)[x, y]}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[TextData[{
  "\tThe functions ",
  StyleBox["EvenSuperMatrix[p_, q_]",
    FontFamily->"Courier"],
  " and ",
  StyleBox["OddSuperMatrix[p_, q_]",
    FontFamily->"Courier"],
  "  construct generic  (p+q)x(p+q) homogeneous supermatrices."
}], "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"genericEven32", "=", 
      StyleBox[\(EvenSuperMatrix[3, \ 2]\),
        FontFamily->"Courier"]}]], "Input"],

Cell[BoxData[
    \({{a$[1, 1], a$[1, 2], a$[1, 3], gv[b$[1, 1]], gv[b$[1, 2]]}, {a$[2, 1], 
        a$[2, 2], a$[2, 3], gv[b$[2, 1]], gv[b$[2, 2]]}, {a$[3, 1], a$[3, 2], 
        a$[3, 3], gv[b$[3, 1]], gv[b$[3, 2]]}, {gv[c$[1, 1]], gv[c$[1, 2]], 
        gv[c$[1, 3]], d$[1, 1], d$[1, 2]}, {gv[c$[2, 1]], gv[c$[2, 2]], 
        gv[c$[2, 3]], d$[2, 1], d$[2, 2]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"genericOdd23", "=", 
      StyleBox[\(OddSuperMatrix[2, \ 3]\),
        FontFamily->"Courier"]}]], "Input"],

Cell[BoxData[
    \({{gv[a$[1, 1]], gv[a$[1, 2]], b$[1, 1], b$[1, 2], 
        b$[1, 3]}, {gv[a$[2, 1]], gv[a$[2, 2]], b$[2, 1], b$[2, 2], 
        b$[2, 3]}, {c$[1, 1], c$[1, 2], gv[d$[1, 1]], gv[d$[1, 2]], 
        gv[d$[1, 3]]}, {c$[2, 1], c$[2, 2], gv[d$[2, 1]], gv[d$[2, 2]], 
        gv[d$[2, 3]]}, {c$[3, 1], c$[3, 2], gv[d$[3, 1]], gv[d$[3, 2]], 
        gv[d$[3, 3]]}}\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["subMatTK, subMatDR", "Subsection",
  FontSize->16],

Cell[TextData[{
  "\tThe functions ",
  StyleBox["subMatTK[x_, rr_, cc_]",
    FontFamily->"Courier"],
  " and ",
  StyleBox["subMatDR[x_, rr_, cc_]",
    FontFamily->"Courier"],
  " return the sub-matrices that are obtained by Taking (TK) or Dropping (DR) \
the rows indicated by ",
  StyleBox["rr",
    FontFamily->"Courier"],
  " and the columns indicated by ",
  StyleBox["cc",
    FontFamily->"Courier"],
  " of the matrix ",
  StyleBox["x",
    FontFamily->"Courier"],
  ". ",
  StyleBox["rr",
    FontFamily->"Courier"],
  " and ",
  StyleBox["cc",
    FontFamily->"Courier"],
  " have the same form as in the corresponding ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " commands (Take, Drop): either a list of two integers ",
  StyleBox["{n1, n2}",
    FontFamily->"Courier"],
  " indicating the range ",
  StyleBox["{n1...n2}",
    FontFamily->"Courier"],
  " of rows (columns), or a single integer ",
  StyleBox["n",
    FontFamily->"Courier"],
  " which is interpreted as ",
  StyleBox["{1, n}",
    FontFamily->"Courier"],
  ". Examples:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(mat67 = Array[mm, {6, 7}]\)], "Input"],

Cell[BoxData[
    \({{mm[1, 1], mm[1, 2], mm[1, 3], mm[1, 4], mm[1, 5], mm[1, 6], 
        mm[1, 7]}, {mm[2, 1], mm[2, 2], mm[2, 3], mm[2, 4], mm[2, 5], 
        mm[2, 6], mm[2, 7]}, {mm[3, 1], mm[3, 2], mm[3, 3], mm[3, 4], 
        mm[3, 5], mm[3, 6], mm[3, 7]}, {mm[4, 1], mm[4, 2], mm[4, 3], 
        mm[4, 4], mm[4, 5], mm[4, 6], mm[4, 7]}, {mm[5, 1], mm[5, 2], 
        mm[5, 3], mm[5, 4], mm[5, 5], mm[5, 6], mm[5, 7]}, {mm[6, 1], 
        mm[6, 2], mm[6, 3], mm[6, 4], mm[6, 5], mm[6, 6], 
        mm[6, 7]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(subMatTK[mat67, {2, 4}, {6, 7}]\)], "Input"],

Cell[BoxData[
    \({{mm[2, 6], mm[2, 7]}, {mm[3, 6], mm[3, 7]}, {mm[4, 6], 
        mm[4, 7]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(subMatDR[mat67, {2, 4}, {6, 7}]\)], "Input"],

Cell[BoxData[
    \({{mm[1, 1], mm[1, 2], mm[1, 3], mm[1, 4], mm[1, 5]}, {mm[5, 1], 
        mm[5, 2], mm[5, 3], mm[5, 4], mm[5, 5]}, {mm[6, 1], mm[6, 2], 
        mm[6, 3], mm[6, 4], mm[6, 5]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(subMatTK[mat67, 3, {5, 6}]\)], "Input"],

Cell[BoxData[
    \({{mm[1, 5], mm[1, 6]}, {mm[2, 5], mm[2, 6]}, {mm[3, 5], 
        mm[3, 6]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(subMatDR[mat67, 3, {5, 6}]\)], "Input"],

Cell[BoxData[
    \({{mm[4, 1], mm[4, 2], mm[4, 3], mm[4, 4], mm[4, 7]}, {mm[5, 1], 
        mm[5, 2], mm[5, 3], mm[5, 4], mm[5, 7]}, {mm[6, 1], mm[6, 2], 
        mm[6, 3], mm[6, 4], mm[6, 7]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell["\<\
\tThe submatrices AA, BB, CC, DD of the supermatrix SM can be \
obtained using either subMatTK or subMatDR:\
\>", "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(AA === subMatTK[SM, 3, 3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AA === subMatDR[SM, {4, 5}, {4, 5}]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BB === subMatTK[SM, 3, {4, 5}]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BB === subMatDR[SM, {4, 5}, 3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CC === subMatDR[SM, 3, {4, 5}]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CC === subMatTK[SM, {4, 5}, 3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DD === subMatDR[SM, 3, 3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DD === subMatTK[SM, {4, 5}, {4, 5}]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["EvenGrassQ, GrassParity on supermatrices/vectors", "Subsection",
  FontSize->16],

Cell[TextData[{
  "\tIf the auxiliary functions EvenGrassQ, GrassParity defined in section 2 \
are used on a supermatrix, they will always give \"Mixed parity entries\", as \
a supermatrix has both even and odd elements. For supermatrices (or \
supervectors) they must be called with 2 extra arguments specifying the (p, \
q) dimensions of the supermatrix/vector.  ",
  StyleBox["EvenGrassQ[x_, p_, q_]",
    FontFamily->"Courier"],
  " now returns ",
  StyleBox["True",
    FontFamily->"Courier"],
  "  (",
  StyleBox["False",
    FontFamily->"Courier"],
  "), and ",
  StyleBox["GrassParity[x_, p_, q_]",
    FontFamily->"Courier"],
  " now returns 0 (1), if ",
  StyleBox["x",
    FontFamily->"Courier"],
  " is an even (odd) ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " supermatrix / supervector of the correct (p, q)-structure; otherwise it \
prints a \"mixed parity entries\" warning. "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[TextData[{
  "\tZero elements in sublists are ignored, allowing odd sectors to contain \
zero elements (or be absent), but if ",
  StyleBox["all",
    FontSlant->"Italic"],
  " elements in ",
  StyleBox["x",
    FontFamily->"Courier"],
  " are zero then EvenGrassQ  prints \"Test fails on zero arguments\".\n\t\
There is no separate test for odd supermatrices/supervectors: under the \
assumptions stated above if ",
  StyleBox["EvenGrassQ[x, p, q]",
    FontFamily->"Courier"],
  " returns ",
  StyleBox["False",
    FontFamily->"Courier"],
  ", then ",
  StyleBox["x",
    FontFamily->"Courier"],
  " is odd. Examples:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(EvenGrassQ[SM0, 3, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(even\ supermatrix\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(EvenGrassQ[SM1, 3, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(odd\ supermatrix\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(EvenGrassQ[SM0 + SM1, 3, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(mixed\ supermatrix\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(EvenGrassQ[SM0]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(extra\ arguments\ missing\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \("Mixed parity entries."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(EvenGrassQ[SM0, 2, 3]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(wrong\ extra\ arguments\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(EvenGrassQ[{1, 2, 3, gv[2]}, 3, 1]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(even\ supervector\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(EvenGrassQ[{1, 2, 3, gv[2]}, 2, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(wrong\ extra\ arguments\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(EvenGrassQ[{gv[1], 0, 0, 1}, 3, 1]\), 
      RowBox[{"(*", " ", 
        RowBox[{
          StyleBox[\(odd\ supervector\),
            FontColor->RGBColor[0, 0, 1]], " ", "-", " ", 
          StyleBox[\(zero\ entries\ in\ odd\ sector\ are\ ignored\),
            FontColor->RGBColor[0, 0, 1]]}], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(EvenGrassQ[{0, 0, 0, 0}, 3, 1]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(zero\ supervector\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \("Test fails on zero arguments."\)], "Print"]
}, Open  ]],

Cell["\<\
\tThe behavior of GrassParity is exactly the same, returning 0 (1) \
whenever EvenGrassQ  returns True (False).\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(GrassParity[SM0, 3, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(even\ supermatrix\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(GrassParity[SM1, 3, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(odd\ supermatrix\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(GrassParity[{gv[1], 0, 0, 1}, 3, 1]\), 
      RowBox[{"(*", " ", 
        RowBox[{
          StyleBox[\(odd\ supervector\),
            FontColor->RGBColor[0, 0, 1]], " ", "-", " ", 
          StyleBox[\(zero\ entries\ in\ odd\ sector\ are\ ignored\),
            FontColor->RGBColor[0, 0, 1]]}], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \(1\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(GrassParity[{0, 0, 0, 0}, 3, 1]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(zero\ supervector\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \("Test fails on zero arguments."\)], "Print"]
}, Open  ]],

Cell[TextData[{
  StyleBox["Note:",
    FontSlant->"Italic"],
  " These auxiliary functions are used by the \"superFunctions\" defined in \
the section 5 to test the parity of their arguments, as the \
\"superFunctions\" act differently on even / odd matrices. If the arguments \
are not what the function expects, different messages, generated by \
EvenGrassQ, are printed. superEDC versions<1.3.. did not handle zero entries \
in odd submatrices correctly, causing incorrect messages to be printed."
}], "Text",
  Evaluatable->False,
  FontSize->16]
}, Closed]],

Cell[CellGroupData[{

Cell["wedgePower, wedgeD, wedgeMatrixExp on supermatrices", "Subsection",
  FontSize->16],

Cell["\<\
\tThese functions can be used on supermatrices also. \
Examples:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgePower[SM0, 3]\)], "Input"],

Cell[BoxData[
    \({{3\ gv[u[1]]\[Wedge]gv[u[2]]\ \(aa[1]\)[x, y]\^2 + \(aa[1]\)[x, y]\^3, 
        gv[u[2]]\[Wedge]gv[
              v[1]]\ \((\(-\(aa[1]\)[x, y]\) - \(aa[2]\)[x, y] - \(dd[2]\)[x, 
                y])\), gv[u[2]]\[Wedge]gv[
                v[1]]\ \((\(aa[1]\)[x, y]\^2 + \(aa[1]\)[x, y]\ \(aa[3]\)[x, 
                    y] + \(aa[3]\)[x, y]\^2)\) + 
          gv[u[1]]\[Wedge]gv[
                v[1]]\ \((\(-\(aa[1]\)[x, y]\) - \(aa[3]\)[x, y] - \(dd[2]\)[
                  x, y])\), 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[
              v[1]]\ \((1 + \(aa[1]\)[x, y]\^2 + \(aa[1]\)[x, y]\ \(dd[1]\)[
                  x, y] + \(dd[1]\)[x, y]\^2)\), 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[
                v[1]]\ \((4\ \(aa[1]\)[x, y] + \(aa[3]\)[x, y] + 
                4\ \(dd[2]\)[x, y])\) + 
          gv[v[1]]\ \((\(aa[1]\)[x, y]\^2 + \(aa[1]\)[x, y]\ \(dd[2]\)[x, 
                    y] + \(dd[2]\)[x, y]\^2)\)}, {gv[u[2]]\[Wedge]gv[
              v[1]]\ \((\(aa[1]\)[x, y] + \(aa[2]\)[x, y] + \(dd[2]\)[x, 
                y])\), 3\ gv[u[1]]\[Wedge]gv[
                v[1]]\ \(aa[2]\)[x, y]\^2 + \(aa[2]\)[x, y]\^3, 
        gv[u[2]]\[Wedge]gv[
                v[1]]\ \((\(-\(aa[2]\)[x, y]\) - \(aa[3]\)[x, y] - \(dd[1]\)[
                  x, y])\) + 
          gv[u[1]]\[Wedge]gv[
                u[2]]\ \((\(-\(aa[2]\)[x, y]\) - \(aa[3]\)[x, y] - \(dd[2]\)[
                  x, y])\), 
        gv[v[1]]\ \((\(aa[2]\)[x, y]\^2 + \(aa[2]\)[x, y]\ \(dd[1]\)[x, 
                  y] + \(dd[1]\)[x, y]\^2)\), 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \((\(-1\) - 
                2\ \(aa[2]\)[x, y] - \(dd[2]\)[x, y])\) + 
          gv[u[2]]\ \((\(aa[2]\)[x, y]\^2 + \(aa[2]\)[x, y]\ \(dd[2]\)[x, 
                    y] + \(dd[2]\)[x, y]\^2)\)}, {gv[u[2]]\[Wedge]gv[
                v[1]]\ \((\(aa[1]\)[x, y]\^2 + \(aa[1]\)[x, y]\ \(aa[3]\)[x, 
                    y] + \(aa[3]\)[x, y]\^2)\) + 
          gv[u[1]]\[Wedge]gv[
                v[1]]\ \((\(aa[1]\)[x, y] + \(aa[3]\)[x, y] + \(dd[2]\)[x, 
                  y])\), gv[u[2]]\[Wedge]gv[
                v[1]]\ \((\(aa[2]\)[x, y] + \(aa[3]\)[x, y] + \(dd[1]\)[x, 
                  y])\) + 
          gv[u[1]]\[Wedge]gv[
                u[2]]\ \((\(aa[2]\)[x, y] + \(aa[3]\)[x, y] + \(dd[2]\)[x, 
                  y])\), \(aa[3]\)[x, y]\^3, 
        gv[u[2]]\ \((\(aa[3]\)[x, y]\^2 + \(aa[3]\)[x, y]\ \(dd[1]\)[x, 
                    y] + \(dd[1]\)[x, y]\^2)\) + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[
                v[1]]\ \((1 + \(aa[3]\)[x, y] + \(dd[1]\)[x, y] + \(dd[2]\)[
                  x, y])\), 
        gv[u[1]]\ \((\(aa[3]\)[x, y]\^2 + \(aa[3]\)[x, y]\ \(dd[2]\)[x, 
                  y] + \(dd[2]\)[x, y]\^2)\)}, {\(-\((gv[u[1]]\[Wedge]gv[
                u[2]]\[Wedge]gv[v[1]])\)\), 
        gv[v[1]]\ \((\(aa[2]\)[x, y]\^2 + \(aa[2]\)[x, y]\ \(dd[1]\)[x, 
                  y] + \(dd[1]\)[x, y]\^2)\), 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[
                v[1]]\ \((\(-1\) - \(aa[3]\)[x, y]\^2 - \(aa[3]\)[x, 
                    y]\ \(dd[1]\)[x, y] - \(dd[1]\)[x, y]\^2)\) + 
          gv[u[2]]\ \((\(aa[3]\)[x, y]\^2 + \(aa[3]\)[x, y]\ \(dd[1]\)[x, 
                    y] + \(dd[1]\)[x, y]\^2)\), \(dd[1]\)[x, y]\^3, 
        gv[u[2]]\[Wedge]gv[
                v[1]]\ \((\(-\(aa[2]\)[x, y]\) - \(dd[1]\)[x, y] - \(dd[2]\)[
                  x, y])\) + 
          gv[u[1]]\[Wedge]gv[
                u[2]]\ \((\(-\(aa[3]\)[x, y]\) - \(dd[1]\)[x, y] - \(dd[2]\)[
                  x, y])\)}, {gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[
                v[1]]\ \((4\ \(aa[1]\)[x, y] + \(aa[3]\)[x, y] + 
                4\ \(dd[2]\)[x, y])\) + 
          gv[v[1]]\ \((\(aa[1]\)[x, y]\^2 + \(aa[1]\)[x, y]\ \(dd[2]\)[x, 
                    y] + \(dd[2]\)[x, y]\^2)\), 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \((1 - 
                2\ \(aa[2]\)[x, y] - \(dd[2]\)[x, y])\) + 
          gv[u[2]]\ \((\(aa[2]\)[x, y]\^2 + \(aa[2]\)[x, y]\ \(dd[2]\)[x, 
                    y] + \(dd[2]\)[x, y]\^2)\), 
        gv[u[1]]\ \((\(aa[3]\)[x, y]\^2 + \(aa[3]\)[x, y]\ \(dd[2]\)[x, 
                  y] + \(dd[2]\)[x, y]\^2)\), 
        gv[u[1]]\[Wedge]gv[
                u[2]]\ \((\(aa[3]\)[x, y] + \(dd[1]\)[x, y] + \(dd[2]\)[x, 
                  y])\) + 
          gv[u[2]]\[Wedge]gv[
                v[1]]\ \((\(aa[2]\)[x, y] + \(dd[1]\)[x, 
                  y] + \(dd[1]\)[x, y]\^2 + \(dd[2]\)[x, 
                  y] + \(dd[1]\)[x, y]\ \(dd[2]\)[x, 
                    y] + \(dd[2]\)[x, y]\^2)\), 
        3\ gv[u[1]]\[Wedge]gv[
                u[2]]\ \(dd[2]\)[x, y]\^2 + \(dd[2]\)[x, y]\^3}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeD[%, \(aa[3]\)[x, y], gv[u[2]]]\)], "Input"],

Cell[BoxData[
    \({{0, 0, gv[v[1]]\ \(aa[1]\)[x, y] + 2\ gv[v[1]]\ \(aa[3]\)[x, y], 
        0, \(-\((gv[u[1]]\[Wedge]gv[v[1]])\)\)}, {0, 0, gv[u[1]] - gv[v[1]], 
        0, 0}, {gv[v[1]]\ \(aa[1]\)[x, y] + 
          2\ gv[v[1]]\ \(aa[3]\)[x, y], \(-gv[u[1]]\) + gv[v[1]], 
        0, \(-\((gv[u[1]]\[Wedge]gv[v[1]])\)\) + 
          2\ \(aa[3]\)[x, y] + \(dd[1]\)[x, y], 0}, {0, 0, 
        2\ \(aa[3]\)[x, y] + 
          2\ gv[u[1]]\[Wedge]gv[v[1]]\ \(aa[3]\)[x, y] + \(dd[1]\)[x, y] + 
          gv[u[1]]\[Wedge]gv[v[1]]\ \(dd[1]\)[x, y], 0, 
        gv[u[1]]}, {\(-\((gv[u[1]]\[Wedge]gv[v[1]])\)\), 0, 0, \(-gv[u[1]]\), 
        0}}\)], "Output"]
}, Open  ]],

Cell["This is an odd (3, 2) supermatrix", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[%, 3, 2]\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell["\<\
But exponentiating this homogeneous supermatrix gives a mixed \
matrix:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(wedgeMatrixExp[soul[%%]]\)], "Input"],

Cell[BoxData[
    \({{1, 
        1\/2\ gv[u[1]]\[Wedge]gv[v[1]]\ \((\(aa[1]\)[x, y] + 
              2\ \(aa[3]\)[x, y])\), 
        gv[v[1]]\ \((\(aa[1]\)[x, y] + 2\ \(aa[3]\)[x, y])\), 
        0, \(-\((gv[u[1]]\[Wedge]gv[v[1]])\)\)}, {1\/2\ gv[u[1]]\[Wedge]gv[
              v[1]]\ \((\(aa[1]\)[x, y] + 2\ \(aa[3]\)[x, y])\), 1, 
        gv[u[1]] - gv[v[1]], 0, 
        0}, {gv[v[1]]\ \((\(aa[1]\)[x, y] + 2\ \(aa[3]\)[x, y])\), \(-gv[
              u[1]]\) + gv[v[1]], 1, \(-\((gv[u[1]]\[Wedge]gv[v[1]])\)\), 
        0}, {0, 0, 
        gv[u[1]]\[Wedge]gv[v[1]]\ \((2\ \(aa[3]\)[x, y] + \(dd[1]\)[x, y])\), 
        1, gv[u[1]]}, {\(-\((gv[u[1]]\[Wedge]gv[v[1]])\)\), 0, 
        0, \(-gv[u[1]]\), 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[%, 3, 2]\)], "Input"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell["", "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[{
  "5. ",
  StyleBox["superFunctions:",
    FontSlant->"Italic"],
  " superWedge, superTrace, superTranspose, parityTranspose, superInverse, \
Berezinian"
}], "Section",
  Evaluatable->False,
  FontSize->18],

Cell[TextData[{
  "\tThese are special functions that act on ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " supermatrices (supervectors). They all take two additional integers as \
arguments: the dimensions ",
  StyleBox["p",
    FontFamily->"Courier"],
  " and ",
  StyleBox["q",
    FontFamily->"Courier"],
  " of the supermatrix. These functions first test if the elements of the \
given input matrix (or matrices) have the correct parities to form a \
homogeneous (p, q) supermatrix. Wrong inputs can cause a variety of messages \
to be printed, generated by EvenGrassQ (see sections 2 and 4 above). The \
definitions implemented agree with those in",
  " the ",
  ButtonBox["wiki/Supermatrix",
    ButtonData:>{
      URL[ "http://en.wikipedia.org/wiki/Supermatrix"], None},
    ButtonStyle->"Hyperlink"],
  " article."
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell["superWedge", "Subsection",
  FontSize->16],

Cell["\<\
\tLike Wedge, superWedge generalizes both Times and Dot for \
supermatrices / supervectors. Although superWedge and Wedge on supermatrices \
/ supervectors of compatible (p, q)-structures give identical results, \
superWedge must be used for odd scalar multiplication, as it acts differently \
from left and right on even / odd supermatrices.\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell["\t Odd scalar multiplication of an even supermatrix: ", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superWedge[gv[1], EvenSuperMatrix[3, 2], 3, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(odd\ scalar\ from\ left\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({{a$[1, 1]\ gv[1], a$[1, 2]\ gv[1], a$[1, 3]\ gv[1], 
        gv[1]\[Wedge]gv[b$[1, 1]], 
        gv[1]\[Wedge]gv[b$[1, 2]]}, {a$[2, 1]\ gv[1], a$[2, 2]\ gv[1], 
        a$[2, 3]\ gv[1], gv[1]\[Wedge]gv[b$[2, 1]], 
        gv[1]\[Wedge]gv[b$[2, 2]]}, {a$[3, 1]\ gv[1], a$[3, 2]\ gv[1], 
        a$[3, 3]\ gv[1], gv[1]\[Wedge]gv[b$[3, 1]], 
        gv[1]\[Wedge]gv[
            b$[3, 2]]}, {\(-\((gv[1]\[Wedge]gv[c$[1, 1]])\)\), \(-\((gv[
                1]\[Wedge]gv[c$[1, 2]])\)\), \(-\((gv[1]\[Wedge]gv[
                c$[1, 3]])\)\), \(-d$[1, 1]\)\ gv[1], \(-d$[1, 2]\)\ gv[
            1]}, {\(-\((gv[1]\[Wedge]gv[c$[2, 1]])\)\), \(-\((gv[1]\[Wedge]gv[
                c$[2, 2]])\)\), \(-\((gv[1]\[Wedge]gv[c$[2, 3]])\)\), \(-d$[
              2, 1]\)\ gv[1], \(-d$[2, 2]\)\ gv[1]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superWedge[EvenSuperMatrix[3, 2], gv[1], 3, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(odd\ scalar\ from\ right\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({{a$[1, 1]\ gv[1], a$[1, 2]\ gv[1], a$[1, 3]\ gv[1], 
        gv[1]\[Wedge]gv[b$[1, 1]], 
        gv[1]\[Wedge]gv[b$[1, 2]]}, {a$[2, 1]\ gv[1], a$[2, 2]\ gv[1], 
        a$[2, 3]\ gv[1], gv[1]\[Wedge]gv[b$[2, 1]], 
        gv[1]\[Wedge]gv[b$[2, 2]]}, {a$[3, 1]\ gv[1], a$[3, 2]\ gv[1], 
        a$[3, 3]\ gv[1], gv[1]\[Wedge]gv[b$[3, 1]], 
        gv[1]\[Wedge]gv[
            b$[3, 2]]}, {\(-\((gv[1]\[Wedge]gv[c$[1, 1]])\)\), \(-\((gv[
                1]\[Wedge]gv[c$[1, 2]])\)\), \(-\((gv[1]\[Wedge]gv[
                c$[1, 3]])\)\), \(-d$[1, 1]\)\ gv[1], \(-d$[1, 2]\)\ gv[
            1]}, {\(-\((gv[1]\[Wedge]gv[c$[2, 1]])\)\), \(-\((gv[1]\[Wedge]gv[
                c$[2, 2]])\)\), \(-\((gv[1]\[Wedge]gv[c$[2, 3]])\)\), \(-d$[
              2, 1]\)\ gv[1], \(-d$[2, 2]\)\ gv[1]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(%% - %\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 
        0}, {0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell["\t Odd scalar multiplication of an odd supermatrix: ", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superWedge[gv[1], OddSuperMatrix[3, 2], 3, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(odd\ scalar\ from\ left\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({{gv[1]\[Wedge]gv[a$[1, 1]], gv[1]\[Wedge]gv[a$[1, 2]], 
        gv[1]\[Wedge]gv[a$[1, 3]], b$[1, 1]\ gv[1], 
        b$[1, 2]\ gv[1]}, {gv[1]\[Wedge]gv[a$[2, 1]], 
        gv[1]\[Wedge]gv[a$[2, 2]], gv[1]\[Wedge]gv[a$[2, 3]], 
        b$[2, 1]\ gv[1], b$[2, 2]\ gv[1]}, {gv[1]\[Wedge]gv[a$[3, 1]], 
        gv[1]\[Wedge]gv[a$[3, 2]], gv[1]\[Wedge]gv[a$[3, 3]], 
        b$[3, 1]\ gv[1], 
        b$[3, 2]\ gv[1]}, {\(-c$[1, 1]\)\ gv[1], \(-c$[1, 2]\)\ gv[
            1], \(-c$[1, 3]\)\ gv[
            1], \(-\((gv[1]\[Wedge]gv[d$[1, 1]])\)\), \(-\((gv[1]\[Wedge]gv[
                d$[1, 2]])\)\)}, {\(-c$[2, 1]\)\ gv[1], \(-c$[2, 2]\)\ gv[
            1], \(-c$[2, 3]\)\ gv[
            1], \(-\((gv[1]\[Wedge]gv[d$[2, 1]])\)\), \(-\((gv[1]\[Wedge]gv[
                d$[2, 2]])\)\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superWedge[OddSuperMatrix[3, 2], gv[1], 3, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(odd\ scalar\ from\ right\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({{\(-\((gv[1]\[Wedge]gv[a$[1, 1]])\)\), \(-\((gv[1]\[Wedge]gv[
                a$[1, 2]])\)\), \(-\((gv[1]\[Wedge]gv[a$[1, 3]])\)\), \(-b$[
              1, 1]\)\ gv[1], \(-b$[1, 2]\)\ gv[
            1]}, {\(-\((gv[1]\[Wedge]gv[a$[2, 1]])\)\), \(-\((gv[1]\[Wedge]gv[
                a$[2, 2]])\)\), \(-\((gv[1]\[Wedge]gv[a$[2, 3]])\)\), \(-b$[
              2, 1]\)\ gv[1], \(-b$[2, 2]\)\ gv[
            1]}, {\(-\((gv[1]\[Wedge]gv[a$[3, 1]])\)\), \(-\((gv[1]\[Wedge]gv[
                a$[3, 2]])\)\), \(-\((gv[1]\[Wedge]gv[a$[3, 3]])\)\), \(-b$[
              3, 1]\)\ gv[1], \(-b$[3, 2]\)\ gv[1]}, {c$[1, 1]\ gv[1], 
        c$[1, 2]\ gv[1], c$[1, 3]\ gv[1], gv[1]\[Wedge]gv[d$[1, 1]], 
        gv[1]\[Wedge]gv[d$[1, 2]]}, {c$[2, 1]\ gv[1], c$[2, 2]\ gv[1], 
        c$[2, 3]\ gv[1], gv[1]\[Wedge]gv[d$[2, 1]], 
        gv[1]\[Wedge]gv[d$[2, 2]]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(%% + %\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 
        0}, {0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t As all supermatrices in this section have the same dimensions (p, \
q)=(3, 2), to simplify the expressions we can use ",
  StyleBox["sW[x_, y_]",
    FontFamily->"Courier"],
  ", which we define as: "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    \(sW[x_, y_] := superWedge[x, y, 3, 2]\)], "Input",
  FontColor->RGBColor[0, 0, 1]],

Cell[TextData[{
  "\tScalar multiplication using superWedge is \"supercommutative\": \
x\[Wedge]y = (-1)^(GP[x]*GP[y])y\[Wedge]x ",
  StyleBox["(or, for non-zero differential FormDegree (FD) variables, x\
\[Wedge]y = (-1)^(GP[x]*GP[y]+FD[x]*FD[y])y\[Wedge]x)",
    FontColor->GrayLevel[0.500008]],
  ", where x is a scalar, y a supermatrix and GP[x_] is the Grassmann parity \
of x. "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(sW[gv[w[1]], SM0] - sW[SM0, gv[w[1]]]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 
        0}, {0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sW[gv[w[1]], SM1] + sW[SM1, gv[w[1]]]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 
        0}, {0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell["\<\
\tsuperWedge multiplies only 2 quantities at a time; for higher \
products it must be used repeatedly. The following equalities test that SM1\
\[Wedge](gv[w[1]]\[Wedge]SM2)=(SM1\[Wedge]gv[w[1]])\[Wedge]SM2, for SM1, SM2  \
even or odd. \
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(sW[SM0, sW[gv[w[1]], SM0]] === sW[sW[SM0, gv[w[1]]], SM0]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sW[SM0, sW[gv[w[1]], SM1]] === sW[sW[SM0, gv[w[1]]], SM1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(sW[SM1, sW[gv[w[1]], SM1]] === sW[sW[SM1, gv[w[1]]], SM1]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\tBetween 2 supermatrices, superWedge acts like Dot:", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(sW[SM0, SM0]\)], "Input"],

Cell[BoxData[
    \({{2\ gv[u[1]]\[Wedge]gv[u[2]]\ \(aa[1]\)[x, 
              y] + \(aa[1]\)[x, y]\^2, \(-\((gv[u[2]]\[Wedge]gv[
                v[1]])\)\), \(-\((gv[u[1]]\[Wedge]gv[v[1]])\)\) + 
          gv[u[2]]\[Wedge]gv[v[1]]\ \(aa[1]\)[x, y] + 
          gv[u[2]]\[Wedge]gv[v[1]]\ \(aa[3]\)[x, y], 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \(aa[1]\)[x, y] + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \(dd[1]\)[x, y], 
        3\ gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]] + 
          gv[v[1]]\ \(aa[1]\)[x, y] + 
          gv[v[1]]\ \(dd[2]\)[x, y]}, {gv[u[2]]\[Wedge]gv[v[1]], 
        2\ gv[u[1]]\[Wedge]gv[v[1]]\ \(aa[2]\)[x, 
              y] + \(aa[2]\)[x, y]\^2, \(-\((gv[u[1]]\[Wedge]gv[u[2]])\)\) - 
          gv[u[2]]\[Wedge]gv[v[1]], 
        gv[v[1]]\ \(aa[2]\)[x, y] + 
          gv[v[1]]\ \(dd[1]\)[x, 
              y], \(-\((gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]])\)\) + 
          gv[u[2]]\ \(aa[2]\)[x, y] + 
          gv[u[2]]\ \(dd[2]\)[x, y]}, {gv[u[1]]\[Wedge]gv[v[1]] + 
          gv[u[2]]\[Wedge]gv[v[1]]\ \(aa[1]\)[x, y] + 
          gv[u[2]]\[Wedge]gv[v[1]]\ \(aa[3]\)[x, y], 
        gv[u[1]]\[Wedge]gv[u[2]] + 
          gv[u[2]]\[Wedge]gv[v[1]], \(aa[3]\)[x, y]\^2, 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]] + 
          gv[u[2]]\ \(aa[3]\)[x, y] + gv[u[2]]\ \(dd[1]\)[x, y], 
        gv[u[1]]\ \(aa[3]\)[x, y] + gv[u[1]]\ \(dd[2]\)[x, y]}, {0, 
        gv[v[1]]\ \(aa[2]\)[x, y] + gv[v[1]]\ \(dd[1]\)[x, y], 
        gv[u[2]]\ \(aa[3]\)[x, y] - 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \(aa[3]\)[x, y] + 
          gv[u[2]]\ \(dd[1]\)[x, y] - 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \(dd[1]\)[x, 
              y], \(dd[1]\)[x, y]\^2, \(-\((gv[u[1]]\[Wedge]gv[u[2]])\)\) - 
          gv[u[2]]\[Wedge]gv[
              v[1]]}, {3\ gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]] + 
          gv[v[1]]\ \(aa[1]\)[x, y] + 
          gv[v[1]]\ \(dd[2]\)[x, 
              y], \(-\((gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]])\)\) + 
          gv[u[2]]\ \(aa[2]\)[x, y] + gv[u[2]]\ \(dd[2]\)[x, y], 
        gv[u[1]]\ \(aa[3]\)[x, y] + gv[u[1]]\ \(dd[2]\)[x, y], 
        gv[u[1]]\[Wedge]gv[u[2]] + gv[u[2]]\[Wedge]gv[v[1]] + 
          gv[u[2]]\[Wedge]gv[v[1]]\ \(dd[1]\)[x, y] + 
          gv[u[2]]\[Wedge]gv[v[1]]\ \(dd[2]\)[x, y], 
        2\ gv[u[1]]\[Wedge]gv[u[2]]\ \(dd[2]\)[x, 
              y] + \(dd[2]\)[x, y]\^2}}\)], "Output"]
}, Open  ]],

Cell["\tThe same result is obtained using Wedge:", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(% === Wedge[SM0, SM0]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
\tUnlike Wedge, however, superWedge also tests for matrix dimension \
compatibility:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    RowBox[{\(SM23 = SuperMatrix[DD, CC, BB, AA];\), 
      RowBox[{"(*", 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\(a\ \((2, \ 3)\)\ supermatrix\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superWedge[SM0, SM23, 3, 2]\), 
      RowBox[{"(*", 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\(superWedge\ does\ not\ allow\ this\ product\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \("Incompatible (p, q) dimensions or not a homogeneous supermatrix"\)], \
"Print"]
}, Open  ]],

Cell[BoxData[
    RowBox[{\(wrongProduct = Wedge[SM0, SM23];\), 
      RowBox[{"(*", 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\(Wedge\ allows\ different\ \((p, \ 
              q)\)\ dimension\ supermatrix\ products\),
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[CellGroupData[{

Cell["\<\
  The following lines test if the rows of wrongProduct are even / \
odd vectors:\
\>", "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->14],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(EvenGrassQ[#, 3, 2] &\) /@ wrongProduct\)], "Input"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"],

Cell[BoxData[
    \({Null, Null, Null, Null, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(EvenGrassQ[#, 2, 3] &\) /@ wrongProduct\)], "Input"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"],

Cell[BoxData[
    \({Null, True, Null, Null, Null}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ /@ wrongProduct[\([2]\)]\)], "Input"],

Cell[BoxData[
    \({True, True, False, False, False}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell["\<\
\tsuperWedge between a 1-dimensional List and a (p, q) supermatrix \
is defined only if the 1-dimensional List consists of p even (odd) followed \
by q odd (even) elements (supervector):\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(super32Vector = 
      Join[\(\(f[#]\)[x, y] &\) /@ {1, 2, 3}, 
        Take[fourGVfields, 2]]\)], "Input"],

Cell[BoxData[
    \({\(f[1]\)[x, y], \(f[2]\)[x, y], \(f[3]\)[x, y], gv[u[1]], 
      gv[u[2]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superWedge[SM0, super32Vector, 3, 2]\)], "Input"],

Cell[BoxData[
    \({\(-\((gv[u[2]]\[Wedge]gv[v[1]])\)\) + 
        gv[u[1]]\[Wedge]gv[u[2]]\ \(f[1]\)[x, y] + \(aa[1]\)[x, y]\ \(f[1]\)[
            x, y] + gv[u[2]]\[Wedge]gv[v[1]]\ \(f[3]\)[x, 
            y], \(-\((gv[u[1]]\[Wedge]gv[v[1]])\)\) + 
        gv[u[1]]\[Wedge]gv[v[1]]\ \(f[2]\)[x, y] + \(aa[2]\)[x, y]\ \(f[2]\)[
            x, y], gv[u[2]]\[Wedge]gv[v[1]]\ \(f[1]\)[x, y] + \(aa[3]\)[x, 
            y]\ \(f[3]\)[x, y], 
      gv[u[1]]\ \(dd[1]\)[x, y] + gv[v[1]]\ \(f[2]\)[x, y] + 
        gv[u[2]]\ \(f[3]\)[x, y] - 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \(f[3]\)[x, y], 
      gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]] + gv[u[2]]\ \(dd[2]\)[x, y] + 
        gv[v[1]]\ \(f[1]\)[x, y] + gv[u[2]]\ \(f[2]\)[x, y] + 
        gv[u[1]]\ \(f[3]\)[x, y]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superWedge[super32Vector, SM0, 3, 2]\)], "Input"],

Cell[BoxData[
    \({gv[u[2]]\[Wedge]gv[v[1]] + 
        gv[u[1]]\[Wedge]gv[u[2]]\ \(f[1]\)[x, y] + \(aa[1]\)[x, y]\ \(f[1]\)[
            x, y] + gv[u[2]]\[Wedge]gv[v[1]]\ \(f[3]\)[x, y], 
      gv[u[1]]\[Wedge]gv[v[1]] + 
        gv[u[1]]\[Wedge]gv[v[1]]\ \(f[2]\)[x, y] + \(aa[2]\)[x, y]\ \(f[2]\)[
            x, y], gv[u[2]]\[Wedge]gv[v[1]]\ \(f[1]\)[x, y] + \(aa[3]\)[x, 
            y]\ \(f[3]\)[x, y], 
      gv[u[1]]\ \(dd[1]\)[x, y] + 
        gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \(f[1]\)[x, y] + 
        gv[v[1]]\ \(f[2]\)[x, y] + gv[u[2]]\ \(f[3]\)[x, y], 
      gv[u[2]]\ \(dd[2]\)[x, y] + gv[v[1]]\ \(f[1]\)[x, y] + 
        gv[u[2]]\ \(f[2]\)[x, y] + gv[u[1]]\ \(f[3]\)[x, y]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superWedge[SM0, RotateLeft[super32Vector, 1], 3, 2]\)], "Input"],

Cell[BoxData[
    \("Incompatible (p, q) dimensions or not a homogeneous supermatrix"\)], \
"Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["superTrace", "Subsection",
  FontSize->16],

Cell[TextData[{
  StyleBox["\tsuperTrace[x_, p_, q_]",
    FontFamily->"Courier"],
  " acts on a ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " (p, q)-dimensional supermatrix ",
  StyleBox["x",
    FontFamily->"Courier"],
  ":"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTrace[SM, 3, 2]\)], "Input"],

Cell[BoxData[
    \(gv[u[1]]\[Wedge]gv[v[1]] + \(aa[1]\)[x, y] + \(aa[2]\)[x, 
        y] + \(aa[3]\)[x, y] - \(dd[1]\)[x, y] - \(dd[2]\)[x, y]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[AA[\([i, i]\)], {i, 3}]\)], "Input"],

Cell[BoxData[
    \(gv[u[1]]\[Wedge]gv[u[2]] + gv[u[1]]\[Wedge]gv[v[1]] + 
      gv[u[1]]\[Wedge]gv[v[2]] + \(aa[1]\)[x, y] + \(aa[2]\)[x, 
        y] + \(aa[3]\)[x, y]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sum[DD[\([i, i]\)], {i, 2}]\)], "Input"],

Cell[BoxData[
    \(gv[u[1]]\[Wedge]gv[u[2]] + 
      gv[u[1]]\[Wedge]gv[v[2]] + \(dd[1]\)[x, y] + \(dd[2]\)[x, 
        y]\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(%% - % - superTrace[SM, 3, 2]\)], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTrace[SM, 2, 3]\)], "Input"],

Cell[BoxData[
    \("Incompatible (p, q) dimensions or not a homogeneous supermatrix"\)], \
"Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["superTranspose", "Subsection",
  FontSize->16],

Cell[TextData[{
  "\t",
  StyleBox["superTranspose[x_, p_, q_]",
    FontFamily->"Courier"],
  " acts on a ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " (p, q)-dimensional supermatrix ",
  StyleBox["x",
    FontFamily->"Courier"],
  " and gives another homogeneous (p, q)-dimensional supermatrix:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(SMt[1] = superTranspose[SM, 3, 2]\)], "Input"],

Cell[BoxData[
    \({{gv[u[1]]\[Wedge]gv[u[2]] + \(aa[1]\)[x, y], gv[u[1]]\[Wedge]gv[v[2]], 
        gv[u[2]]\[Wedge]gv[v[1]], 
        gv[v[2]] - gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[v[1]] - 
          gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]]}, {gv[u[1]]\[Wedge]gv[
            v[2]], gv[u[1]]\[Wedge]gv[v[1]] + \(aa[2]\)[x, y], 
        gv[u[2]]\[Wedge]gv[v[2]], 
        gv[v[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]] - 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]]}, {gv[u[2]]\[Wedge]gv[
            v[1]], gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[2]] + \(aa[3]\)[x, y], 
        gv[u[2]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
        gv[u[1]] - 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]]}, {\(-gv[v[2]]\) - 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], \(-gv[v[1]]\) - 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], \(-gv[u[2]]\) - 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[2]] + \(dd[1]\)[x, y], 
        gv[u[2]]\[Wedge]gv[v[1]]}, {\(-gv[v[1]]\) - 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], \(-gv[u[2]]\) - 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], \(-gv[u[1]]\) - 
          gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[u[2]] + \(dd[2]\)[x, y]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(subMatTK[SMt[1], 3, 3] === Transpose[AA]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(subMatDR[SMt[1], 3, 3] === Transpose[DD]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(subMatTK[SMt[1], 3, {4, 5}] === Transpose[CC]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(subMatDR[SMt[1], 3, {4, 5}] === \(-Transpose[BB]\)\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(SMt[2] = superTranspose[SMt[1], 3, 2]\)], "Input"],

Cell[BoxData[
    \({{gv[u[1]]\[Wedge]gv[u[2]] + \(aa[1]\)[x, y], gv[u[1]]\[Wedge]gv[v[2]], 
        gv[u[2]]\[Wedge]gv[v[1]], \(-gv[v[2]]\) - 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], \(-gv[v[1]]\) - 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]]}, {gv[u[1]]\[Wedge]gv[
            v[2]], gv[u[1]]\[Wedge]gv[v[1]] + \(aa[2]\)[x, y], 
        gv[u[2]]\[Wedge]gv[v[2]], \(-gv[v[1]]\) - 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], \(-gv[u[2]]\) - 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]]}, {gv[u[2]]\[Wedge]gv[
            v[1]], gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[2]] + \(aa[3]\)[x, y], \(-gv[u[2]]\) - 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], \(-gv[u[1]]\) - 
          gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]]}, {\(-gv[v[2]]\) + 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], \(-gv[v[1]]\) + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], \(-gv[u[2]]\) + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
        gv[u[1]]\[Wedge]gv[v[2]] + \(dd[1]\)[x, y], 
        gv[v[1]]\[Wedge]gv[v[2]]}, {\(-gv[v[1]]\) + 
          gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], \(-gv[u[2]]\) + 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], \(-gv[u[1]]\) + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], gv[u[2]]\[Wedge]gv[v[1]], 
        gv[u[1]]\[Wedge]gv[u[2]] + \(dd[2]\)[x, y]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(AA === subMatTK[SMt[2], 3, 3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(BB === \(-subMatTK[SMt[2], 3, {4, 5}]\)\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(CC === \(-subMatDR[SMt[2], 3, {4, 5}]\)\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DD === subMatDR[SMt[2], 3, 3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\t",
  StyleBox["superTranspose",
    FontFamily->"Courier"],
  " must be applied 4 times to give the original supermatrix:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(SM === Nest[superTranspose[#, 3, 2] &, SM, 4]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[" Supermatrices as tensors with different index positions", 
  "Subsubsection",
  ShowGroupOpenCloseIcon->True,
  FontSize->14],

Cell[TextData[{
  "The supermatrices considered so far were treated as operators on \
supervectors giving linear transformations of their components. If the \
vectors are given as lists of their contravariant components ",
  Cell[BoxData[
      \(X\^a\)]],
  " in some basis, then the components of the supermatrix S acting on them \
from the left must correspond to a tensor with index positions ",
  Cell[BoxData[
      \(\(S\^a\)\_b\)]],
  ", a {U, d}-type tensor (U=UP, d=down). One can extend the definition of \
superTranspose to supermatrices with different index positions ({U, U}, {d, \
U}, and {d, d}) by introducing a \"graded-symmetric\" even supermatrix -- \
tensor gdd={{G, 0)}, {0, F}}, where G is a symmetric pxp matrix and F an \
antisymmetric qxq matrix, and use it to lower (and its inverse to raise) \
indices (metric tensor). "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[TextData[{
  "Then, imposing the two requirements (for brevity, we use \
sT[X]=superTranspose[X, p, q]):\n (1) sT[gdd]=gdd, \n (2) \
sT[X\[Wedge]Y]=(-1)^(GP[X]*GP[Y])sT[Y]\[Wedge]sT[X], \nwe can obtain the \
action of superTranspose on ",
  Cell[BoxData[
      \(S\_ab\)]],
  ", ",
  Cell[BoxData[
      \(S\^ab\)]],
  " and  ",
  Cell[BoxData[
      \(S\_a\%\(\ \ b\)\)]],
  " from its action on ",
  Cell[BoxData[
      \(\(S\^a\)\_b\)]],
  " and gdd. In this version of superEDC, we have modified the definition of \
superTranspose to ",
  StyleBox["superTranspose[x_, p_, q_, {i_, j_}]",
    FontFamily->"Courier"],
  ", where the last (optional) argument {i, j} is a list of two numbers \
indicating the position of the two indices (UP=1, down=0) of the supermatrix \
tensor ",
  StyleBox["x",
    FontFamily->"Courier"],
  ". If the last argument is missing, the default index positions {1,0} (UP, \
down) is assumed, in agreement with the old definition. "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[TextData[{
  "The supermatrices ",
  Cell[BoxData[
      \(\(S\^a\)\_b\)]],
  " and ",
  Cell[BoxData[
      \(S\_b\%\(\(\ \ \)\(a\)\)\)]],
  " are superTransposes of each other, but superTranspose acts differently on \
them, which is why superTranspose (with the default last argument {1,0}) must \
be applied 4 times to obtain the original matrix. "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[TextData[{
  "The requirement sT[X\[Wedge]Y]=(-1)^(GP[X]*GP[Y])sT[Y]\[Wedge]sT[X] is \
also used to define the superTranspose of a supervector; again an optional \
argument is needed --  ",
  StyleBox["superTranspose[x_, p_, q_, i_]",
    FontFamily->"Courier"],
  " -- to distinguish UP (i=1) or down (i=0) index position. When omitted, \
the value i=1 ia assumed."
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell["\<\
Action of superTranspose on an even supermatrix / supervector\
\>", \
"Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(evenSM0 = EvenSuperMatrix[3, 2]\)], "Input"],

Cell[BoxData[
    \({{a$[1, 1], a$[1, 2], a$[1, 3], gv[b$[1, 1]], gv[b$[1, 2]]}, {a$[2, 1], 
        a$[2, 2], a$[2, 3], gv[b$[2, 1]], gv[b$[2, 2]]}, {a$[3, 1], a$[3, 2], 
        a$[3, 3], gv[b$[3, 1]], gv[b$[3, 2]]}, {gv[c$[1, 1]], gv[c$[1, 2]], 
        gv[c$[1, 3]], d$[1, 1], d$[1, 2]}, {gv[c$[2, 1]], gv[c$[2, 2]], 
        gv[c$[2, 3]], d$[2, 1], d$[2, 2]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[evenSM0, 3, 2]\)], "Input"],

Cell[BoxData[
    \({{a$[1, 1], a$[2, 1], a$[3, 1], gv[c$[1, 1]], gv[c$[2, 1]]}, {a$[1, 2], 
        a$[2, 2], a$[3, 2], gv[c$[1, 2]], gv[c$[2, 2]]}, {a$[1, 3], a$[2, 3], 
        a$[3, 3], gv[c$[1, 3]], 
        gv[c$[2, 3]]}, {\(-gv[b$[1, 1]]\), \(-gv[b$[2, 1]]\), \(-gv[
            b$[3, 1]]\), d$[1, 1], 
        d$[2, 1]}, {\(-gv[b$[1, 2]]\), \(-gv[b$[2, 2]]\), \(-gv[b$[3, 2]]\), 
        d$[1, 2], d$[2, 2]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% === superTranspose[evenSM0, 3, 2, {1, 0}]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
The action of superTranspose is different if different index \
positions are assumed: \
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[evenSM0, 3, 2, {0, 1}]\)], "Input"],

Cell[BoxData[
    \({{a$[1, 1], a$[2, 1], 
        a$[3, 1], \(-gv[c$[1, 1]]\), \(-gv[c$[2, 1]]\)}, {a$[1, 2], a$[2, 2], 
        a$[3, 2], \(-gv[c$[1, 2]]\), \(-gv[c$[2, 2]]\)}, {a$[1, 3], a$[2, 3], 
        a$[3, 3], \(-gv[c$[1, 3]]\), \(-gv[c$[2, 3]]\)}, {gv[b$[1, 1]], 
        gv[b$[2, 1]], gv[b$[3, 1]], d$[1, 1], d$[2, 1]}, {gv[b$[1, 2]], 
        gv[b$[2, 2]], gv[b$[3, 2]], d$[1, 2], d$[2, 2]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[evenSM0, 3, 2, {0, 0}]\)], "Input"],

Cell[BoxData[
    \({{a$[1, 1], a$[2, 1], 
        a$[3, 1], \(-gv[c$[1, 1]]\), \(-gv[c$[2, 1]]\)}, {a$[1, 2], a$[2, 2], 
        a$[3, 2], \(-gv[c$[1, 2]]\), \(-gv[c$[2, 2]]\)}, {a$[1, 3], a$[2, 3], 
        a$[3, 3], \(-gv[c$[1, 3]]\), \(-gv[c$[2, 3]]\)}, {\(-gv[
            b$[1, 1]]\), \(-gv[b$[2, 1]]\), \(-gv[b$[3, 1]]\), \(-d$[1, 
            1]\), \(-d$[2, 1]\)}, {\(-gv[b$[1, 2]]\), \(-gv[
            b$[2, 2]]\), \(-gv[b$[3, 2]]\), \(-d$[1, 2]\), \(-d$[2, 
            2]\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[evenSM0, 3, 2, {1, 1}]\)], "Input"],

Cell[BoxData[
    \({{a$[1, 1], a$[2, 1], a$[3, 1], gv[c$[1, 1]], gv[c$[2, 1]]}, {a$[1, 2], 
        a$[2, 2], a$[3, 2], gv[c$[1, 2]], gv[c$[2, 2]]}, {a$[1, 3], a$[2, 3], 
        a$[3, 3], gv[c$[1, 3]], gv[c$[2, 3]]}, {gv[b$[1, 1]], gv[b$[2, 1]], 
        gv[b$[3, 1]], \(-d$[1, 1]\), \(-d$[2, 1]\)}, {gv[b$[1, 2]], 
        gv[b$[2, 2]], 
        gv[b$[3, 2]], \(-d$[1, 2]\), \(-d$[2, 2]\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The supermatrices ",
  Cell[BoxData[
      \(\(S\^a\)\_b\)]],
  " and ",
  Cell[BoxData[
      \(S\_b\%\(\(\ \ \)\(a\)\)\)]],
  " are superTransposes of each other, while applying superTranspose twice to \
   ",
  Cell[BoxData[
      \(S\_ab\)]],
  " or ",
  Cell[BoxData[
      \(S\^ab\)]],
  " gives the original matrix: "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[superTranspose[evenSM0, 3, 2, {1, 0}], 3, 2, {0, 1}] === 
      evenSM0\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[superTranspose[evenSM0, 3, 2, {0, 1}], 3, 2, {1, 0}] === 
      evenSM0\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[superTranspose[evenSM0, 3, 2, {0, 0}], 3, 2, {0, 0}] === 
      evenSM0\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[superTranspose[evenSM0, 3, 2, {1, 1}], 3, 2, {1, 1}] === 
      evenSM0\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superTranspose[evenSM0[\([1]\)], 3, 2, 1]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(even\ supervector\ X\^a\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({a$[1, 1], a$[1, 2], a$[1, 3], gv[b$[1, 1]], gv[b$[1, 2]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superTranspose[evenSM0[\([1]\)], 3, 2, 0]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(even\ supervector\ \(X\_a\%\ \)\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({a$[1, 1], a$[1, 2], 
      a$[1, 3], \(-gv[b$[1, 1]]\), \(-gv[b$[1, 2]]\)}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[TextData[StyleBox["",
  FontSlant->"Italic"]], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["Action of superTranspose on an odd supermatrix / supervector", "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(oddSM1 = OddSuperMatrix[3, 2]\)], "Input"],

Cell[BoxData[
    \({{gv[a$[1, 1]], gv[a$[1, 2]], gv[a$[1, 3]], b$[1, 1], 
        b$[1, 2]}, {gv[a$[2, 1]], gv[a$[2, 2]], gv[a$[2, 3]], b$[2, 1], 
        b$[2, 2]}, {gv[a$[3, 1]], gv[a$[3, 2]], gv[a$[3, 3]], b$[3, 1], 
        b$[3, 2]}, {c$[1, 1], c$[1, 2], c$[1, 3], gv[d$[1, 1]], 
        gv[d$[1, 2]]}, {c$[2, 1], c$[2, 2], c$[2, 3], gv[d$[2, 1]], 
        gv[d$[2, 2]]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[oddSM1, 3, 2]\)], "Input"],

Cell[BoxData[
    \({{gv[a$[1, 1]], gv[a$[2, 1]], 
        gv[a$[3, 1]], \(-c$[1, 1]\), \(-c$[2, 1]\)}, {gv[a$[1, 2]], 
        gv[a$[2, 2]], 
        gv[a$[3, 2]], \(-c$[1, 2]\), \(-c$[2, 2]\)}, {gv[a$[1, 3]], 
        gv[a$[2, 3]], gv[a$[3, 3]], \(-c$[1, 3]\), \(-c$[2, 3]\)}, {b$[1, 1], 
        b$[2, 1], b$[3, 1], gv[d$[1, 1]], gv[d$[2, 1]]}, {b$[1, 2], b$[2, 2], 
        b$[3, 2], gv[d$[1, 2]], gv[d$[2, 2]]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% === superTranspose[oddSM1, 3, 2, {1, 0}]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
The action of superTranspose is different if different index \
positions are assumed: \
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[oddSM1, 3, 2, {0, 1}]\)], "Input"],

Cell[BoxData[
    \({{gv[a$[1, 1]], gv[a$[2, 1]], gv[a$[3, 1]], c$[1, 1], 
        c$[2, 1]}, {gv[a$[1, 2]], gv[a$[2, 2]], gv[a$[3, 2]], c$[1, 2], 
        c$[2, 2]}, {gv[a$[1, 3]], gv[a$[2, 3]], gv[a$[3, 3]], c$[1, 3], 
        c$[2, 3]}, {\(-b$[1, 1]\), \(-b$[2, 1]\), \(-b$[3, 1]\), 
        gv[d$[1, 1]], 
        gv[d$[2, 1]]}, {\(-b$[1, 2]\), \(-b$[2, 2]\), \(-b$[3, 2]\), 
        gv[d$[1, 2]], gv[d$[2, 2]]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[oddSM1, 3, 2, {0, 0}]\)], "Input"],

Cell[BoxData[
    \({{gv[a$[1, 1]], gv[a$[2, 1]], gv[a$[3, 1]], c$[1, 1], 
        c$[2, 1]}, {gv[a$[1, 2]], gv[a$[2, 2]], gv[a$[3, 2]], c$[1, 2], 
        c$[2, 2]}, {gv[a$[1, 3]], gv[a$[2, 3]], gv[a$[3, 3]], c$[1, 3], 
        c$[2, 3]}, {b$[1, 1], b$[2, 1], 
        b$[3, 1], \(-gv[d$[1, 1]]\), \(-gv[d$[2, 1]]\)}, {b$[1, 2], b$[2, 2], 
        b$[3, 2], \(-gv[d$[1, 2]]\), \(-gv[d$[2, 2]]\)}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[oddSM1, 3, 2, {1, 1}]\)], "Input"],

Cell[BoxData[
    \({{gv[a$[1, 1]], gv[a$[2, 1]], 
        gv[a$[3, 1]], \(-c$[1, 1]\), \(-c$[2, 1]\)}, {gv[a$[1, 2]], 
        gv[a$[2, 2]], 
        gv[a$[3, 2]], \(-c$[1, 2]\), \(-c$[2, 2]\)}, {gv[a$[1, 3]], 
        gv[a$[2, 3]], 
        gv[a$[3, 3]], \(-c$[1, 3]\), \(-c$[2, 3]\)}, {\(-b$[1, 1]\), \(-b$[2, 
            1]\), \(-b$[3, 1]\), \(-gv[d$[1, 1]]\), \(-gv[
            d$[2, 1]]\)}, {\(-b$[1, 2]\), \(-b$[2, 2]\), \(-b$[3, 2]\), \(-gv[
            d$[1, 2]]\), \(-gv[d$[2, 2]]\)}}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The supermatrices ",
  Cell[BoxData[
      \(\(S\^a\)\_b\)]],
  " and ",
  Cell[BoxData[
      \(S\_b\%\(\(\ \ \)\(a\)\)\)]],
  " are superTransposes of each other, while applying superTranspose twice to \
   ",
  Cell[BoxData[
      \(S\_ab\)]],
  " or ",
  Cell[BoxData[
      \(S\^ab\)]],
  " gives the original matrix: "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[superTranspose[oddSM1, 3, 2, {1, 0}], 3, 2, {0, 1}] === 
      oddSM1\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[superTranspose[oddSM1, 3, 2, {0, 1}], 3, 2, {1, 0}] === 
      oddSM1\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[superTranspose[oddSM1, 3, 2, {0, 0}], 3, 2, {0, 0}] === 
      oddSM1\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[superTranspose[oddSM1, 3, 2, {1, 1}], 3, 2, {1, 1}] === 
      oddSM1\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superTranspose[oddSM1[\([1]\)], 3, 2, 1]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(odd\ supervector\ X\^a\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({gv[a$[1, 1]], gv[a$[1, 2]], 
      gv[a$[1, 3]], \(-b$[1, 1]\), \(-b$[1, 2]\)}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superTranspose[oddSM1[\([1]\)], 3, 2, 0]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(odd\ supervector\ \(X\_a\%\ \)\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({gv[a$[1, 1]], gv[a$[1, 2]], gv[a$[1, 3]], b$[1, 1], 
      b$[1, 2]}\)], "Output"],

Cell[TextData[StyleBox["",
  FontSlant->"Italic"]], "Text",
  Evaluatable->False]
}, Open  ]]
}, Closed]],

Cell[TextData[StyleBox["",
  FontSlant->"Italic"]], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[{
  "Test basic superTranspose definition: SM = ",
  Cell[BoxData[
      \(\(S\^a\)\_b\)]],
  ", SMt = ",
  Cell[BoxData[
      \(S\_b\%\(\(\ \ \)\(a\)\)\)]],
  " "
}], "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    RowBox[{\(SMt = superTranspose[evenSM0, 3, 2]\), ";", 
      RowBox[{"(*", 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\(even\ parity\ supermatrix\ index\ \(\(parities\)\(:\)\)\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({dg[1], dg[2], dg[3], dg[4], dg[5]} = {0, 0, 0, 1, 1}\)], "Input"],

Cell[BoxData[
    \({0, 0, 0, 1, 1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      SMt[\([b, a]\)] - \ 
        evenSM0[\([a, b]\)] \((\(-1\))\)^\((dg[a]\ dg[b] + dg[b])\), {a, 1, 
        5}, {b, 1, 5}]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 
        0}, {0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    \(\[IndentingNewLine]\)], "Input"],

Cell[BoxData[
    RowBox[{\(SMt = superTranspose[oddSM1, 3, 2]\), ";", 
      RowBox[{"(*", 
        StyleBox[" ",
          FontColor->RGBColor[0, 0, 1]], 
        StyleBox[\(odd\ parity\ supermatrix\ index\ \(\(parities\)\(:\)\)\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \({dg[1], dg[2], dg[3], dg[4], dg[5]} = {1, 1, 1, 0, 0}\)], "Input"],

Cell[BoxData[
    \({1, 1, 1, 0, 0}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Table[
      SMt[\([b, a]\)] - \ 
        oddSM1[\([a, b]\)] \((\(-1\))\)^\((dg[a]\ dg[b] + dg[b])\), {a, 1, 
        5}, {b, 1, 5}]\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 0}, {0, 0, 0, 0, 
        0}, {0, 0, 0, 0, 0}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[TextData[StyleBox["",
  FontSlant->"Italic"]], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell["\<\
Test of sT[X\[Wedge]Y]=(-1)^(GP[X]*GP[Y])sT[Y]\[Wedge]sT[X] for \
even/odd  matrix-vector products.\
\>", "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(evenVEC = SM[\([1]\)]\)], "Input"],

Cell[BoxData[
    \({gv[u[1]]\[Wedge]gv[u[2]] + \(aa[1]\)[x, y], gv[u[1]]\[Wedge]gv[v[2]], 
      gv[u[2]]\[Wedge]gv[v[1]], 
      gv[v[2]] + gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
      gv[v[1]] + gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(oddVEC = SM[\([4]\)]\)], "Input"],

Cell[BoxData[
    \({gv[v[2]] - gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
      gv[v[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
      gv[u[2]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
      gv[u[1]]\[Wedge]gv[v[2]] + \(dd[1]\)[x, y], 
      gv[v[1]]\[Wedge]gv[v[2]]}\)], "Output"]
}, Open  ]],

Cell[BoxData[
    RowBox[{"(*", " ", 
      StyleBox[\(Next\ 4\ lines\ with\ default\ index\ positions\ for\ \
matrices\ /\ \(vectors : \ \(S\^a\)\_b\), \ X\^a\),
        FontColor->RGBColor[0, 0, 1]], " ", "*)"}]], "Input"],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[superWedge[evenSM0, evenVEC, 3, 2], 3, 2] === 
      superWedge[superTranspose[evenVEC, 3, 2], 
        superTranspose[evenSM0, 3, 2], 3, 2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[superWedge[evenSM0, oddVEC, 3, 2], 3, 2] === 
      superWedge[superTranspose[oddVEC, 3, 2], superTranspose[evenSM0, 3, 2], 
        3, 2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superTranspose[superWedge[oddSM1, evenVEC, 3, 2], 3, 2] === 
      superWedge[superTranspose[evenVEC, 3, 2], superTranspose[oddSM1, 3, 2], 
        3, 2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superTranspose[superWedge[oddSM1, oddVEC, 3, 2], 3, 2]\), "===",
       
      RowBox[{
      "-", \(superWedge[superTranspose[oddVEC, 3, 2], 
          superTranspose[oddSM1, 3, 2], 3, 2]\), 
        RowBox[{"(*", " ", 
          StyleBox[\(note\  - \ \(sign!\)\),
            FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[StyleBox["",
  FontSlant->"Italic"]], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superTranspose[superWedge[oddSM1, evenVEC, 3, 2], 3, 2, {1}]\), 
      "===", \(superWedge[superTranspose[evenVEC, 3, 2, {0}], 
        superTranspose[oddSM1, 3, 2, {1, 1}], 3, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(assumed\ index\ \(positions : \ oddSM1\^ab\), \ 
          evenVEC\_b\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superTranspose[superWedge[oddSM1, oddVEC, 3, 2], 3, 2, {1}]\), "===",
       
      RowBox[{
      "-", \(superWedge[superTranspose[oddVEC, 3, 2, {0}], 
          superTranspose[oddSM1, 3, 2, {1, 1}], 3, 2]\), 
        RowBox[{"(*", " ", 
          RowBox[{
            StyleBox[\(assumed\ index\ \(positions : \ oddSM1\^ab\)\),
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[",",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[" ",
              FontColor->RGBColor[0, 0, 1]], 
            RowBox[{
              StyleBox[\(oddVEC\_b\),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox[";",
                FontColor->RGBColor[0, 0, 1]], " ", 
              StyleBox[\(note\  - \ \(sign!\)\),
                FontColor->RGBColor[0, 0, 1]]}]}], "*)"}]}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superTranspose[superWedge[oddSM1, SM0, 3, 2], 3, 2, {1, 0}]\), 
      "===", \(superWedge[superTranspose[SM0, 3, 2, {0, 0}], 
        superTranspose[oddSM1, 3, 2, {1, 1}], 3, 2]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(assumed\ index\ \(positions : \ oddSM1\^ab\), \ SM0\_bc\),
          FontColor->RGBColor[0, 0, 1]], " ", "*)"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(superTranspose[superWedge[oddSM1, SM1, 3, 2], 3, 2, {1, 0}]\), "===",
       
      RowBox[{
      "-", \(superWedge[superTranspose[SM1, 3, 2, {0, 0}], 
          superTranspose[oddSM1, 3, 2, {1, 1}], 3, 2]\), 
        RowBox[{"(*", " ", 
          RowBox[{
            StyleBox[\(assumed\ index\ \(positions : \ oddSM1\^ab\)\),
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[",",
              FontColor->RGBColor[0, 0, 1]], 
            StyleBox[" ",
              FontColor->RGBColor[0, 0, 1]], 
            RowBox[{
              StyleBox[\(SM1\_bc\),
                FontColor->RGBColor[0, 0, 1]], 
              StyleBox[";",
                FontColor->RGBColor[0, 0, 1]], " ", 
              StyleBox[\(note\  - \ \(sign!\)\),
                FontColor->RGBColor[0, 0, 1]]}]}], " ", "*)"}]}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
\tIf the components of X, Y have non-zero diffrential-form degree \
(FD), the following relation holds:
 sT[X\[Wedge]Y]=(-1)^(GP[X]*GP[Y]+FD[X]*FD[Y])sT[Y]\[Wedge]sT[X].\
\>", "Text",\

  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16]
}, Closed]]
}, Closed]],

Cell[TextData[StyleBox["",
  FontSlant->"Italic"]], "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{

Cell["parityTranspose", "Subsection",
  FontSize->16],

Cell[TextData[{
  StyleBox["\tparityTranspose[x_, p_, q_]",
    FontFamily->"Courier"],
  " acts on a homogeneous (p, q)-dimensional supermatrix ",
  StyleBox["x",
    FontFamily->"Courier"],
  " and produces a homogeneous (q, p)-dimensional supermatrix of the same \
paritry (",
  StyleBox["note the interchange",
    FontSlant->"Italic"],
  " p\[LongLeftRightArrow]q):"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(ptSM = parityTranspose[SM, 3, 2]\)], "Input"],

Cell[BoxData[
    \({{gv[u[1]]\[Wedge]gv[v[2]] + \(dd[1]\)[x, y], gv[v[1]]\[Wedge]gv[v[2]], 
        gv[v[2]] - gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[v[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]] - 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]}, {gv[u[2]]\[Wedge]gv[
            v[1]], gv[u[1]]\[Wedge]gv[u[2]] + \(dd[2]\)[x, y], 
        gv[v[1]] - gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[2]] - gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]] - gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]]}, {gv[v[2]] + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]], 
        gv[v[1]] + gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[u[2]] + \(aa[1]\)[x, y], gv[u[1]]\[Wedge]gv[v[2]], 
        gv[u[2]]\[Wedge]gv[v[1]]}, {gv[v[1]] + 
          gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[2]] + gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[2]], gv[u[1]]\[Wedge]gv[v[1]] + \(aa[2]\)[x, y], 
        gv[u[2]]\[Wedge]gv[v[2]]}, {gv[u[2]] + 
          gv[u[1]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[1]] + gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[v[2]], 
        gv[u[2]]\[Wedge]gv[v[1]], gv[u[2]]\[Wedge]gv[v[2]], 
        gv[u[1]]\[Wedge]gv[v[2]] + \(aa[3]\)[x, y]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[ptSM, 3, 2]\)], "Input"],

Cell[BoxData[
    \("Wrong (p, q) dimensions or mixed parity entries."\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[ptSM, 2, 3]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tThe operations ",
  StyleBox["parityTranspose[x_, p_, q_]",
    FontFamily->"Courier"],
  " (= \[Pi]) and ",
  StyleBox["superTranspose[x_, p_, q_,{i_,j_}]",
    FontFamily->"Courier"],
  " (= ",
  StyleBox["st",
    FontSlant->"Italic"],
  "), with {i,j}={1,0} or {0,1}, satisfy the identities ",
  Cell[BoxData[
      \(\[Pi]\^2 = 1\)]],
  " and  ",
  Cell[BoxData[
      RowBox[{
        RowBox[{"\[Pi]", " ", "\[EmptySmallCircle]", " ", 
          StyleBox["st",
            FontSlant->"Italic"], " ", "\[EmptySmallCircle]", " ", "\[Pi]"}], 
        "=", 
        SuperscriptBox[
          StyleBox["st",
            FontSlant->"Italic"], "3"]}]]],
  ":"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(parityTranspose[ptSM, 2, 3] === SM\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"parityTranspose", "[", 
        RowBox[{
          RowBox[{"superTranspose", "[", 
            RowBox[{\(parityTranspose[SM, 3, 2]\), ",", "2", ",", "3", ",", 
              StyleBox[\({1, 0}\),
                FontColor->RGBColor[0, 0, 1]]}], "]"}], ",", "2", ",", "3"}], 
        "]"}], "===", 
      RowBox[{"Nest", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"superTranspose", "[", 
              RowBox[{"#", ",", "3", ",", "2", ",", 
                StyleBox[\({1, 0}\),
                  FontColor->RGBColor[0, 0, 1]]}], "]"}], "&"}], ",", "SM", 
          ",", "3"}], "]"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"parityTranspose", "[", 
        RowBox[{
          RowBox[{"superTranspose", "[", 
            RowBox[{\(parityTranspose[SM, 3, 2]\), ",", "2", ",", "3", ",", 
              StyleBox[\({0, 1}\),
                FontColor->RGBColor[0, 0, 1]]}], "]"}], ",", "2", ",", "3"}], 
        "]"}], "===", 
      RowBox[{"Nest", "[", 
        RowBox[{
          RowBox[{
            RowBox[{"superTranspose", "[", 
              RowBox[{"#", ",", "3", ",", "2", ",", 
                StyleBox[\({0, 1}\),
                  FontColor->RGBColor[0, 0, 1]]}], "]"}], "&"}], ",", "SM", 
          ",", "3"}], "]"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Also the following identities (in an obvious notation) ",
  Cell[BoxData[
      RowBox[{
        RowBox[{
          StyleBox["st01",
            FontSlant->"Italic"], " ", "\[EmptySmallCircle]", " ", "\[Pi]"}], 
        "=", 
        RowBox[{"\[Pi]", " ", 
          StyleBox[
            RowBox[{"\[EmptySmallCircle]", 
              StyleBox["st10",
                FontSlant->"Italic"]}]]}]}]]],
  "  and ",
  Cell[BoxData[
      RowBox[{" ", 
        RowBox[{
          RowBox[{
            StyleBox["st10",
              FontSlant->"Italic"], " ", "\[EmptySmallCircle]", " ", 
            "\[Pi]"}], "=", 
          RowBox[{"\[Pi]", " ", 
            StyleBox[
              RowBox[{"\[EmptySmallCircle]", 
                StyleBox["st01",
                  FontSlant->"Italic"]}]]}]}]}]]],
  "  hold:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"superTranspose", "[", 
        RowBox[{\(parityTranspose[SM, 3, 2]\), ",", "2", ",", "3", ",", 
          StyleBox[\({0, 1}\),
            FontColor->RGBColor[0, 0, 1]]}], "]"}], "===", 
      RowBox[{"parityTranspose", "[", 
        RowBox[{
          RowBox[{"superTranspose", "[", 
            RowBox[{"SM", ",", "3", ",", "2", ",", 
              StyleBox[\({1, 0}\),
                FontColor->RGBColor[0, 0, 1]]}], "]"}], ",", "3", ",", "2"}], 
        "]"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"superTranspose", "[", 
        RowBox[{\(parityTranspose[SM, 3, 2]\), ",", "2", ",", "3", ",", 
          StyleBox[\({1, 0}\),
            FontColor->RGBColor[0, 0, 1]]}], "]"}], "===", 
      RowBox[{"parityTranspose", "[", 
        RowBox[{
          RowBox[{"superTranspose", "[", 
            RowBox[{"SM", ",", "3", ",", "2", ",", 
              StyleBox[\({0, 1}\),
                FontColor->RGBColor[0, 0, 1]]}], "]"}], ",", "3", ",", "2"}], 
        "]"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["superInverse", "Subsection",
  FontSize->16],

Cell[TextData[{
  "\t",
  StyleBox["superInverse[x_, p_, q_]",
    FontFamily->"Courier"],
  " acts on a ",
  StyleBox["homogeneous",
    FontSlant->"Italic"],
  " (p, q)-dimensional supermatrix ",
  StyleBox["x",
    FontFamily->"Courier"],
  " and produces another (p, q)-dimensional supermatrix -- the inverse of  ",
  StyleBox["x",
    FontFamily->"Courier"],
  " -- provided it exists:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"inverseSM0", "=", 
      RowBox[{
        StyleBox["superInverse",
          FontFamily->"Courier"], "[", \(SM0, 3, 2\), "]"}]}]], "Input"],

Cell[BoxData[
    \({{\(-\(\(gv[u[1]]\[Wedge]gv[u[2]]\)\/\(aa[1]\)[x, y]\^2\)\) + 
          1\/\(aa[1]\)[x, y], \(-\(\(gv[u[2]]\[Wedge]gv[v[1]]\)\/\(\(aa[1]\)[
                  x, y]\ \(aa[2]\)[x, y]\ \(dd[2]\)[x, 
                  y]\)\)\), \(-\(\(gv[u[2]]\[Wedge]gv[v[1]]\)\/\(\(aa[1]\)[x, 
                    y]\ \(aa[3]\)[x, 
                    y]\)\)\) - \(gv[u[1]]\[Wedge]gv[v[1]]\)\/\(\(aa[1]\)[x, \
y]\ \(aa[3]\)[x, y]\ \(dd[2]\)[x, y]\), \(-\(\(gv[u[1]]\[Wedge]gv[
                    u[2]]\[Wedge]gv[
                    v[1]]\ \((1 + \(aa[3]\)[x, y]\ \(dd[2]\)[x, 
                        y])\)\)\/\(\(aa[1]\)[x, y]\ \(aa[3]\)[x, 
                  y]\ \(dd[1]\)[x, y]\ \(dd[2]\)[x, y]\)\)\), \(-\(gv[
                  v[1]]\/\(\(aa[1]\)[x, y]\ \(dd[2]\)[x, y]\)\)\) + \((gv[
                    u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[
                    v[1]]\ \((\(aa[1]\)[x, y]\ \(aa[3]\)[x, y] + \(aa[1]\)[x, 
                        y]\ \(dd[2]\)[x, y] + \(aa[3]\)[x, y]\ \(dd[2]\)[x, 
                        y])\))\)/\((\(aa[1]\)[x, y]\^2\ \(aa[3]\)[x, 
                  y]\ \(dd[2]\)[x, y]\^2)\)}, {\(gv[u[2]]\[Wedge]gv[v[1]]\)\/\
\(\(aa[1]\)[x, y]\ \(aa[2]\)[x, y]\ \(dd[2]\)[x, y]\), \(-\(\(gv[
                    u[1]]\[Wedge]gv[v[1]]\)\/\(aa[2]\)[x, y]\^2\)\) + 
          1\/\(aa[2]\)[x, y], \(-\(\(gv[u[2]]\[Wedge]gv[v[1]]\)\/\(\(aa[2]\)[
                    x, y]\ \(aa[3]\)[x, y]\ \(dd[1]\)[x, 
                    y]\)\)\) - \(gv[u[1]]\[Wedge]gv[u[2]]\)\/\(\(aa[2]\)[x, \
y]\ \(aa[3]\)[x, y]\ \(dd[2]\)[x, y]\), \(-\(gv[
                v[1]]\/\(\(aa[2]\)[x, y]\ \(dd[1]\)[x, y]\)\)\), \(-\(gv[
                  u[2]]\/\(\(aa[2]\)[x, y]\ \(dd[2]\)[x, 
                    y]\)\)\) + \(gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \
\((\(aa[2]\)[x, y] - \(aa[3]\)[x, y]\ \(dd[1]\)[x, y])\)\)\/\(\(aa[2]\)[x, y]\
\^2\ \(aa[3]\)[x, y]\ \(dd[1]\)[x, y]\ \(dd[2]\)[x, y]\)}, {\(-\(\(gv[
                    u[2]]\[Wedge]gv[v[1]]\)\/\(\(aa[1]\)[x, y]\ \(aa[3]\)[x, 
                    y]\)\)\) + \(gv[u[1]]\[Wedge]gv[v[1]]\)\/\(\(aa[1]\)[x, \
y]\ \(aa[3]\)[x, y]\ \(dd[2]\)[x, y]\), \
\(gv[u[2]]\[Wedge]gv[v[1]]\)\/\(\(aa[2]\)[x, y]\ \(aa[3]\)[x, y]\ \
\(dd[1]\)[x, y]\) + \(gv[u[1]]\[Wedge]gv[u[2]]\)\/\(\(aa[2]\)[x, y]\ \
\(aa[3]\)[x, y]\ \(dd[2]\)[x, y]\), 
        1\/\(aa[3]\)[x, y], \(-\(gv[
                  u[2]]\/\(\(aa[3]\)[x, y]\ \(dd[1]\)[x, 
                    y]\)\)\) + \(gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \
\((\(-1\) + \(aa[2]\)[x, y])\)\)\/\(\(aa[2]\)[x, y]\ \(aa[3]\)[x, y]\ \(dd[1]\
\)[x, y]\ \(dd[2]\)[x, y]\), \(-\(gv[
                u[1]]\/\(\(aa[3]\)[x, y]\ \(dd[2]\)[x, 
                  y]\)\)\)}, \
{\(gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\)\/\(\(aa[1]\)[x, y]\ \
\(aa[3]\)[x, y]\ \(dd[1]\)[x, y]\ \(dd[2]\)[x, y]\), \(-\(gv[
                v[1]]\/\(\(aa[2]\)[x, y]\ \(dd[1]\)[x, y]\)\)\), \(-\(gv[
                  u[2]]\/\(\(aa[3]\)[x, y]\ \(dd[1]\)[x, 
                    y]\)\)\) + \(gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \
\((1 + \(aa[2]\)[x, y]\ \(dd[2]\)[x, y])\)\)\/\(\(aa[2]\)[x, y]\ \(aa[3]\)[x, \
y]\ \(dd[1]\)[x, y]\ \(dd[2]\)[x, y]\), 
        1\/\(dd[1]\)[x, y], \(-\(\(gv[u[2]]\[Wedge]gv[v[1]]\)\/\(\(aa[2]\)[x, 
                    y]\ \(dd[1]\)[x, y]\ \(dd[2]\)[x, 
                    y]\)\)\) - \(gv[u[1]]\[Wedge]gv[u[2]]\)\/\(\(aa[3]\)[x, \
y]\ \(dd[1]\)[x, y]\ \(dd[2]\)[x, y]\)}, {\(-\(gv[
                  v[1]]\/\(\(aa[1]\)[x, y]\ \(dd[2]\)[x, y]\)\)\) + \((gv[
                    u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[
                    v[1]]\ \((\(aa[1]\)[x, y]\ \(aa[3]\)[x, y] + \(aa[1]\)[x, 
                        y]\ \(dd[2]\)[x, y] + \(aa[3]\)[x, y]\ \(dd[2]\)[x, 
                        y])\))\)/\((\(aa[1]\)[x, y]\^2\ \(aa[3]\)[x, 
                  y]\ \(dd[2]\)[x, y]\^2)\), \(-\(gv[
                  u[2]]\/\(\(aa[2]\)[x, y]\ \(dd[2]\)[x, 
                    y]\)\)\) - \(gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\ \
\((\(aa[2]\)[x, y] + \(aa[3]\)[x, y]\ \(dd[1]\)[x, y])\)\)\/\(\(aa[2]\)[x, y]\
\^2\ \(aa[3]\)[x, y]\ \(dd[1]\)[x, y]\ \(dd[2]\)[x, y]\), \(-\(gv[
                u[1]]\/\(\(aa[3]\)[x, y]\ \(dd[2]\)[x, 
                  y]\)\)\), \(-\(\(gv[u[2]]\[Wedge]gv[
                      v[1]]\ \((\(-1\) + \(aa[2]\)[x, y])\)\)\/\(\(aa[2]\)[x, 
                    y]\ \(dd[1]\)[x, y]\ \(dd[2]\)[x, 
                    y]\)\)\) + \(gv[u[1]]\[Wedge]gv[u[2]]\)\/\(\(aa[3]\)[x, \
y]\ \(dd[1]\)[x, y]\ \(dd[2]\)[x, y]\), \(-\(\(gv[u[1]]\[Wedge]gv[
                    u[2]]\)\/\(dd[2]\)[x, y]\^2\)\) + 
          1\/\(dd[2]\)[x, y]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[superWedge[inverseSM0, SM0, 3, 2]]\)], "Input"],

Cell[BoxData[
    \({{1, 0, 0, 0, 0}, {0, 1, 0, 0, 0}, {0, 0, 1, 0, 0}, {0, 0, 0, 1, 
        0}, {0, 0, 0, 0, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[superWedge[SM0, inverseSM0, 3, 2]]\)], "Input"],

Cell[BoxData[
    \({{1, 0, 0, 0, 0}, {0, 1, 0, 0, 0}, {0, 0, 1, 0, 0}, {0, 0, 0, 1, 
        0}, {0, 0, 0, 0, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["superInverse",
        FontFamily->"Courier"], "[", 
      RowBox[{
        RowBox[{"SM", 
          StyleBox["/.",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(\(aa[_]\)[x, y] \[Rule] 0\),
            FontColor->RGBColor[1, 0, 0]]}], ",", "3", ",", "2"}], 
      "]"}]], "Input"],

Cell[BoxData[
    \("Not invertible"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["superInverse",
        FontFamily->"Courier"], "[", 
      RowBox[{
        RowBox[{"SM", 
          StyleBox["/.",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(\(dd[_]\)[x, y] \[Rule] 0\),
            FontColor->RGBColor[1, 0, 0]]}], ",", "3", ",", "2"}], 
      "]"}]], "Input"],

Cell[BoxData[
    \("Not invertible"\)], "Print"]
}, Open  ]],

Cell[TextData[{
  "\tThe operations ",
  StyleBox["superTranspose[x_, p_, q_]",
    FontFamily->"Courier"],
  "  and ",
  StyleBox["superInverse[x_, p_, q_]",
    FontFamily->"Courier"],
  " commute, provided the index positions of ",
  StyleBox["x",
    FontFamily->"Courier"],
  " and ",
  StyleBox["superInverse[x",
    FontFamily->"Courier"],
  "] are assumed correctly so that matrix multiplication involves contraction \
of adjacent indices of opposite {U, d} types and the product (= identity \
matrix) has one index UP and one down:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"superTranspose", "[", 
        RowBox[{
          RowBox[{
            StyleBox["superInverse",
              FontFamily->"Courier"], "[", \(SM0, 3, 2\), "]"}], ",", "3", 
          ",", "2"}], "]"}], "===", 
      RowBox[{
        StyleBox["superInverse",
          FontFamily->"Courier"], "[", \(superTranspose[SM0, 3, 2], 3, 2\), 
        "]"}], 
      RowBox[{"(*", " ", 
        StyleBox[
          RowBox[{
            RowBox[{"default", " ", "index", " ", 
              RowBox[{"positions", ":", " ", 
                SubscriptBox[
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"S", 
                        StyleBox["M0",
                          FontColor->RGBColor[0, 0, 1]]}]], "a"], "b"]}]}], 
            ",", " ", \(implies\ inverse\ \(invSM0\^b\)\_a\)}],
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"superTranspose", "[", 
        RowBox[{
          RowBox[{
            StyleBox["superInverse",
              FontFamily->"Courier"], "[", \(SM0, 3, 2\), "]"}], ",", "3", 
          ",", "2", ",", \({0, 1}\)}], "]"}], "===", 
      RowBox[{
        StyleBox["superInverse",
          FontFamily->"Courier"], "[", \(superTranspose[SM0, 3, 2, {0, 1}], 
        3, 2\), "]"}], 
      RowBox[{"(*", " ", 
        StyleBox[
          RowBox[{
            RowBox[{"assumed", " ", "index", " ", 
              RowBox[{"positions", ":", " ", 
                SubsuperscriptBox[
                  StyleBox[
                    RowBox[{"S", 
                      StyleBox["M0",
                        FontColor->RGBColor[0, 0, 1]]}]], 
                  "b", \(\(\ \ \)\(a\)\)]}]}], ",", 
            " ", \(implies\ inverse\ invSM0\_a\%\(\(\ \ \)\(b\)\)\)}],
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"superTranspose", "[", 
        RowBox[{
          RowBox[{
            StyleBox["superInverse",
              FontFamily->"Courier"], "[", \(SM0, 3, 2\), "]"}], ",", "3", 
          ",", "2", ",", 
          StyleBox[\({0, 0}\),
            FontColor->RGBColor[0, 0, 1]]}], "]"}], "===", 
      RowBox[{
        StyleBox["superInverse",
          FontFamily->"Courier"], "[", 
        RowBox[{
          RowBox[{"superTranspose", "[", 
            RowBox[{"SM0", ",", "3", ",", "2", ",", 
              StyleBox[\({1, 1}\),
                FontColor->RGBColor[0, 0, 1]]}], "]"}], ",", "3", ",", "2"}], 
        "]"}], 
      RowBox[{"(*", " ", 
        StyleBox[
          RowBox[{
            RowBox[{"assumed", " ", "index", " ", 
              RowBox[{"positions", ":", " ", 
                SuperscriptBox[
                  StyleBox[
                    RowBox[{"SM", 
                      StyleBox["0",
                        FontColor->RGBColor[0, 0, 1]]}]], "ab"]}]}], ",", 
            " ", \(implies\ inverse\ invSM0\_ba\)}],
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      RowBox[{"superTranspose", "[", 
        RowBox[{
          RowBox[{
            StyleBox["superInverse",
              FontFamily->"Courier"], "[", \(SM0, 3, 2\), "]"}], ",", "3", 
          ",", "2", ",", 
          StyleBox[\({1, 1}\),
            FontColor->RGBColor[0, 0, 1]]}], "]"}], "===", 
      RowBox[{
        StyleBox["superInverse",
          FontFamily->"Courier"], "[", 
        RowBox[{
          RowBox[{"superTranspose", "[", 
            RowBox[{"SM0", ",", "3", ",", "2", ",", 
              StyleBox[\({0, 0}\),
                FontColor->RGBColor[0, 0, 1]]}], "]"}], ",", "3", ",", "2"}], 
        "]"}], 
      RowBox[{"(*", " ", 
        StyleBox[
          RowBox[{
            RowBox[{"assumed", " ", "index", " ", 
              RowBox[{"positions", ":", " ", 
                SubscriptBox[
                  StyleBox[
                    RowBox[{"SM", 
                      StyleBox["0",
                        FontColor->RGBColor[0, 0, 1]]}]], "ab"]}]}], ",", 
            " ", \(implies\ inverse\ invSM0\^ba\)}],
          FontColor->RGBColor[0, 0, 1]], "*)"}]}]], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell["Berezinian", "Subsection",
  FontSize->16],

Cell[TextData[{
  "\t",
  StyleBox["Berezinian[x_, p_, q_]",
    FontFamily->"Courier"],
  " acts on an ",
  StyleBox["even",
    FontSlant->"Italic"],
  ", homogeneous  (p, q)-dimensional supermatrix ",
  StyleBox["x",
    FontFamily->"Courier"],
  " and produces an even scalar -- the Berezinian of ",
  StyleBox["x",
    FontFamily->"Courier"],
  " -- provided it exists:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Berezinian",
        FontFamily->"Courier"], "[", \(SM, 3, 2\), "]"}]], "Input"],

Cell[BoxData[
    \(\(-\(\(gv[u[1]]\[Wedge]gv[u[2]]\ \(aa[2]\)[x, y]\ \(aa[3]\)[x, 
                y]\ \((\(aa[1]\)[x, y] - \(dd[2]\)[x, y])\)\)\/\(\(dd[1]\)[x, 
                y]\ \(dd[2]\)[x, y]\^2\)\)\) - \(gv[u[1]]\[Wedge]gv[v[2]]\ \
\(aa[1]\)[x, y]\ \(aa[2]\)[x, y]\ \((\(aa[3]\)[x, y] - \(dd[1]\)[x, y])\)\)\/\
\(\(dd[1]\)[x, y]\^2\ \(dd[2]\)[x, y]\) + \(gv[u[1]]\[Wedge]gv[v[1]]\ \(aa[1]\
\)[x, y]\ \(aa[3]\)[x, y]\)\/\(\(dd[1]\)[x, y]\ \(dd[2]\)[x, y]\) + \(\(aa[1]\
\)[x, y]\ \(aa[2]\)[x, y]\ \(aa[3]\)[x, y]\)\/\(\(dd[1]\)[x, y]\ \(dd[2]\)[x, \
y]\) + \((gv[u[1]]\[Wedge]gv[u[2]]\[Wedge]gv[v[1]]\[Wedge]gv[
                v[2]]\ \((\(-2\)\ \(aa[2]\)[x, y] - \(aa[1]\)[x, 
                    y]\ \(aa[2]\)[x, y] + \(aa[1]\)[x, y]\ \(aa[2]\)[x, 
                    y]\ \(dd[1]\)[x, y] - 
                2\ \(aa[1]\)[x, y]\ \(aa[3]\)[x, y]\ \(dd[1]\)[x, 
                    y] + \(aa[2]\)[x, y]\ \(aa[3]\)[x, y]\ \(dd[1]\)[x, 
                    y] - \(aa[1]\)[x, y]\ \(aa[2]\)[x, y]\ \(dd[2]\)[x, y] + 
                2\ \(aa[1]\)[x, y]\ \(aa[3]\)[x, y]\ \(dd[2]\)[x, 
                    y] - \(aa[2]\)[x, y]\ \(aa[3]\)[x, y]\ \(dd[2]\)[x, 
                    y])\))\)/\((\(dd[1]\)[x, y]\^2\ \(dd[2]\)[x, y]\^2)\)\)], \
"Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. gv[__] \[Rule] 0\)], "Input"],

Cell[BoxData[
    \(\(\(aa[1]\)[x, y]\ \(aa[2]\)[x, y]\ \(aa[3]\)[x, y]\)\/\(\(dd[1]\)[x, \
y]\ \(dd[2]\)[x, y]\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Berezinian",
        FontFamily->"Courier"], "[", \(SM0, 3, 2\), "]"}]], "Input"],

Cell[BoxData[
    \(\(-\(\(gv[u[1]]\[Wedge]gv[u[2]]\ \(aa[2]\)[x, y]\ \(aa[3]\)[x, 
                y]\ \((\(aa[1]\)[x, y] - \(dd[2]\)[x, y])\)\)\/\(\(dd[1]\)[x, 
                y]\ \(dd[2]\)[x, y]\^2\)\)\) + \(gv[u[1]]\[Wedge]gv[v[1]]\ \
\(aa[1]\)[x, y]\ \(aa[3]\)[x, y]\)\/\(\(dd[1]\)[x, y]\ \(dd[2]\)[x, y]\) + \(\
\(aa[1]\)[x, y]\ \(aa[2]\)[x, y]\ \(aa[3]\)[x, y]\)\/\(\(dd[1]\)[x, y]\ \
\(dd[2]\)[x, y]\)\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Berezinian",
        FontFamily->"Courier"], "[", 
      RowBox[{
        RowBox[{"SM", 
          StyleBox["/.",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(\(aa[_]\)[x, y] \[Rule] 0\),
            FontColor->RGBColor[1, 0, 0]]}], ",", "3", ",", "2"}], 
      "]"}]], "Input"],

Cell[BoxData[
    \(0\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{
      StyleBox["Berezinian",
        FontFamily->"Courier"], "[", 
      RowBox[{
        RowBox[{"SM", 
          StyleBox["/.",
            FontColor->RGBColor[1, 0, 0]], 
          StyleBox[\(\(dd[_]\)[x, y] \[Rule] 0\),
            FontColor->RGBColor[1, 0, 0]]}], ",", "3", ",", "2"}], 
      "]"}]], "Input"],

Cell[BoxData[
    \("Not defined"\)], "Print"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[TextData[StyleBox["",
  FontSlant->"Italic"]], "Text",
  Evaluatable->False],

Cell[CellGroupData[{

Cell[TextData[{
  "6. ",
  StyleBox["A non-trivial Example:",
    FontSlant->"Italic"],
  " Compute the Maurer-Cartan forms for the group OSP(2|2)"
}], "Section",
  Evaluatable->False,
  FontSize->18],

Cell["\<\
\tCalculations with symbols representing graded quantities are \
complicated as one must keep track of all their properties: Grassmann Parity, \
FormDegree, (anti)commutation rules, and whether the symbols represent \
matrices or not. This example illustrates how one can deal with these issues.\
\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[TextData[{
  "\tThe Lie algebra of OSP(2, 2) has 4 even and 4 odd generators and is \
defined by the (graded) commutators given below (zeroComms), taken from \
Appendix D of the paper by Anabalon, Gomis, Kamimura and Zanelli \"",
  StyleBox["N=4 superconformal mechanics as a non linear realization",
    FontSlant->"Italic"],
  "\", JHEP ",
  StyleBox["10",
    FontWeight->"Bold"],
  " (2006) 068 (ArXiv: ",
  ButtonBox["hep-th/0607124",
    ButtonData:>{
      URL[ "http://arxiv.org/abs/hep-th/0607124"], None},
    ButtonStyle->"Hyperlink"],
  "). We follow the notation of this paper which the reader should consult \
for more details."
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell["\<\
\tWe will interpret the generators, denoted by {H, D, K, B, Q[i], \
S[j]} in the paper, as matrices so we will define the symbols EV[_], OD[_] to \
represent (even-odd) symbolic matrices. And we will require that the even \
(odd) generators will commute (anticommute) with the Grasmann variables, \
ordering the variables to the left of the symbolic matrix generators \
(DeclareMatrixForms prints a reminder to do this): \
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeclareMatrixForms[{0, EV[_], EV[_]}, {0, OD[_], OD[_]}]\)], "Input"],

Cell[BoxData[
    \("Define GrassParity and ordering rule for symbolic matrices and gv[] \
variables!"\)], "Output",
  FontSize->16,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \("OK"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(GrassParity[EV[_]] = 0; GrassParity[OD[_]] = 1;\)], "Input"],

Cell[BoxData[
    \(Wedge[EV[x_], gv[y_]] := Wedge[gv[y], EV[x]]\)], "Input"],

Cell[BoxData[
    \(Wedge[OD[x_], gv[y_]] := \(-Wedge[gv[y], OD[x]]\)\)], "Input"],

Cell[TextData[{
  "\tWe will also define the graded commutator of two generators ",
  StyleBox["gradComm[x_, y_]",
    FontFamily->"Courier"]
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    \(gradComm[x_, y_] := 
      Wedge[x, y] - \((\(-1\))\)^\((GrassParity[x] GrassParity[y])\) 
          Wedge[y, x]\)], "Input"],

Cell["\<\
\tWith these definitions, the graded commutators defining the \
osp(2|2) algebra imply that the following expressions vanish (see equations D \
3 - D 6):\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(zeroComms = {gradComm[EV[H], EV[D]] - I\ EV[H], 
        gradComm[EV[K], EV[D]] + I\ EV[K], 
        gradComm[EV[H], EV[K]] - 2  I\ EV[D], 
        gradComm[OD[Q[1]], OD[Q[1]]] - \ EV[H], gradComm[OD[Q[1]], OD[Q[2]]], 
        gradComm[OD[Q[2]], OD[Q[2]]] - \ EV[H], 
        gradComm[OD[Q[1]], OD[S[1]]] - \ EV[D], 
        gradComm[OD[Q[2]], OD[S[2]]] - \ EV[D], 
        gradComm[OD[Q[1]], OD[S[2]]] - 1/2\ EV[B], 
        gradComm[OD[Q[2]], OD[S[1]]] + 1/2\ EV[B], 
        gradComm[EV[D], OD[Q[1]]] + I/2\ OD[Q[1]], 
        gradComm[EV[D], OD[Q[2]]] + I/2\ OD[Q[2]], 
        gradComm[EV[D], OD[S[1]]] - I/2\ OD[S[1]], 
        gradComm[EV[D], OD[S[2]]] - I/2\ OD[S[2]], 
        gradComm[EV[H], OD[S[1]]] - I\ \ OD[Q[1]], 
        gradComm[EV[H], OD[S[2]]] - I\ \ OD[Q[2]], 
        gradComm[EV[B], OD[Q[1]]] + I\ OD[Q[2]], 
        gradComm[EV[B], OD[Q[2]]] - I\ OD[Q[1]], 
        gradComm[EV[B], OD[S[1]]] + I\ OD[S[2]], 
        gradComm[EV[B], OD[S[2]]] - I\ OD[S[1]]}\)], "Input"],

Cell[BoxData[
    \({\(-\[ImaginaryI]\)\ EV[H] - EV[D]\[Wedge]EV[H] + 
        EV[H]\[Wedge]EV[D], \[ImaginaryI]\ EV[K] - EV[D]\[Wedge]EV[K] + 
        EV[K]\[Wedge]EV[D], \(-2\)\ \[ImaginaryI]\ EV[D] + 
        EV[H]\[Wedge]EV[K] - EV[K]\[Wedge]EV[H], \(-EV[H]\) + 
        2\ OD[Q[1]]\[Wedge]OD[Q[1]], 
      OD[Q[1]]\[Wedge]OD[Q[2]] + OD[Q[2]]\[Wedge]OD[Q[1]], \(-EV[H]\) + 
        2\ OD[Q[2]]\[Wedge]OD[Q[2]], \(-EV[D]\) + OD[Q[1]]\[Wedge]OD[S[1]] + 
        OD[S[1]]\[Wedge]OD[Q[1]], \(-EV[D]\) + OD[Q[2]]\[Wedge]OD[S[2]] + 
        OD[S[2]]\[Wedge]OD[Q[2]], \(-\(EV[B]\/2\)\) + 
        OD[Q[1]]\[Wedge]OD[S[2]] + OD[S[2]]\[Wedge]OD[Q[1]], 
      EV[B]\/2 + OD[Q[2]]\[Wedge]OD[S[1]] + OD[S[1]]\[Wedge]OD[Q[2]], 
      1\/2\ \[ImaginaryI]\ OD[Q[1]] + EV[D]\[Wedge]OD[Q[1]] - 
        OD[Q[1]]\[Wedge]EV[D], 
      1\/2\ \[ImaginaryI]\ OD[Q[2]] + EV[D]\[Wedge]OD[Q[2]] - 
        OD[Q[2]]\[Wedge]EV[D], \(-\(1\/2\)\)\ \[ImaginaryI]\ OD[S[1]] + 
        EV[D]\[Wedge]OD[S[1]] - 
        OD[S[1]]\[Wedge]EV[D], \(-\(1\/2\)\)\ \[ImaginaryI]\ OD[S[2]] + 
        EV[D]\[Wedge]OD[S[2]] - 
        OD[S[2]]\[Wedge]EV[D], \(-\[ImaginaryI]\)\ OD[Q[1]] + 
        EV[H]\[Wedge]OD[S[1]] - 
        OD[S[1]]\[Wedge]EV[H], \(-\[ImaginaryI]\)\ OD[Q[2]] + 
        EV[H]\[Wedge]OD[S[2]] - 
        OD[S[2]]\[Wedge]EV[H], \[ImaginaryI]\ OD[Q[2]] + 
        EV[B]\[Wedge]OD[Q[1]] - 
        OD[Q[1]]\[Wedge]EV[B], \(-\[ImaginaryI]\)\ OD[Q[1]] + 
        EV[B]\[Wedge]OD[Q[2]] - 
        OD[Q[2]]\[Wedge]EV[B], \[ImaginaryI]\ OD[S[2]] + 
        EV[B]\[Wedge]OD[S[1]] - 
        OD[S[1]]\[Wedge]EV[B], \(-\[ImaginaryI]\)\ OD[S[1]] + 
        EV[B]\[Wedge]OD[S[2]] - OD[S[2]]\[Wedge]EV[B]}\)], "Output"]
}, Open  ]],

Cell["\<\
An explicit representation is given by the following 4x4 \
matrices:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    \(\(explicitMatRules = {EV[
              H] -> {{0, I, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}, \[IndentingNewLine]EV[
              D] -> {{\(-I\)/2, 0, 0, 0}, {0, I/2, 0, 0}, {0, 0, 0, 0}, {0, 
                0, 0, 0}}, \[IndentingNewLine]EV[
              K] -> {{0, 0, 0, 0}, {\(-I\), 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
                0}}, \[IndentingNewLine]EV[
              B] -> {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, \(-I\)\ }, {0, 0, 
                I\ , 0}}, \[IndentingNewLine]OD[
              Q[1]] -> {{0, 0, 0, 1}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 
                I\ /\((2\ )\), 0, 0}}, \[IndentingNewLine]OD[
              Q[2]] -> {{0, 0, 1, 0}, {0, 0, 0, 0}, {0, I/\((2)\), 0, 0}, {0, 
                0, 0, 0}}, \[IndentingNewLine]OD[
              S[1]] -> {{0, 0, 0, 0}, {0, 0, 0, 1}, {0, 0, 0, 
                0}, {\(-I\)/\((2)\), 0, 0, 0}}, \[IndentingNewLine]OD[
              S[2]] -> {{0, 0, 0, 0}, {0, 0, 1, 0}, {\(-I\)/\((2)\), 0, 0, 
                0}, {0, 0, 0, 0}}};\)\)], "Input"],

Cell[TextData[{
  "which verify that the expressions ",
  StyleBox["zeroComms",
    FontWeight->"Bold"],
  " vanish:"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(zeroCommsEXPL = zeroComms /. explicitMatRules\)], "Input"],

Cell[BoxData[
    \({{{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 
          0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 
          0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 
          0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 
          0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
          0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 
          0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
          0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 
          0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 
          0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 
          0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 
          0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 
          0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
          0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 
          0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
          0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 
          0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 
          0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Union[zeroQ /@ zeroCommsEXPL]\)], "Input"],

Cell[BoxData[
    \({True}\)], "Output"]
}, Open  ]],

Cell[TextData[
"\tThe group parameters corresponding to the generators {H, D, K, B, Q[i], \
S[j]} will be denoted by the symbols {-t, z, \[Omega], \[Alpha], \
gv[\[Eta][i]], gv[\[Lambda][j]]}, and the list of exponents in the \
parametrization of the group element (see eq. D 7 in the paper) will be \
written"], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(ExponentList = 
      I*MapThread[
          Wedge, {{\(-t\), z, \[Omega], \[Alpha], gv[\[Eta][1]], 
              gv[\[Eta][2]], gv[\[Lambda][1]], gv[\[Lambda][2]]}, {EV[H], 
              EV[D], EV[K], EV[B], OD[Q[1]], OD[Q[2]], OD[S[1]], 
              OD[S[2]]}}]\)], "Input"],

Cell[BoxData[
    \({\(-\[ImaginaryI]\)\ t\ EV[H], \[ImaginaryI]\ z\ EV[
          D], \[ImaginaryI]\ \[Omega]\ EV[K], \[ImaginaryI]\ \[Alpha]\ EV[
          B], \[ImaginaryI]\ gv[\[Eta][1]]\[Wedge]OD[
            Q[1]], \[ImaginaryI]\ gv[\[Eta][2]]\[Wedge]OD[
            Q[2]], \[ImaginaryI]\ gv[\[Lambda][1]]\[Wedge]OD[
            S[1]], \[ImaginaryI]\ gv[\[Lambda][2]]\[Wedge]OD[
            S[2]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(ReorderedExponentList = 
      Join[Drop[ExponentList, {4}], {ExponentList[\([4]\)]}]\)], "Input"],

Cell[BoxData[
    \({\(-\[ImaginaryI]\)\ t\ EV[H], \[ImaginaryI]\ z\ EV[
          D], \[ImaginaryI]\ \[Omega]\ EV[
          K], \[ImaginaryI]\ gv[\[Eta][1]]\[Wedge]OD[
            Q[1]], \[ImaginaryI]\ gv[\[Eta][2]]\[Wedge]OD[
            Q[2]], \[ImaginaryI]\ gv[\[Lambda][1]]\[Wedge]OD[
            S[1]], \[ImaginaryI]\ gv[\[Lambda][2]]\[Wedge]OD[
            S[2]], \[ImaginaryI]\ \[Alpha]\ EV[B]}\)], "Output"]
}, Open  ]],

Cell["\<\
Finally, in the symbolic matrices to be exponentiated, the Q[i] and \
S[i] terms are summed:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(groupMatExponents = 
      Join[Take[ReorderedExponentList, 
          3], {Plus @@ Take[ReorderedExponentList, {4, 5}]}, {Plus @@ 
            Take[ReorderedExponentList, {6, 
                7}]}, {ReorderedExponentList[\([\(-1\)]\)]}]\)], "Input"],

Cell[BoxData[
    \({\(-\[ImaginaryI]\)\ t\ EV[H], \[ImaginaryI]\ z\ EV[
          D], \[ImaginaryI]\ \[Omega]\ EV[
          K], \[ImaginaryI]\ gv[\[Eta][1]]\[Wedge]OD[
              Q[1]] + \[ImaginaryI]\ gv[\[Eta][2]]\[Wedge]OD[
              Q[2]], \[ImaginaryI]\ gv[\[Lambda][1]]\[Wedge]OD[
              S[1]] + \[ImaginaryI]\ gv[\[Lambda][2]]\[Wedge]OD[
              S[2]], \[ImaginaryI]\ \[Alpha]\ EV[B]}\)], "Output"]
}, Open  ]],

Cell["\<\
\tTo obtain the parametrized group element we must first \
exponentiate the matrices in this list. For the even exponents, we can use \
MatrixExp after substituting the explicit matrices for each EV[i_]. For the \
exponents with odd variables, we must use wedgeMatrixExp. However, if we just \
substitute the explicit (numerical) matrices for the OD[i_] as given above \
(explicitMatRules), we will miss the anticommutativity between the generators \
and the Grassmann variables in the series expansion of the exponentials! 
\tAlso, even matrices of the form gv[\[Eta][1]]\[Wedge]OD[Q[1]] will become \
odd: \
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(gv[\[Eta][1]]\[Wedge]OD[Q[1]] /. explicitMatRules\)], "Input"],

Cell[BoxData[
    \({{0, 0, 0, gv[\[Eta][1]]}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 
        1\/2\ \[ImaginaryI]\ gv[\[Eta][1]], 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[TextData[{
  " To get around this problem, i.e., to make the ",
  StyleBox["numbers",
    FontSlant->"Italic"],
  " in the odd explicit matrices behave as odd Grassmann variables, we will \
multiply all odd generators by a special symbol that (i) anticommutes with \
all gv[_], (ii) commutes with the OD[_] generators and (iii) its square \
equals 1. These properties ensure that the commutators are unaffected. \n\tWe \
will name this symbol \"od1\", and declare it as a matrix (= non-commuting \
variable) with special Wedge properties:\t"
}], "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeclareMatrixForms[{0, od1, od1}]\)], "Input"],

Cell[BoxData[
    \("Define GrassParity and ordering rule for symbolic matrices and gv[] \
variables!"\)], "Output",
  FontSize->16,
  FontSlant->"Italic",
  FontColor->RGBColor[1, 0, 1]],

Cell[BoxData[
    \("OK"\)], "Print"]
}, Open  ]],

Cell[BoxData[
    \(Wedge[od1, gv[i_]] := \(-Wedge[gv[i], od1]\); 
    Wedge[od1, d[gv[i_]]] := \(-Wedge[d[gv[i]], od1]\); 
    Wedge[od1, od1] = 1;\)], "Input"],

Cell[BoxData[
    \(Wedge[od1, EV[i_]] := Wedge[EV[i], od1]; 
    Wedge[od1, OD[i_]] := Wedge[OD[i], od1];\)], "Input"],

Cell["\<\
Also, for later use, we want d to treat the symbol od1 as a \
constant:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[BoxData[
    \(\(d[od1] = 0;\)\)], "Input"]
}, Closed]],

Cell["\<\
\tHaving defined the properties of od1, we replace the odd \
generators in zeroComms:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(zeroComms /. OD[i_] \[RuleDelayed] Wedge[OD[i], od1]\)], "Input"],

Cell[BoxData[
    \({\(-\[ImaginaryI]\)\ EV[H] - EV[D]\[Wedge]EV[H] + 
        EV[H]\[Wedge]EV[D], \[ImaginaryI]\ EV[K] - EV[D]\[Wedge]EV[K] + 
        EV[K]\[Wedge]EV[D], \(-2\)\ \[ImaginaryI]\ EV[D] + 
        EV[H]\[Wedge]EV[K] - EV[K]\[Wedge]EV[H], \(-EV[H]\) + 
        2\ OD[Q[1]]\[Wedge]OD[Q[1]], 
      OD[Q[1]]\[Wedge]OD[Q[2]] + OD[Q[2]]\[Wedge]OD[Q[1]], \(-EV[H]\) + 
        2\ OD[Q[2]]\[Wedge]OD[Q[2]], \(-EV[D]\) + OD[Q[1]]\[Wedge]OD[S[1]] + 
        OD[S[1]]\[Wedge]OD[Q[1]], \(-EV[D]\) + OD[Q[2]]\[Wedge]OD[S[2]] + 
        OD[S[2]]\[Wedge]OD[Q[2]], \(-\(EV[B]\/2\)\) + 
        OD[Q[1]]\[Wedge]OD[S[2]] + OD[S[2]]\[Wedge]OD[Q[1]], 
      EV[B]\/2 + OD[Q[2]]\[Wedge]OD[S[1]] + OD[S[1]]\[Wedge]OD[Q[2]], 
      1\/2\ \[ImaginaryI]\ OD[Q[1]]\[Wedge]od1 + 
        EV[D]\[Wedge]OD[Q[1]]\[Wedge]od1 - OD[Q[1]]\[Wedge]EV[D]\[Wedge]od1, 
      1\/2\ \[ImaginaryI]\ OD[Q[2]]\[Wedge]od1 + 
        EV[D]\[Wedge]OD[Q[2]]\[Wedge]od1 - 
        OD[Q[2]]\[Wedge]EV[
            D]\[Wedge]od1, \(-\(1\/2\)\)\ \[ImaginaryI]\ OD[
              S[1]]\[Wedge]od1 + EV[D]\[Wedge]OD[S[1]]\[Wedge]od1 - 
        OD[S[1]]\[Wedge]EV[
            D]\[Wedge]od1, \(-\(1\/2\)\)\ \[ImaginaryI]\ OD[
              S[2]]\[Wedge]od1 + EV[D]\[Wedge]OD[S[2]]\[Wedge]od1 - 
        OD[S[2]]\[Wedge]EV[
            D]\[Wedge]od1, \(-\[ImaginaryI]\)\ OD[Q[1]]\[Wedge]od1 + 
        EV[H]\[Wedge]OD[S[1]]\[Wedge]od1 - 
        OD[S[1]]\[Wedge]EV[
            H]\[Wedge]od1, \(-\[ImaginaryI]\)\ OD[Q[2]]\[Wedge]od1 + 
        EV[H]\[Wedge]OD[S[2]]\[Wedge]od1 - 
        OD[S[2]]\[Wedge]EV[
            H]\[Wedge]od1, \[ImaginaryI]\ OD[Q[2]]\[Wedge]od1 + 
        EV[B]\[Wedge]OD[Q[1]]\[Wedge]od1 - 
        OD[Q[1]]\[Wedge]EV[
            B]\[Wedge]od1, \(-\[ImaginaryI]\)\ OD[Q[1]]\[Wedge]od1 + 
        EV[B]\[Wedge]OD[Q[2]]\[Wedge]od1 - 
        OD[Q[2]]\[Wedge]EV[
            B]\[Wedge]od1, \[ImaginaryI]\ OD[S[2]]\[Wedge]od1 + 
        EV[B]\[Wedge]OD[S[1]]\[Wedge]od1 - 
        OD[S[1]]\[Wedge]EV[
            B]\[Wedge]od1, \(-\[ImaginaryI]\)\ OD[S[1]]\[Wedge]od1 + 
        EV[B]\[Wedge]OD[S[2]]\[Wedge]od1 - 
        OD[S[2]]\[Wedge]EV[B]\[Wedge]od1}\)], "Output"]
}, Open  ]],

Cell["\<\
The even commutators are unchanged, but the odd have an extra \
overall factor od1.\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(% /. explicitMatRules\)], "Input"],

Cell[BoxData[
    \({{{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 
          0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 
          0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 
          0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 
          0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
          0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 
          0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
          0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 
          0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 
          0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 
          0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 
          0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 
          0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
          0}, {0, 0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 
          0, 0, 0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 
          0}}, {{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 
          0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 0, 0, 
          0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(zeroQ[%]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell["\<\
\tWe are now ready to exponentiate the explicit matrices. First \
Wedge-multiply the odd generators by od1 and then substitute the explicit \
matrices in the list of exponents:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(EXPLICITgroupMatExponents = \(groupMatExponents /. 
          OD[i_] \[RuleDelayed] Wedge[OD[i], od1]\) /. 
        explicitMatRules\)], "Input"],

Cell[BoxData[
    \({{{0, t, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{z\/2, 0, 
          0, 0}, {0, \(-\(z\/2\)\), 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 
          0, 0, 0}, {\[Omega], 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}, {{0, 
          0, \[ImaginaryI]\ gv[\[Eta][
                  2]]\[Wedge]od1, \[ImaginaryI]\ gv[\[Eta][
                  1]]\[Wedge]od1}, {0, 0, 0, 
          0}, {0, \(-\(1\/2\)\)\ gv[\[Eta][2]]\[Wedge]od1, 0, 
          0}, {0, \(-\(1\/2\)\)\ gv[\[Eta][1]]\[Wedge]od1, 0, 0}}, {{0, 0, 0, 
          0}, {0, 0, \[ImaginaryI]\ gv[\[Lambda][
                  2]]\[Wedge]od1, \[ImaginaryI]\ gv[\[Lambda][
                  1]]\[Wedge]od1}, {1\/2\ gv[\[Lambda][2]]\[Wedge]od1, 0, 0, 
          0}, {1\/2\ gv[\[Lambda][1]]\[Wedge]od1, 0, 0, 0}}, {{0, 0, 0, 
          0}, {0, 0, 0, 0}, {0, 0, 0, \[Alpha]}, {0, 0, \(-\[Alpha]\), 
          0}}}\)], "Output"]
}, Open  ]],

Cell["\<\
As wedgeMatrixExp coincides with MatrixExp when odd variables are \
absent, we can exponentiate all of these matrices using wedgeMatrixExp:\
\>", \
"Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(groupElementMatrices = 
      wedgeMatrixExp /@ EXPLICITgroupMatExponents\)], "Input"],

Cell[BoxData[
    \({{{1, t, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 
          1}}, {{\[ExponentialE]\^\(z/2\), 0, 0, 
          0}, {0, \[ExponentialE]\^\(\(-z\)/2\), 0, 0}, {0, 0, 1, 0}, {0, 0, 
          0, 1}}, {{1, 0, 0, 0}, {\[Omega], 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 
          1}}, {{1, 
          0, \[ImaginaryI]\ gv[\[Eta][
                  2]]\[Wedge]od1, \[ImaginaryI]\ gv[\[Eta][
                  1]]\[Wedge]od1}, {0, 1, 0, 
          0}, {0, \(-\(1\/2\)\)\ gv[\[Eta][2]]\[Wedge]od1, 1, 
          0}, {0, \(-\(1\/2\)\)\ gv[\[Eta][1]]\[Wedge]od1, 0, 1}}, {{1, 0, 0, 
          0}, {0, 1, \[ImaginaryI]\ gv[\[Lambda][
                  2]]\[Wedge]od1, \[ImaginaryI]\ gv[\[Lambda][
                  1]]\[Wedge]od1}, {1\/2\ gv[\[Lambda][2]]\[Wedge]od1, 0, 1, 
          0}, {1\/2\ gv[\[Lambda][1]]\[Wedge]od1, 0, 0, 1}}, {{1, 0, 0, 
          0}, {0, 1, 0, 0}, {0, 0, Cos[\[Alpha]], Sin[\[Alpha]]}, {0, 
          0, \(-Sin[\[Alpha]]\), Cos[\[Alpha]]}}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions /@ groupElementMatrices\)], "Input"],

Cell[BoxData[
    \({{4, 4}, {4, 4}, {4, 4}, {4, 4}, {4, 4}, {4, 4}}\)], "Output"]
}, Open  ]],

Cell["\<\
Finally, to obtain the group element we Wedge-multiply these \
matrices together:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{"groupElement", "=", \(reWrite[Wedge @@ groupElementMatrices]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(equation\ D\ 7\),
          FontColor->RGBColor[0, 0, 1]], "  ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({{\[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\) - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z + t\ \[Omega])\)\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z + 
                t\ \[Omega])\)\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]], \[ExponentialE]\^\(\(-z\)/2\)\ t, \(-\[ImaginaryI]\)\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Cos[\[Alpha]]\ gv[\[Lambda][
                  2]]\[Wedge]od1, \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Sin[\[Alpha]]\ gv[\[Lambda][
                  2]]\[Wedge]od1}, {\[ExponentialE]\^\(\(-z\)/2\)\ \[Omega] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ gv[\
\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ gv[\
\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]], \[ExponentialE]\^\(\(-z\)/2\), \(-\[ImaginaryI]\)\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \[Omega]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Cos[\[Alpha]]\ gv[\[Lambda][
                  2]]\[Wedge]od1, \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \[Omega]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Sin[\[Alpha]]\ gv[\[Lambda][2]]\[Wedge]od1}, {1\/2\ gv[\[Lambda][
                2]]\[Wedge]od1, \(-\(1\/2\)\)\ gv[\[Eta][2]]\[Wedge]od1, 
        Cos[\[Alpha]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]], 
        Sin[\[Alpha]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]}, {1\/2\ gv[\[Lambda][
                1]]\[Wedge]od1, \(-\(1\/2\)\)\ gv[\[Eta][
                1]]\[Wedge]od1, \(-Sin[\[Alpha]]\) - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][2]], 
        Cos[\[Alpha]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][2]]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(Dimensions[groupElement]\)], "Input"],

Cell[BoxData[
    \({4, 4}\)], "Output"]
}, Open  ]],

Cell["\<\
This is an even (2, 2) supermatrix, odd terms having an extra od1 \
factor, which EvenGrassQ does not treat as a Grassmann variable -- otherwise \
all terms would be even!\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[groupElement, 2, 2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "\tTo compute the (left invariant) Maurer-Cartan form we need to calculate \
",
  Cell[BoxData[
      \(g\^\(-1\)\)]],
  " and ",
  StyleBox["d[g]",
    FontFamily->"Courier"],
  ". The inverse element can be computed in two ways: either by \
exponentiating the negative matrices (in the list ",
  StyleBox["EXPLICITgroupMatExponents",
    FontWeight->"Bold"],
  ") in reverse order, or by using the function superInverse (we use reWrite \
after each computation to collect similar terms and apply trigonometric \
simplification rules. ",
  StyleBox["Warning:",
    FontWeight->"Bold"],
  " ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " 3 cannot simplify the following calculations and gives wrong results!): "
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(InverseElement = 
      reWrite[Wedge @@ \((wedgeMatrixExp /@ 
              Reverse[\(-EXPLICITgroupMatExponents\)])\)]\)], "Input"],

Cell[BoxData[
    \({{\[ExponentialE]\^\(\(-z\)/2\), \(-\[ExponentialE]\^\(\(-z\)/2\)\)\ t, \
\(-\[ImaginaryI]\)\ gv[\[Eta][2]]\[Wedge]od1, \(-\[ImaginaryI]\)\ gv[\[Eta][
                1]]\[Wedge]od1}, {\(-\[ExponentialE]\^\(\(-z\)/2\)\)\ \
\[Omega] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ gv[\
\[Eta][1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ gv[\
\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]], \[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\) - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z + t\ \[Omega])\)\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z + 
                t\ \[Omega])\)\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]], \(-\[ImaginaryI]\)\ gv[\[Lambda][
                2]]\[Wedge]od1, \(-\[ImaginaryI]\)\ gv[\[Lambda][
                1]]\[Wedge]od1}, {1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \
\[Omega]\ Sin[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Cos[\[Alpha]]\ gv[\
\[Eta][2]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ Cos[\[Alpha]]\ gv[\[Lambda][
                  2]]\[Wedge]od1, \(-\(1\/2\)\)\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Sin[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Cos[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ Cos[\[Alpha]]\ gv[\[Lambda][
                  2]]\[Wedge]od1, 
        Cos[\[Alpha]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]], \(-Sin[\[Alpha]]\) - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][
                  2]]}, {\(-\(1\/2\)\)\ \[ExponentialE]\^\(\(-z\)/2\)\ \
\[Omega]\ Cos[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Sin[\[Alpha]]\ gv[\
\[Eta][2]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ Sin[\[Alpha]]\ gv[\[Lambda][
                  2]]\[Wedge]od1, 
        1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Cos[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Sin[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ Sin[\[Alpha]]\ gv[\[Lambda][
                  2]]\[Wedge]od1, 
        Sin[\[Alpha]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]], 
        Cos[\[Alpha]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][2]]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(superInverseElement = 
      reWrite[superInverse[groupElement, 2, 2]]\)], "Input"],

Cell[BoxData[
    \({{\[ExponentialE]\^\(\(-z\)/2\), \(-\[ExponentialE]\^\(\(-z\)/2\)\)\ t, \
\(-\[ImaginaryI]\)\ gv[\[Eta][2]]\[Wedge]od1, \(-\[ImaginaryI]\)\ gv[\[Eta][
                1]]\[Wedge]od1}, {\(-\[ExponentialE]\^\(\(-z\)/2\)\)\ \
\[Omega] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ gv[\
\[Eta][1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ gv[\
\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]], \[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\) - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z + t\ \[Omega])\)\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z + 
                t\ \[Omega])\)\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]], \(-\[ImaginaryI]\)\ gv[\[Lambda][
                2]]\[Wedge]od1, \(-\[ImaginaryI]\)\ gv[\[Lambda][
                1]]\[Wedge]od1}, {1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \
\[Omega]\ Sin[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Cos[\[Alpha]]\ gv[\
\[Eta][2]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ Cos[\[Alpha]]\ gv[\[Lambda][
                  2]]\[Wedge]od1, \(-\(1\/2\)\)\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Sin[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Cos[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ Cos[\[Alpha]]\ gv[\[Lambda][
                  2]]\[Wedge]od1, 
        Cos[\[Alpha]] + 
          1\/2\ \((Cos[\[Alpha]] - \[ImaginaryI]\ Sin[\[Alpha]])\)\ Sin[\
\[Alpha]]\ \((\(-\[ImaginaryI]\)\ Cos[\[Alpha]] + 
                Sin[\[Alpha]])\)\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]], \(-Sin[\[Alpha]]\) - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ Cos[\[Alpha]]\ \((Cos[\[Alpha]] + \[ImaginaryI]\ \
Sin[\[Alpha]])\)\ \((\[ImaginaryI]\ Cos[\[Alpha]] + 
                Sin[\[Alpha]])\)\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  2]]}, {\(-\(1\/2\)\)\ \[ExponentialE]\^\(\(-z\)/2\)\ \
\[Omega]\ Cos[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Sin[\[Alpha]]\ gv[\
\[Eta][2]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ Sin[\[Alpha]]\ gv[\[Lambda][
                  2]]\[Wedge]od1, 
        1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Cos[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Sin[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]od1 + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ Sin[\[Alpha]]\ gv[\[Lambda][
                  2]]\[Wedge]od1, 
        Sin[\[Alpha]] + 
          1\/2\ Cos[\[Alpha]]\ \((Cos[\[Alpha]] + \[ImaginaryI]\ \
Sin[\[Alpha]])\)\ \((\[ImaginaryI]\ Cos[\[Alpha]] + 
                Sin[\[Alpha]])\)\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]], 
        Cos[\[Alpha]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \((Cos[\[Alpha]] + \[ImaginaryI]\ Sin[\[Alpha]])\)\ Sin[\
\[Alpha]]\ \((\[ImaginaryI]\ Cos[\[Alpha]] + 
                Sin[\[Alpha]])\)\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  2]]}}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell["     We can check that these two inverses agree:", "Text",
  ShowGroupOpenCloseIcon->True,
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(superInverseElement === InverseElement\)], "Input"],

Cell[BoxData[
    \(False\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[superInverseElement - InverseElement]\)], "Input",
  FontColor->RGBColor[1, 0, 0]],

Cell[BoxData[
    \({{0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}, {0, 0, 0, 0}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[Wedge[groupElement, InverseElement]]\)], "Input"],

Cell[BoxData[
    \({{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(reWrite[Wedge[InverseElement, groupElement]]\)], "Input"],

Cell[BoxData[
    \({{1, 0, 0, 0}, {0, 1, 0, 0}, {0, 0, 1, 0}, {0, 0, 0, 1}}\)], "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(EvenGrassQ[InverseElement, 2, 2]\)], "Input"],

Cell[BoxData[
    \(True\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(dg = reWrite[d[groupElement]]\)], "Input"],

Cell[BoxData[
    \({{\[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ d[t] + 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z - 
                t\ \[Omega])\)\ d[
              z] + \[ExponentialE]\^\(\(-z\)/2\)\ t\ d[\[Omega]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z + t\ \[Omega])\)\ gv[\[Eta][1]]\[Wedge]d[
                gv[\[Lambda][1]]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z + t\ \[Omega])\)\ gv[\[Eta][2]]\[Wedge]d[
                gv[\[Lambda][2]]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z + t\ \[Omega])\)\ gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z + t\ \[Omega])\)\ gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][2]]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]] - 
          1\/4\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z - t\ \[Omega])\)\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/4\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z - t\ \[Omega])\)\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ d[\[Omega]]\
\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ d[\[Omega]]\
\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]], \[ExponentialE]\^\(\(-z\)/2\)\ d[t] - 
          1\/2\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ d[
              z], \(-\[ImaginaryI]\)\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z + t\ \[Omega])\)\ Sin[\[Alpha]]\ d[
                gv[\[Eta][
                    1]]]\[Wedge]od1 + \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Cos[\[Alpha]]\ d[
                gv[\[Eta][
                    2]]]\[Wedge]od1 - \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ t\ Sin[\[Alpha]]\ d[
                gv[\[Lambda][
                    1]]]\[Wedge]od1 + \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ t\ Cos[\[Alpha]]\ d[
                gv[\[Lambda][
                    2]]]\[Wedge]od1 - \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Cos[\[Alpha]]\ d[t]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z - t\ \[Omega])\)\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z - t\ \[Omega])\)\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ \
Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ \
Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1, \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Cos[\[Alpha]]\ d[
                gv[\[Eta][
                    1]]]\[Wedge]od1 + \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Sin[\[Alpha]]\ d[
                gv[\[Eta][
                    2]]]\[Wedge]od1 + \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ t\ Cos[\[Alpha]]\ d[
                gv[\[Lambda][
                    1]]]\[Wedge]od1 + \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ t\ Sin[\[Alpha]]\ d[
                gv[\[Lambda][
                    2]]]\[Wedge]od1 + \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \[Omega]\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Sin[\[Alpha]]\ d[t]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z - t\ \[Omega])\)\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \((\
\[ExponentialE]\^z - t\ \[Omega])\)\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ \
Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ t\ \
Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \((\[ExponentialE]\^z + 
                t\ \[Omega])\)\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Lambda][
                  
                  2]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ t\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1}, {\(-\(1\/2\)\)\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ d[
              z] + \[ExponentialE]\^\(\(-z\)/2\)\ d[\[Omega]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ gv[\
\[Eta][1]]\[Wedge]d[gv[\[Lambda][1]]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ gv[\
\[Eta][2]]\[Wedge]d[gv[\[Lambda][2]]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ gv[\
\[Lambda][1]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ gv[\
\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]] + 
          1\/4\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/4\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ d[\[Omega]]\
\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ d[\[Omega]]\
\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]], \(-\(1\/2\)\)\ \[ExponentialE]\^\(\(-z\)/2\)\ d[
            z], \(-\[ImaginaryI]\)\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[
                gv[\[Eta][
                    1]]]\[Wedge]od1 + \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                gv[\[Eta][
                    2]]]\[Wedge]od1 - \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ Sin[\[Alpha]]\ d[
                gv[\[Lambda][
                    1]]]\[Wedge]od1 + \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ Cos[\[Alpha]]\ d[
                gv[\[Lambda][2]]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Sin[\
\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Cos[\
\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ Sin[\[Alpha]]\ \
d[z]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ Cos[\[Alpha]]\ \
d[z]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \[Omega]\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \[Omega]\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1, \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                gv[\[Eta][
                    1]]]\[Wedge]od1 + \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Sin[\[Alpha]]\ d[
                gv[\[Eta][
                    2]]]\[Wedge]od1 + \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ Cos[\[Alpha]]\ d[
                gv[\[Lambda][
                    1]]]\[Wedge]od1 + \[ImaginaryI]\ \
\[ExponentialE]\^\(\(-z\)/2\)\ Sin[\[Alpha]]\ d[
                gv[\[Lambda][2]]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Cos[\
\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ \[Omega]\ Sin[\
\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ Cos[\[Alpha]]\ \
d[z]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\)\ Sin[\[Alpha]]\ \
d[z]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \[Omega]\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ \[Omega]\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 - \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 + \[ImaginaryI]\ \[ExponentialE]\^\(\(-z\)/2\
\)\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][2]]\[Wedge]od1}, {1\/2\ d[
              gv[\[Lambda][2]]]\[Wedge]od1, \(-\(1\/2\)\)\ d[
              gv[\[Eta][2]]]\[Wedge]od1, \(-d[\[Alpha]]\)\ Sin[\[Alpha]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]d[
                gv[\[Lambda][1]]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]d[
                gv[\[Lambda][2]]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][2]]] - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][2]]] - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]], 
        Cos[\[Alpha]]\ d[\[Alpha]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]d[
                gv[\[Lambda][1]]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]d[
                gv[\[Lambda][2]]] - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][2]]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][2]]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]}, {1\/2\ d[
              gv[\[Lambda][1]]]\[Wedge]od1, \(-\(1\/2\)\)\ d[
              gv[\[Eta][1]]]\[Wedge]od1, \(-Cos[\[Alpha]]\)\ d[\[Alpha]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]d[
                gv[\[Lambda][1]]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]d[
                gv[\[Lambda][2]]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][1]]] - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][1]]] - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][
                  2]], \(-d[\[Alpha]]\)\ Sin[\[Alpha]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]d[
                gv[\[Lambda][1]]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]d[
                gv[\[Lambda][2]]] - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][1]]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][1]]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Alpha]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][2]]}}\)], "Output"]
}, Closed]],

Cell[TextData[{
  "Note that Wedge is used also for multiplication of Grassmann variables \
with the 1-forms d[t], d[z], etc. Finally, we compute the \
Left-Invariant-Maurer-Cartan form = ",
  StyleBox["-i",
    FontFamily->"Courier"],
  Cell[BoxData[
      \(g\^\(-1\)\)]],
  StyleBox["d[g]",
    FontFamily->"Courier"],
  ":"
}], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(LeftInvMCform = 
        reWrite[\(-I\)\ superWedge[InverseElement, dg, 2, 2]]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(first\ equation\ 2.2\),
          FontColor->RGBColor[0, 0, 1]], "  ", "*)"}]}]], "Input"],

Cell[BoxData[
    \({{\(-\[ImaginaryI]\)\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[t] - 
          1\/2\ \[ImaginaryI]\ d[z] + 
          1\/2\ gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]] - 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]] - 
          1\/4\ d[z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/4\ d[z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]], \(-\[ImaginaryI]\)\ \[ExponentialE]\^\(-z\)\ d[t] - 
          1\/2\ gv[\[Eta][1]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/2\ gv[\[Eta][2]]\[Wedge]d[gv[\[Eta][2]]], \(-Sin[\[Alpha]]\)\ d[
                gv[\[Eta][1]]]\[Wedge]od1 + 
          Cos[\[Alpha]]\ d[
                gv[\[Eta][
                    2]]]\[Wedge]od1 - \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 + \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 - \[ExponentialE]\^\(-z\)\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 + \[ExponentialE]\^\(-z\)\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][1]]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][1]]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][2]]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][2]]]\[Wedge]od1, 
        Cos[\[Alpha]]\ d[gv[\[Eta][1]]]\[Wedge]od1 + 
          Sin[\[Alpha]]\ d[
                gv[\[Eta][
                    2]]]\[Wedge]od1 + \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 + \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 + \[ExponentialE]\^\(-z\)\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 + \[ExponentialE]\^\(-z\)\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][1]]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][1]]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][2]]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][
                    2]]]\[Wedge]od1}, {\[ImaginaryI]\ \[ExponentialE]\^\(-z\)\
\ \[Omega]\^2\ d[t] + \[ImaginaryI]\ \[Omega]\ d[
              z] - \[ImaginaryI]\ d[\[Omega]] + 
          1\/2\ gv[\[Lambda][1]]\[Wedge]d[gv[\[Lambda][1]]] + 
          1\/2\ gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Lambda][2]]] + \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]] + \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]] + \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] + \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]] - 
          d[\[Omega]]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          d[\[Omega]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][
                  2]], \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
              t] + 1\/2\ \[ImaginaryI]\ d[z] - 
          1\/2\ gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/2\ gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]] + 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]] + 
          1\/4\ d[z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] + 
          1\/4\ d[z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]], \(-Sin[\[Alpha]]\)\ d[gv[\[Lambda][1]]]\[Wedge]od1 + 
          Cos[\[Alpha]]\ d[
                gv[\[Lambda][
                    2]]]\[Wedge]od1 + \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ \
Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 - \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Cos[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 + \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 - \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1 + \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 - \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 + 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 - 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][1]]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][2]]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Cos[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Sin[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/4\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/4\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1, 
        Cos[\[Alpha]]\ d[gv[\[Lambda][1]]]\[Wedge]od1 + 
          Sin[\[Alpha]]\ d[
                gv[\[Lambda][
                    2]]]\[Wedge]od1 - \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ \
Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 - \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Sin[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 - \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 - \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1 - \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 - \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 - 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 - 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][1]]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][2]]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Sin[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Cos[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/4\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/4\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1}, {1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                gv[\[Lambda][1]]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                gv[\[Lambda][2]]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Sin[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Cos[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[t]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[t]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 - 
          1\/4\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 + 
          1\/4\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 + 
          1\/4\ Cos[\[Alpha]]\ gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]d[gv[\[Eta][1]]]\[Wedge]od1 + 
          1\/4\ Sin[\[Alpha]]\ gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]d[gv[\[Eta][2]]]\[Wedge]od1 - 
          1\/4\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 - 
          1\/4\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/4\ \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/4\ \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/4\ \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 - 
          1\/4\ \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/8\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/8\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/4\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 + 
          1\/4\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1, \(-\(1\/2\)\)\ \[ImaginaryI]\ Sin[\[Alpha]]\
\ d[gv[\[Eta][1]]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[gv[\[Eta][2]]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/4\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/4\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 + 
          1\/4\ Sin[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][1]]]\[Wedge]od1 - 
          1\/4\ Cos[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][1]]]\[Wedge]od1 + 
          1\/4\ Sin[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][2]]]\[Wedge]od1 - 
          1\/4\ Cos[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][2]]]\[Wedge]od1, 
        0, \(-\[ImaginaryI]\)\ d[\[Alpha]] - 
          1\/2\ gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][2]]] + 
          1\/2\ gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]] - 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ExponentialE]\^\(-z\)\ d[
                t]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[Omega]\ d[z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]] - 
          1\/4\ d[z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/4\ d[z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ d[\[Omega]]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]] + 
          1\/4\ \[ImaginaryI]\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/4\ \[ImaginaryI]\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][
                    2]]]}, {\(-\(1\/2\)\)\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                gv[\[Lambda][1]]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                gv[\[Lambda][2]]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Cos[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Sin[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[t]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[t]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 + 
          1\/4\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 + 
          1\/4\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]od1 - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]od1 + 
          1\/4\ Sin[\[Alpha]]\ gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]d[gv[\[Eta][1]]]\[Wedge]od1 - 
          1\/4\ Cos[\[Alpha]]\ gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]d[gv[\[Eta][2]]]\[Wedge]od1 - 
          1\/4\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 + 
          1\/4\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/4\ \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/4\ \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/4\ \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 + 
          1\/4\ \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/8\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 - 
          1\/8\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/4\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]od1 - 
          1\/4\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]od1, 
        1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[gv[\[Eta][1]]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[gv[\[Eta][2]]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][1]]\[Wedge]od1 + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]]\[Wedge]od1 + 
          1\/4\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]od1 + 
          1\/4\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]od1 - 
          1\/4\ Cos[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][1]]]\[Wedge]od1 - 
          1\/4\ Sin[\[Alpha]]\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][1]]]\[Wedge]od1 - 
          1\/4\ Cos[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][2]]]\[Wedge]od1 - 
          1\/4\ Sin[\[Alpha]]\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][2]]]\[Wedge]od1, \[ImaginaryI]\ d[\[Alpha]] + 
          1\/2\ gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][2]]] - 
          1\/2\ gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]] + 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ExponentialE]\^\(-z\)\ d[
                t]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[Omega]\ d[z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]] + 
          1\/4\ d[z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/4\ d[z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ d[\[Omega]]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]] - 
          1\/4\ \[ImaginaryI]\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/4\ \[ImaginaryI]\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]], 
        0}}\)], "Output"]
}, Closed]],

Cell[BoxData[
    RowBox[{\( (*\(\(*\)\(\ \)\(testZero\)\) = 
          reWrite[d[LeftInvMCform] + I\ LeftInvMCform\[Wedge]LeftInvMCform] // 
            Timing\ **) \), 
      RowBox[{"(*", " ", 
        StyleBox[\(this\ calculation\ takes\ \(long!\)\),
          FontColor->RGBColor[0, 0, 1]], "  ", "*)"}]}]], "Input"],

Cell["\<\
\tThis LeftInvMCform can be written as a formal sum of individual \
components multiplying the corresponding generators (we denote by MC[X] the \
MC 1-form corresponding to the generator X):\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(generatorList = {EV[H], EV[D], EV[K], EV[B], OD[Q[1]], OD[Q[2]], 
          OD[S[1]], OD[S[2]]} /. 
        OD[i_] \[RuleDelayed] Wedge[OD[i], od1]\)], "Input"],

Cell[BoxData[
    \({EV[H], EV[D], EV[K], EV[B], OD[Q[1]]\[Wedge]od1, OD[Q[2]]\[Wedge]od1, 
      OD[S[1]]\[Wedge]od1, OD[S[2]]\[Wedge]od1}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(DeclareForms[1, MC[_]]\)], "Input"],

Cell[BoxData[
    \("OK"\)], "Print"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(MCforms = \(generatorList /. {EV \[Rule] MC, OD \[Rule] MC}\) /. 
        od1 \[Rule] 1\)], "Input"],

Cell[BoxData[
    \({MC[H], MC[D], MC[K], MC[B], MC[Q[1]], MC[Q[2]], MC[S[1]], 
      MC[S[2]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    RowBox[{\(formalMCsum = Inner[Wedge, MCforms, generatorList]\), 
      RowBox[{"(*", " ", 
        StyleBox[\(second\ equation\ 2.2\),
          FontColor->RGBColor[0, 0, 1]], "  ", "*)"}]}]], "Input"],

Cell[BoxData[
    \(MC[B]\[Wedge]EV[B] + MC[D]\[Wedge]EV[D] + MC[H]\[Wedge]EV[H] + 
      MC[K]\[Wedge]EV[K] + MC[Q[1]]\[Wedge]OD[Q[1]]\[Wedge]od1 + 
      MC[Q[2]]\[Wedge]OD[Q[2]]\[Wedge]od1 + 
      MC[S[1]]\[Wedge]OD[S[1]]\[Wedge]od1 + 
      MC[S[2]]\[Wedge]OD[S[2]]\[Wedge]od1\)], "Output"]
}, Open  ]],

Cell["In matrix form this sum is:", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(formalMCsumMatrix = formalMCsum /. explicitMatRules\)], "Input"],

Cell[BoxData[
    \({{\(-\(1\/2\)\)\ \[ImaginaryI]\ MC[D], \[ImaginaryI]\ MC[H], 
        MC[Q[2]]\[Wedge]od1, 
        MC[Q[1]]\[Wedge]od1}, {\(-\[ImaginaryI]\)\ MC[K], 
        1\/2\ \[ImaginaryI]\ MC[D], MC[S[2]]\[Wedge]od1, 
        MC[S[1]]\[Wedge]od1}, {\(-\(1\/2\)\)\ \[ImaginaryI]\ MC[
              S[2]]\[Wedge]od1, 1\/2\ \[ImaginaryI]\ MC[Q[2]]\[Wedge]od1, 
        0, \(-\[ImaginaryI]\)\ MC[
            B]}, {\(-\(1\/2\)\)\ \[ImaginaryI]\ MC[S[1]]\[Wedge]od1, 
        1\/2\ \[ImaginaryI]\ MC[Q[1]]\[Wedge]od1, \[ImaginaryI]\ MC[B], 
        0}}\)], "Output"]
}, Open  ]],

Cell["\<\
\tWe can now solve for the individual components by equating this \
to the LeftInvMCform computed earlier, after getting rid of the od1 factors \
which appear in all odd elements:\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(MCformSolution = 
      reWrite[\(Solve[
            LeftInvMCform \[Equal] formalMCsumMatrix /. od1 \[Rule] 1, 
            MCforms]\)[\([1]\)]]\)], "Input"],

Cell[BoxData[
    \({MC[H] \[Rule] \(-\[ExponentialE]\^\(-z\)\)\ d[t] + 
          1\/2\ \[ImaginaryI]\ gv[\[Eta][1]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ gv[\[Eta][2]]\[Wedge]d[gv[\[Eta][2]]], 
      MC[K] \[Rule] \(-\[ExponentialE]\^\(-z\)\)\ \[Omega]\^2\ d[
              t] - \[Omega]\ d[z] + d[\[Omega]] + 
          1\/2\ \[ImaginaryI]\ gv[\[Lambda][1]]\[Wedge]d[gv[\[Lambda][1]]] + 
          1\/2\ \[ImaginaryI]\ gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Lambda][
                    2]]] + \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \
\[Omega]\^2\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]] + \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ \
d[t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]] + \[ImaginaryI]\ \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]] + \[ImaginaryI]\ \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]] - \[ImaginaryI]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][
                  1]] - \[ImaginaryI]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ d[\[Omega]]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]], 
      MC[Q[1]] \[Rule] 
        Cos[\[Alpha]]\ d[gv[\[Eta][1]]] + 
          d[gv[\[Eta][
                  2]]]\ Sin[\[Alpha]] + \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  1]] + \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  2]] + \[ExponentialE]\^\(-z\)\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]] + \[ExponentialE]\^\(-z\)\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][1]] + 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][2]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][2]]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]], 
      MC[D] \[Rule] 
        2\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[t] + 
          d[z] + \[ImaginaryI]\ gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][1]]] + \[ImaginaryI]\ gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][
                    2]]] - \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]] - \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]], 
      MC[Q[2]] \[Rule] 
        Cos[\[Alpha]]\ d[gv[\[Eta][2]]] - 
          d[gv[\[Eta][
                  1]]]\ Sin[\[Alpha]] - \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  1]] + \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  2]] - \[ExponentialE]\^\(-z\)\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]] + \[ExponentialE]\^\(-z\)\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][1]] + 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][2]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][2]]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]], 
      MC[B] \[Rule] 
        d[\[Alpha]] - 
          1\/2\ \[ImaginaryI]\ gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][2]]] + 
          1\/2\ \[ImaginaryI]\ gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ d[
                t]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]] - 
          1\/4\ \[ImaginaryI]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/4\ \[ImaginaryI]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]] - 
          1\/4\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/4\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]d[gv[\[Eta][2]]], 
      MC[S[1]] \[Rule] 
        Cos[\[Alpha]]\ d[gv[\[Lambda][1]]] + 
          d[gv[\[Lambda][
                  2]]]\ Sin[\[Alpha]] - \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ \
Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  1]] - \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Sin[\[Alpha]]\ \
d[t]\[Wedge]gv[\[Eta][
                  2]] - \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]] - \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]] - \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]] - \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]] - 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][2]] + 
          Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][1]] + 
          Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][2]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Sin[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]] + 1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \
\[Omega]\^2\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]] + 
          1\/4\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/4\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]], 
      MC[S[2]] \[Rule] 
        Cos[\[Alpha]]\ d[gv[\[Lambda][2]]] - 
          d[gv[\[Lambda][
                  1]]]\ Sin[\[Alpha]] + \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ \
Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  1]] - \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Cos[\[Alpha]]\ \
d[t]\[Wedge]gv[\[Eta][
                  2]] + \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]] - \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]] + \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]] - \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]] + 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][2]] - 
          Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][1]] + 
          Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][2]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Cos[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]] - 1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \
\[Omega]\^2\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]] + 
          1\/4\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/4\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]]}\)], "Output"]
}, Closed]],

Cell[CellGroupData[{

Cell[BoxData[
    \(evenMCforms = 
      Select[MCformSolution, EvenGrassQ[#[\([2]\)]] &]\)], "Input"],

Cell[BoxData[
    \({MC[H] \[Rule] \(-\[ExponentialE]\^\(-z\)\)\ d[t] + 
          1\/2\ \[ImaginaryI]\ gv[\[Eta][1]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ gv[\[Eta][2]]\[Wedge]d[gv[\[Eta][2]]], 
      MC[K] \[Rule] \(-\[ExponentialE]\^\(-z\)\)\ \[Omega]\^2\ d[
              t] - \[Omega]\ d[z] + d[\[Omega]] + 
          1\/2\ \[ImaginaryI]\ gv[\[Lambda][1]]\[Wedge]d[gv[\[Lambda][1]]] + 
          1\/2\ \[ImaginaryI]\ gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Lambda][
                    2]]] + \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \
\[Omega]\^2\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]] + \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ \
d[t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]] + \[ImaginaryI]\ \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]] + \[ImaginaryI]\ \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]] - \[ImaginaryI]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][
                  1]] - \[ImaginaryI]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ d[\[Omega]]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]], 
      MC[D] \[Rule] 
        2\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[t] + 
          d[z] + \[ImaginaryI]\ gv[\[Lambda][1]]\[Wedge]d[
                gv[\[Eta][1]]] + \[ImaginaryI]\ gv[\[Lambda][2]]\[Wedge]d[
                gv[\[Eta][
                    2]]] - \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]] - \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]], 
      MC[B] \[Rule] 
        d[\[Alpha]] - 
          1\/2\ \[ImaginaryI]\ gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][2]]] + 
          1\/2\ \[ImaginaryI]\ gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ d[
                t]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]] - 
          1\/4\ \[ImaginaryI]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/4\ \[ImaginaryI]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]] - 
          1\/4\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/4\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][
                  2]]\[Wedge]d[gv[\[Eta][2]]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(oddMCforms = 
      Select[MCformSolution, \(! EvenGrassQ[#[\([2]\)]]\) &]\)], "Input"],

Cell[BoxData[
    \({MC[Q[1]] \[Rule] 
        Cos[\[Alpha]]\ d[gv[\[Eta][1]]] + 
          d[gv[\[Eta][
                  2]]]\ Sin[\[Alpha]] + \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  1]] + \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  2]] + \[ExponentialE]\^\(-z\)\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]] + \[ExponentialE]\^\(-z\)\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][1]] + 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][2]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][2]]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]], 
      MC[Q[2]] \[Rule] 
        Cos[\[Alpha]]\ d[gv[\[Eta][2]]] - 
          d[gv[\[Eta][
                  1]]]\ Sin[\[Alpha]] - \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  1]] + \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  2]] - \[ExponentialE]\^\(-z\)\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]] + \[ExponentialE]\^\(-z\)\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][1]] + 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Eta][2]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[gv[\[Eta][2]]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]], 
      MC[S[1]] \[Rule] 
        Cos[\[Alpha]]\ d[gv[\[Lambda][1]]] + 
          d[gv[\[Lambda][
                  2]]]\ Sin[\[Alpha]] - \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ \
Cos[\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][
                  1]] - \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Sin[\[Alpha]]\ \
d[t]\[Wedge]gv[\[Eta][
                  2]] - \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]] - \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]] - \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]] - \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]] - 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][2]] + 
          Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][1]] + 
          Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][2]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Sin[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]] + 1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \
\[Omega]\^2\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]] + 
          1\/4\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/4\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]], 
      MC[S[2]] \[Rule] 
        Cos[\[Alpha]]\ d[gv[\[Lambda][2]]] - 
          d[gv[\[Lambda][
                  1]]]\ Sin[\[Alpha]] + \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ \
Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][
                  1]] - \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Cos[\[Alpha]]\ \
d[t]\[Wedge]gv[\[Eta][
                  2]] + \[ExponentialE]\^\(-z\)\ \[Omega]\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][
                  1]] - \[ExponentialE]\^\(-z\)\ \[Omega]\ Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Lambda][2]] + \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]] - \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]] + 
          1\/2\ Sin[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ Cos[\[Alpha]]\ d[z]\[Wedge]gv[\[Lambda][2]] - 
          Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][1]] + 
          Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][2]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][1]]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[gv[\[Eta][2]]] - 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ Cos[\
\[Alpha]]\ d[t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]] - 1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \
\[Omega]\^2\ Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Cos[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ \
Sin[\[Alpha]]\ d[
                t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][1]] - 
          1\/2\ \[ImaginaryI]\ \[Omega]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                  2]]\[Wedge]gv[\[Lambda][2]] + 
          1\/4\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/4\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[
                z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  1]]\[Wedge]gv[\[Lambda][2]] + 
          1\/2\ \[ImaginaryI]\ Cos[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]] + 
          1\/2\ \[ImaginaryI]\ Sin[\[Alpha]]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                  1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                  2]]}\)], "Output"]
}, Closed]],

Cell[TextData[
"\tThe odd vector components are simpler if we perform a rotation with angle \
-\[Alpha]:"], "Text",
  Evaluatable->False,
  FontSize->16],

Cell[CellGroupData[{

Cell[BoxData[
    \(RotationMat = {{Cos[\[Alpha]], Sin[\[Alpha]]}, {\(-Sin[\[Alpha]]\), 
          Cos[\[Alpha]]}}\)], "Input"],

Cell[BoxData[
    \({{Cos[\[Alpha]], Sin[\[Alpha]]}, {\(-Sin[\[Alpha]]\), 
        Cos[\[Alpha]]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(InverseRotationMat = {{Cos[\[Alpha]], \(-Sin[\[Alpha]]\)}, \
{Sin[\[Alpha]], Cos[\[Alpha]]}}\)], "Input"],

Cell[BoxData[
    \({{Cos[\[Alpha]], \(-Sin[\[Alpha]]\)}, {Sin[\[Alpha]], 
        Cos[\[Alpha]]}}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RotatedVector[Q12] = 
      reWrite[InverseRotationMat . {MC[Q[1]], MC[Q[2]]} /. 
          oddMCforms]\)], "Input"],

Cell[BoxData[
    \({d[gv[\[Eta][1]]] + \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
              t]\[Wedge]gv[\[Eta][1]] + \[ExponentialE]\^\(-z\)\ d[
              t]\[Wedge]gv[\[Lambda][1]] + 1\/2\ d[z]\[Wedge]gv[\[Eta][1]] + 
        1\/2\ \[ImaginaryI]\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[
              gv[\[Eta][1]]] + 
        1\/2\ \[ImaginaryI]\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]]\[Wedge]d[
              gv[\[Eta][2]]], 
      d[gv[\[Eta][2]]] + \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
              t]\[Wedge]gv[\[Eta][2]] + \[ExponentialE]\^\(-z\)\ d[
              t]\[Wedge]gv[\[Lambda][2]] + 1\/2\ d[z]\[Wedge]gv[\[Eta][2]] + 
        1\/2\ \[ImaginaryI]\ gv[\[Eta][1]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
              gv[\[Eta][1]]] + 
        1\/2\ \[ImaginaryI]\ gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]]\[Wedge]d[
              gv[\[Eta][2]]]}\)], "Output"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[
    \(RotatedVector[S12] = 
      reWrite[InverseRotationMat . {MC[S[1]], MC[S[2]]} /. 
          oddMCforms]\)], "Input"],

Cell[BoxData[
    \({d[gv[\[Lambda][1]]] - \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
              t]\[Wedge]gv[\[Eta][1]] - \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
              t]\[Wedge]gv[\[Lambda][1]] - \[Omega]\ d[
              z]\[Wedge]gv[\[Eta][1]] - 1\/2\ d[z]\[Wedge]gv[\[Lambda][1]] + 
        d[\[Omega]]\[Wedge]gv[\[Eta][1]] - 
        1\/2\ \[ImaginaryI]\ gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][
                2]]\[Wedge]d[gv[\[Eta][2]]] + 
        1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
              t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                2]]\[Wedge]gv[\[Lambda][2]] - 
        1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
              t]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                1]]\[Wedge]gv[\[Lambda][2]] + 
        1\/2\ \[ImaginaryI]\ \[Omega]\ d[
              z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                2]]\[Wedge]gv[\[Lambda][2]] - 
        1\/4\ \[ImaginaryI]\ d[
              z]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][
                1]]\[Wedge]gv[\[Lambda][2]] - 
        1\/2\ \[ImaginaryI]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][2]], 
      d[gv[\[Lambda][2]]] - \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
              t]\[Wedge]gv[\[Eta][2]] - \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
              t]\[Wedge]gv[\[Lambda][2]] - \[Omega]\ d[
              z]\[Wedge]gv[\[Eta][2]] - 1\/2\ d[z]\[Wedge]gv[\[Lambda][2]] + 
        d[\[Omega]]\[Wedge]gv[\[Eta][2]] + 
        1\/2\ \[ImaginaryI]\ gv[\[Lambda][1]]\[Wedge]gv[\[Lambda][
                2]]\[Wedge]d[gv[\[Eta][1]]] - 
        1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\^2\ d[
              t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                2]]\[Wedge]gv[\[Lambda][1]] + 
        1\/2\ \[ImaginaryI]\ \[ExponentialE]\^\(-z\)\ \[Omega]\ d[
              t]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                1]]\[Wedge]gv[\[Lambda][2]] - 
        1\/2\ \[ImaginaryI]\ \[Omega]\ d[
              z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Eta][
                2]]\[Wedge]gv[\[Lambda][1]] + 
        1\/4\ \[ImaginaryI]\ d[
              z]\[Wedge]gv[\[Eta][1]]\[Wedge]gv[\[Lambda][
                1]]\[Wedge]gv[\[Lambda][2]] + 
        1\/2\ \[ImaginaryI]\ d[\[Omega]]\[Wedge]gv[\[Eta][
                1]]\[Wedge]gv[\[Eta][2]]\[Wedge]gv[\[Lambda][1]]}\)], "Output"]
}, Open  ]],

Cell["\<\
Apart from notational differences, these expressions agree with \
those in the paper (see D 9).\
\>", "Text",
  Evaluatable->False,
  FontSize->16],

Cell["\<\

\
\>", "Text"]
}, Closed]]
}, Closed]],

Cell[TextData[StyleBox["",
  FontSlant->"Italic"]], "Text",
  Evaluatable->False]
},
FrontEndVersion->"4.0 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 748}},
WindowToolbars->{},
CellGrouping->Manual,
WindowSize->{956, 719},
WindowMargins->{{6, Automatic}, {Automatic, 3}},
PrivateNotebookOptions->{"ColorPalette"->{RGBColor, -1}},
ShowCellLabel->True,
ShowCellTags->False,
RenderingOptions->{"ObjectDithering"->True,
"RasterDithering"->False},
Magnification->1.25,
MacintoshSystemPageSetup->"\<\
0040001804P000000aP2I0000003609To`83609T0@00001804P000000aP2I001
0@00I00100000@0200000BL?00400000000000000000051`I6H0I00000000000
00000000000000000000000000000000\>"
]


(***********************************************************************
Cached data follows.  If you edit this Notebook file directly, not using
Mathematica, you must remove the line containing CacheID at the top of 
the file.  The cache data will then be recreated when you save this file 
from within Mathematica.
***********************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1739, 51, 113, 3, 134, "Title",
  Evaluatable->False],
Cell[1855, 56, 151, 5, 41, "Text"],
Cell[2009, 63, 1358, 47, 185, "Text"]
}, Closed]],
Cell[3382, 113, 1388, 42, 180, "Text",
  Evaluatable->False],
Cell[4773, 157, 555, 20, 89, "Text",
  Evaluatable->False],
Cell[5331, 179, 38, 1, 33, "Input"],
Cell[5372, 182, 236, 9, 41, "Text"],
Cell[5611, 193, 567, 14, 113, "Text",
  Evaluatable->False],
Cell[6181, 209, 46, 1, 33, "Input"],

Cell[CellGroupData[{
Cell[6252, 214, 49, 1, 33, "Input"],
Cell[6304, 217, 37, 1, 33, "Output"]
}, Open  ]],
Cell[6356, 221, 38, 1, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[6419, 226, 89, 2, 75, "Subtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[6533, 232, 162, 7, 73, "Section",
  Evaluatable->False],
Cell[6698, 241, 542, 16, 89, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[7265, 261, 109, 2, 33, "Input"],
Cell[7377, 265, 85, 1, 33, "Output"]
}, Open  ]],
Cell[7477, 269, 494, 17, 89, "Text",
  Evaluatable->False],
Cell[7974, 288, 197, 6, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[8196, 298, 124, 2, 33, "Input"],
Cell[8323, 302, 117, 2, 33, "Output"]
}, Open  ]],
Cell[8455, 307, 146, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[8626, 316, 161, 2, 33, "Input"],
Cell[8790, 320, 322, 5, 52, "Output"]
}, Open  ]],
Cell[9127, 328, 111, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[9263, 334, 43, 1, 33, "Input"],
Cell[9309, 337, 281, 5, 52, "Output"]
}, Open  ]],
Cell[9605, 345, 198, 7, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[9828, 356, 43, 1, 33, "Input"],
Cell[9874, 359, 956, 25, 58, "Output"]
}, Open  ]],
Cell[10845, 387, 494, 15, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[11364, 406, 64, 1, 33, "Input"],
Cell[11431, 409, 64, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[11532, 415, 285, 8, 36, "Input"],
Cell[11820, 425, 318, 9, 36, "Output"]
}, Open  ]],
Cell[12153, 437, 184, 5, 65, "Text",
  Evaluatable->False],
Cell[12340, 444, 87, 1, 52, "Input"],
Cell[12430, 447, 162, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[12617, 456, 58, 1, 33, "Input"],
Cell[12678, 459, 58, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12773, 465, 61, 1, 33, "Input"],
Cell[12837, 468, 72, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[12946, 474, 58, 1, 33, "Input"],
Cell[13007, 477, 35, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[13079, 483, 58, 1, 33, "Input"],
Cell[13140, 486, 69, 1, 33, "Output"]
}, Open  ]],
Cell[13224, 490, 269, 7, 89, "Text",
  Evaluatable->False]
}, Closed]],
Cell[13508, 500, 38, 1, 31, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[13571, 505, 222, 7, 106, "Section",
  Evaluatable->False],
Cell[13796, 514, 131, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[13952, 523, 252, 5, 52, "Input"],
Cell[14207, 530, 231, 4, 52, "Output"]
}, Open  ]],
Cell[14453, 537, 274, 11, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[14752, 552, 45, 1, 33, "Input"],
Cell[14800, 555, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[14875, 561, 45, 1, 33, "Input"],
Cell[14923, 564, 217, 3, 52, "Output"]
}, Open  ]],
Cell[15155, 570, 486, 10, 113, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[15666, 584, 51, 1, 33, "Input"],
Cell[15720, 587, 56, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15813, 593, 52, 1, 33, "Input"],
Cell[15868, 596, 56, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[15961, 602, 57, 1, 33, "Input"],
Cell[16021, 605, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16096, 611, 88, 1, 33, "Input"],
Cell[16187, 614, 135, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16359, 621, 109, 2, 33, "Input"],
Cell[16471, 625, 120, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16628, 632, 55, 1, 33, "Input"],
Cell[16686, 635, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16761, 641, 54, 1, 33, "Input"],
Cell[16818, 644, 39, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[16894, 650, 56, 1, 33, "Input"],
Cell[16953, 653, 35, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17025, 659, 55, 1, 33, "Input"],
Cell[17083, 662, 35, 1, 33, "Output"]
}, Open  ]],
Cell[17133, 666, 362, 13, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[17520, 683, 46, 1, 33, "Input"],
Cell[17569, 686, 64, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[17670, 692, 47, 1, 33, "Input"],
Cell[17720, 695, 64, 1, 28, "Print"]
}, Open  ]],
Cell[17799, 699, 650, 17, 137, "Text",
  Evaluatable->False]
}, Closed]],
Cell[18464, 719, 81, 2, 31, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[18570, 725, 220, 8, 106, "Section",
  Evaluatable->False],
Cell[18793, 735, 1075, 33, 161, "Text",
  Evaluatable->False],
Cell[19871, 770, 235, 8, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20131, 782, 43, 1, 57, "Subsection"],
Cell[20177, 785, 150, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[20352, 794, 129, 3, 33, "Input"],
Cell[20484, 799, 401, 6, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[20922, 810, 48, 1, 33, "Input"],
Cell[20973, 813, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21048, 819, 66, 1, 33, "Input"],
Cell[21117, 822, 64, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21218, 828, 49, 1, 33, "Input"],
Cell[21270, 831, 35, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21342, 837, 48, 1, 33, "Input"],
Cell[21393, 840, 64, 1, 33, "Output"]
}, Open  ]],
Cell[21472, 844, 101, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[21598, 850, 46, 1, 33, "Input"],
Cell[21647, 853, 119, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[21803, 860, 48, 1, 33, "Input"],
Cell[21854, 863, 606, 9, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[22497, 877, 46, 1, 33, "Input"],
Cell[22546, 880, 762, 13, 166, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[23345, 898, 48, 1, 33, "Input"],
Cell[23396, 901, 2749, 45, 477, "Output"]
}, Open  ]],
Cell[26160, 949, 146, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[26331, 958, 53, 1, 33, "Input"],
Cell[26387, 961, 101, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26525, 968, 53, 1, 33, "Input"],
Cell[26581, 971, 126, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[26744, 978, 53, 1, 33, "Input"],
Cell[26800, 981, 551, 9, 131, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[27388, 995, 53, 1, 33, "Input"],
Cell[27444, 998, 666, 13, 128, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[28159, 1017, 48, 1, 36, "Subsection"],
Cell[28210, 1020, 792, 32, 89, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[29027, 1056, 137, 3, 33, "Input"],
Cell[29167, 1061, 417, 7, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[29621, 1073, 51, 1, 33, "Input"],
Cell[29675, 1076, 2518, 44, 419, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[32230, 1125, 51, 1, 33, "Input"],
Cell[32284, 1128, 67, 1, 33, "Output"]
}, Open  ]],
Cell[32366, 1132, 141, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[32532, 1141, 145, 3, 33, "Input"],
Cell[32680, 1146, 578, 8, 127, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[33295, 1159, 140, 3, 33, "Input"],
Cell[33438, 1164, 570, 9, 127, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34045, 1178, 45, 1, 33, "Input"],
Cell[34093, 1181, 35, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[34165, 1187, 56, 1, 33, "Input"],
Cell[34224, 1190, 442, 7, 109, "Output"]
}, Open  ]],
Cell[34681, 1200, 183, 5, 65, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[34901, 1210, 50, 1, 36, "Subsection"],
Cell[34954, 1213, 499, 18, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[35478, 1235, 85, 1, 33, "Input"],
Cell[35566, 1238, 358, 6, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[35961, 1249, 51, 1, 33, "Input"],
Cell[36015, 1252, 600, 10, 137, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36652, 1267, 56, 1, 33, "Input"],
Cell[36711, 1270, 67, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[36815, 1276, 55, 1, 33, "Input"],
Cell[36873, 1279, 106, 2, 53, "Output"]
}, Open  ]],
Cell[36994, 1284, 109, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[37128, 1290, 64, 1, 33, "Input"],
Cell[37195, 1293, 39, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37271, 1299, 66, 1, 33, "Input"],
Cell[37340, 1302, 49, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[37426, 1308, 56, 1, 33, "Input"],
Cell[37485, 1311, 49, 1, 28, "Print"]
}, Open  ]],
Cell[37549, 1315, 54, 2, 41, "Text",
  Evaluatable->False],
Cell[37606, 1319, 533, 16, 89, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[38164, 1339, 84, 1, 33, "Input"],
Cell[38251, 1342, 408, 6, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[38696, 1353, 80, 1, 33, "Input"],
Cell[38779, 1356, 12627, 258, 1793, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[51443, 1619, 72, 1, 28, "Input"],
Cell[51518, 1622, 108, 2, 33, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[51675, 1630, 60, 1, 36, "Subsection"],
Cell[51738, 1633, 475, 18, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[52238, 1655, 46, 1, 33, "Input"],
Cell[52287, 1658, 844, 14, 166, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[53168, 1677, 879, 28, 137, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[54072, 1709, 292, 4, 52, "Input"],
Cell[54367, 1715, 279, 4, 52, "Output"]
}, Open  ]],
Cell[54661, 1722, 209, 7, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[54895, 1733, 48, 1, 33, "Input"],
Cell[54946, 1736, 85, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55068, 1742, 379, 9, 33, "Input"],
Cell[55450, 1753, 85, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[55572, 1759, 382, 9, 33, "Input"],
Cell[55957, 1770, 85, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[56079, 1776, 381, 9, 33, "Input"],
Cell[56463, 1787, 103, 2, 33, "Output"]
}, Open  ]]
}, Closed]],
Cell[56593, 1793, 353, 13, 60, "Text"],
Cell[56949, 1808, 64, 1, 33, "Input"],

Cell[CellGroupData[{
Cell[57038, 1813, 93, 1, 33, "Input"],
Cell[57134, 1816, 67, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[57238, 1822, 89, 1, 33, "Input"],
Cell[57330, 1825, 67, 1, 33, "Output"]
}, Open  ]],
Cell[57412, 1829, 38, 1, 36, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[57487, 1835, 44, 1, 36, "Subsection"],
Cell[57534, 1838, 454, 18, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[58013, 1860, 131, 3, 33, "Input"],
Cell[58147, 1865, 116, 2, 33, "Output"]
}, Open  ]],
Cell[58278, 1870, 183, 7, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[58486, 1881, 43, 1, 33, "Input"],
Cell[58532, 1884, 718, 19, 57, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[59287, 1908, 48, 1, 33, "Input"],
Cell[59338, 1911, 845, 23, 57, "Output"]
}, Open  ]],
Cell[60198, 1937, 140, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[60363, 1946, 51, 1, 33, "Input"],
Cell[60417, 1949, 955, 25, 79, "Output"]
}, Open  ]],
Cell[61387, 1977, 257, 10, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[61669, 1991, 63, 1, 33, "Input"],
Cell[61735, 1994, 70, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[61842, 2000, 75, 1, 33, "Input"],
Cell[61920, 2003, 47, 1, 33, "Output"]
}, Open  ]],
Cell[61982, 2007, 100, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[62107, 2013, 163, 2, 52, "Input"],
Cell[62273, 2017, 35, 1, 33, "Output"]
}, Open  ]],
Cell[62323, 2021, 213, 7, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[62561, 2032, 125, 3, 33, "Input"],
Cell[62689, 2037, 93, 1, 33, "Output"]
}, Open  ]],
Cell[62797, 2041, 273, 5, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[63095, 2050, 169, 3, 52, "Input"],
Cell[63267, 2055, 35, 1, 33, "Output"]
}, Open  ]],
Cell[63317, 2059, 509, 13, 113, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[63851, 2076, 87, 1, 33, "Input"],
Cell[63941, 2079, 76, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[64054, 2085, 87, 1, 33, "Input"],
Cell[64144, 2088, 71, 1, 33, "Output"]
}, Open  ]],
Cell[64230, 2092, 297, 13, 41, "Text",
  Evaluatable->False],
Cell[64530, 2107, 262, 4, 52, "Input"],

Cell[CellGroupData[{
Cell[64817, 2115, 51, 1, 33, "Input"],
Cell[64871, 2118, 2370, 61, 101, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67278, 2184, 55, 1, 33, "Input"],
Cell[67336, 2187, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[67411, 2193, 49, 1, 33, "Input"],
Cell[67463, 2196, 2825, 73, 123, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[70337, 2275, 52, 1, 36, "Subsection"],
Cell[70392, 2278, 412, 16, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[70829, 2298, 260, 9, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[71114, 2311, 65, 1, 33, "Input"],
Cell[71182, 2314, 84, 1, 36, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71303, 2320, 65, 1, 33, "Input"],
Cell[71371, 2323, 314, 4, 54, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[71722, 2332, 70, 1, 33, "Input"],
Cell[71795, 2335, 169, 3, 33, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[72013, 2344, 350, 14, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[72388, 2362, 153, 2, 33, "Input"],
Cell[72544, 2366, 166, 2, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72747, 2373, 99, 2, 33, "Input"],
Cell[72849, 2377, 2155, 43, 696, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[75041, 2425, 104, 2, 28, "Input"],
Cell[75148, 2429, 2164, 39, 696, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[77349, 2473, 53, 1, 28, "Input"],
Cell[77405, 2476, 67, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[77509, 2482, 64, 1, 33, "Input"],
Cell[77576, 2485, 67, 1, 33, "Output"]
}, Open  ]],
Cell[77658, 2489, 344, 7, 89, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[78027, 2500, 36, 1, 33, "Input"],
Cell[78066, 2503, 401, 6, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[78504, 2514, 52, 1, 33, "Input"],
Cell[78559, 2517, 96, 2, 28, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[78704, 2525, 350, 14, 36, "Text",
  Evaluatable->False],
Cell[79057, 2541, 108, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[79190, 2547, 68, 1, 33, "Input"],
Cell[79261, 2550, 187, 5, 63, "Output"],
Cell[79451, 2557, 37, 1, 28, "Print"]
}, Open  ]],
Cell[79503, 2561, 333, 8, 89, "Text",
  Evaluatable->False],
Cell[79839, 2571, 103, 2, 52, "Input"],
Cell[79945, 2575, 593, 11, 147, "Input"],

Cell[CellGroupData[{
Cell[80563, 2590, 84, 1, 33, "Input"],
Cell[80650, 2593, 125, 2, 33, "Output"]
}, Open  ]],
Cell[80790, 2598, 128, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[80943, 2607, 89, 2, 33, "Input"],
Cell[81035, 2611, 96, 2, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[81168, 2618, 155, 3, 33, "Input"],
Cell[81326, 2623, 6094, 99, 698, "Output"]
}, Closed]],
Cell[87435, 2725, 418, 10, 84, "Text",
  Evaluatable->False],
Cell[87856, 2737, 203, 3, 52, "Input"],

Cell[CellGroupData[{
Cell[88084, 2744, 87, 1, 33, "Input"],
Cell[88174, 2747, 684, 11, 162, "Output"]
}, Open  ]],
Cell[88873, 2761, 126, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[89024, 2770, 82, 1, 33, "Input"],
Cell[89109, 2773, 78, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[89224, 2779, 177, 5, 33, "Input"],
Cell[89404, 2786, 684, 11, 162, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90125, 2802, 40, 1, 33, "Input"],
Cell[90168, 2805, 50, 1, 33, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[90267, 2812, 246, 9, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[90538, 2825, 109, 2, 33, "Input"],
Cell[90650, 2829, 92, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[90779, 2835, 89, 2, 33, "Input"],
Cell[90871, 2839, 216, 4, 36, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]]
}, Closed]],
Cell[91138, 2849, 258, 8, 84, "Text",
  Evaluatable->False]
}, Closed]],
Cell[91411, 2860, 38, 1, 31, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[91474, 2865, 85, 2, 75, "Subtitle",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[91584, 2871, 225, 7, 106, "Section",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[91834, 2882, 61, 1, 57, "Subsection"],
Cell[91898, 2885, 1026, 22, 185, "Text",
  Evaluatable->False],
Cell[92927, 2909, 235, 8, 41, "Text",
  Evaluatable->False],
Cell[93165, 2919, 376, 9, 89, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[93566, 2932, 92, 1, 33, "Input"],
Cell[93661, 2935, 74, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[93772, 2941, 196, 5, 52, "Input"],
Cell[93971, 2948, 204, 3, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[94212, 2956, 192, 5, 52, "Input"],
Cell[94407, 2963, 223, 4, 52, "Output"]
}, Open  ]],
Cell[94645, 2970, 556, 19, 89, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[95226, 2993, 192, 3, 33, "Input"],
Cell[95421, 2998, 373, 6, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[95831, 3009, 180, 5, 33, "Input"],
Cell[96014, 3016, 407, 6, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[96458, 3027, 180, 5, 33, "Input"],
Cell[96641, 3034, 403, 6, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[97081, 3045, 218, 4, 33, "Input"],
Cell[97302, 3051, 196, 3, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[97535, 3059, 63, 1, 33, "Input"],
Cell[97601, 3062, 60, 1, 33, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[97710, 3069, 118, 4, 36, "Subsection"],

Cell[CellGroupData[{
Cell[97853, 3077, 378, 10, 89, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[98256, 3091, 202, 4, 33, "Input"],
Cell[98461, 3097, 1331, 24, 223, "Output"]
}, Open  ]],
Cell[99807, 3124, 127, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[99959, 3133, 508, 14, 33, "Input"],
Cell[100470, 3149, 554, 8, 109, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[101061, 3162, 48, 1, 33, "Input"],
Cell[101112, 3165, 895, 18, 125, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102044, 3188, 67, 1, 33, "Input"],
Cell[102114, 3191, 416, 9, 125, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102567, 3205, 206, 4, 33, "Input"],
Cell[102776, 3211, 86, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[102899, 3217, 205, 4, 33, "Input"],
Cell[103107, 3223, 86, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[103230, 3229, 191, 4, 33, "Input"],
Cell[103424, 3235, 86, 1, 28, "Print"]
}, Open  ]],
Cell[103525, 3239, 128, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[103678, 3248, 280, 6, 52, "Input"],
Cell[103961, 3256, 1177, 20, 185, "Output"]
}, Open  ]],
Cell[105153, 3279, 91, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[105269, 3285, 181, 5, 33, "Input"],
Cell[105453, 3292, 58, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[105548, 3298, 59, 1, 33, "Input"],
Cell[105610, 3301, 936, 15, 166, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106583, 3321, 205, 4, 33, "Input"],
Cell[106791, 3327, 86, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[106914, 3333, 191, 4, 33, "Input"],
Cell[107108, 3339, 86, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[107231, 3345, 225, 4, 33, "Input"],
Cell[107459, 3351, 1300, 21, 204, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[108808, 3378, 325, 11, 60, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[109158, 3393, 136, 3, 33, "Input"],
Cell[109297, 3398, 378, 5, 109, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[109712, 3408, 134, 3, 33, "Input"],
Cell[109849, 3413, 391, 6, 109, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[110301, 3426, 56, 1, 36, "Subsection"],
Cell[110360, 3429, 1112, 41, 137, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[111497, 3474, 58, 1, 33, "Input"],
Cell[111558, 3477, 529, 8, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112124, 3490, 64, 1, 33, "Input"],
Cell[112191, 3493, 109, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112337, 3500, 64, 1, 33, "Input"],
Cell[112404, 3503, 208, 3, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112649, 3511, 59, 1, 33, "Input"],
Cell[112711, 3514, 109, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[112857, 3521, 59, 1, 33, "Input"],
Cell[112919, 3524, 208, 3, 71, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113164, 3532, 201, 6, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[113390, 3542, 58, 1, 33, "Input"],
Cell[113451, 3545, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113526, 3551, 68, 1, 33, "Input"],
Cell[113597, 3554, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113672, 3560, 63, 1, 33, "Input"],
Cell[113738, 3563, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113813, 3569, 63, 1, 33, "Input"],
Cell[113879, 3572, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[113954, 3578, 63, 1, 33, "Input"],
Cell[114020, 3581, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[114095, 3587, 63, 1, 33, "Input"],
Cell[114161, 3590, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[114236, 3596, 58, 1, 33, "Input"],
Cell[114297, 3599, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[114372, 3605, 68, 1, 33, "Input"],
Cell[114443, 3608, 38, 1, 33, "Output"]
}, Open  ]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[114542, 3616, 86, 1, 36, "Subsection"],
Cell[114631, 3619, 956, 27, 161, "Text",
  Evaluatable->False],
Cell[115590, 3648, 676, 22, 113, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[116291, 3674, 185, 4, 33, "Input"],
Cell[116479, 3680, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116554, 3686, 184, 4, 33, "Input"],
Cell[116741, 3692, 39, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[116817, 3698, 192, 4, 33, "Input"],
Cell[117012, 3704, 83, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117132, 3710, 187, 4, 33, "Input"],
Cell[117322, 3716, 56, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117415, 3722, 191, 4, 33, "Input"],
Cell[117609, 3728, 83, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[117729, 3734, 198, 4, 33, "Input"],
Cell[117930, 3740, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118005, 3746, 204, 4, 33, "Input"],
Cell[118212, 3752, 83, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118332, 3758, 407, 9, 52, "Input"],
Cell[118742, 3769, 39, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[118818, 3775, 253, 6, 33, "Input"],
Cell[119074, 3783, 64, 1, 28, "Print"]
}, Open  ]],
Cell[119153, 3787, 173, 5, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[119351, 3796, 186, 4, 33, "Input"],
Cell[119540, 3802, 35, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[119612, 3808, 185, 4, 33, "Input"],
Cell[119800, 3814, 35, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[119872, 3820, 408, 9, 52, "Input"],
Cell[120283, 3831, 35, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[120355, 3837, 254, 6, 33, "Input"],
Cell[120612, 3845, 64, 1, 28, "Print"]
}, Open  ]],
Cell[120691, 3849, 551, 11, 113, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[121279, 3865, 89, 1, 36, "Subsection"],
Cell[121371, 3868, 126, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[121522, 3877, 51, 1, 33, "Input"],
Cell[121576, 3880, 4657, 83, 724, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[126270, 3968, 69, 1, 28, "Input"],
Cell[126342, 3971, 654, 11, 128, "Output"]
}, Open  ]],
Cell[127011, 3985, 87, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[127123, 3991, 52, 1, 33, "Input"],
Cell[127178, 3994, 39, 1, 33, "Output"]
}, Open  ]],
Cell[127232, 3998, 133, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[127390, 4007, 57, 1, 33, "Input"],
Cell[127450, 4010, 722, 13, 173, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[128209, 4028, 52, 1, 33, "Input"],
Cell[128264, 4031, 83, 1, 28, "Print"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[128386, 4037, 38, 1, 31, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[128449, 4042, 222, 8, 106, "Section",
  Evaluatable->False],
Cell[128674, 4052, 886, 24, 137, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[129585, 4080, 48, 1, 57, "Subsection"],
Cell[129636, 4083, 404, 8, 113, "Text",
  Evaluatable->False],
Cell[130043, 4093, 107, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[130175, 4099, 216, 4, 33, "Input"],
Cell[130394, 4105, 821, 13, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[131252, 4123, 217, 4, 33, "Input"],
Cell[131472, 4129, 821, 13, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[132330, 4147, 39, 1, 33, "Input"],
Cell[132372, 4150, 128, 2, 33, "Output"]
}, Open  ]],
Cell[132515, 4155, 106, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[132646, 4161, 215, 4, 33, "Input"],
Cell[132864, 4167, 822, 14, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[133723, 4186, 216, 4, 33, "Input"],
Cell[133942, 4192, 886, 13, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[134865, 4210, 39, 1, 33, "Input"],
Cell[134907, 4213, 128, 2, 33, "Output"]
}, Open  ]],
Cell[135050, 4218, 272, 8, 65, "Text",
  Evaluatable->False],
Cell[135325, 4228, 101, 2, 33, "Input"],
Cell[135429, 4232, 434, 10, 89, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[135888, 4246, 70, 1, 33, "Input"],
Cell[135961, 4249, 128, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136126, 4256, 70, 1, 33, "Input"],
Cell[136199, 4259, 128, 2, 33, "Output"]
}, Open  ]],
Cell[136342, 4264, 298, 7, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[136665, 4275, 90, 1, 33, "Input"],
Cell[136758, 4278, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[136833, 4284, 90, 1, 33, "Input"],
Cell[136926, 4287, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[137001, 4293, 90, 1, 33, "Input"],
Cell[137094, 4296, 38, 1, 33, "Output"]
}, Open  ]],
Cell[137147, 4300, 106, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[137278, 4306, 45, 1, 33, "Input"],
Cell[137326, 4309, 2416, 43, 385, "Output"]
}, Open  ]],
Cell[139757, 4355, 96, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[139878, 4361, 54, 1, 33, "Input"],
Cell[139935, 4364, 38, 1, 33, "Output"]
}, Open  ]],
Cell[139988, 4368, 146, 5, 41, "Text",
  Evaluatable->False],
Cell[140137, 4375, 328, 8, 33, "Input"],

Cell[CellGroupData[{
Cell[140490, 4387, 335, 8, 33, "Input"],
Cell[140828, 4397, 100, 2, 28, "Print"]
}, Open  ]],
Cell[140943, 4402, 384, 9, 52, "Input"],

Cell[CellGroupData[{
Cell[141352, 4415, 183, 6, 52, "Subsubsection",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[141560, 4425, 74, 1, 33, "Input"],
Cell[141637, 4428, 83, 1, 28, "Print"],
Cell[141723, 4431, 83, 1, 28, "Print"],
Cell[141809, 4434, 83, 1, 28, "Print"],
Cell[141895, 4437, 83, 1, 28, "Print"],
Cell[141981, 4440, 83, 1, 28, "Print"],
Cell[142067, 4443, 64, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142168, 4449, 74, 1, 33, "Input"],
Cell[142245, 4452, 83, 1, 28, "Print"],
Cell[142331, 4455, 83, 1, 28, "Print"],
Cell[142417, 4458, 83, 1, 28, "Print"],
Cell[142503, 4461, 83, 1, 28, "Print"],
Cell[142589, 4464, 64, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[142690, 4470, 68, 1, 33, "Input"],
Cell[142761, 4473, 67, 1, 33, "Output"]
}, Open  ]]
}, Closed]],
Cell[142855, 4478, 248, 6, 60, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[143128, 4488, 127, 3, 33, "Input"],
Cell[143258, 4493, 109, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[143404, 4500, 69, 1, 33, "Input"],
Cell[143476, 4503, 792, 13, 147, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[144305, 4521, 69, 1, 33, "Input"],
Cell[144377, 4524, 712, 12, 128, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145126, 4541, 84, 1, 33, "Input"],
Cell[145213, 4544, 100, 2, 28, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[145362, 4552, 48, 1, 36, "Subsection"],
Cell[145413, 4555, 289, 12, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[145727, 4571, 53, 1, 33, "Input"],
Cell[145783, 4574, 157, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[145977, 4581, 60, 1, 33, "Input"],
Cell[146040, 4584, 182, 3, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146259, 4592, 60, 1, 33, "Input"],
Cell[146322, 4595, 137, 3, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146496, 4603, 62, 1, 33, "Input"],
Cell[146561, 4606, 35, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[146633, 4612, 53, 1, 33, "Input"],
Cell[146689, 4615, 100, 2, 28, "Print"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[146838, 4623, 52, 1, 36, "Subsection"],
Cell[146893, 4626, 360, 13, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[147278, 4643, 66, 1, 33, "Input"],
Cell[147347, 4646, 1371, 24, 223, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[148755, 4675, 73, 1, 33, "Input"],
Cell[148831, 4678, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[148906, 4684, 73, 1, 33, "Input"],
Cell[148982, 4687, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149057, 4693, 78, 1, 33, "Input"],
Cell[149138, 4696, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149213, 4702, 83, 1, 33, "Input"],
Cell[149299, 4705, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[149374, 4711, 70, 1, 33, "Input"],
Cell[149447, 4714, 1380, 21, 223, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[150864, 4740, 62, 1, 33, "Input"],
Cell[150929, 4743, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151004, 4749, 72, 1, 33, "Input"],
Cell[151079, 4752, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151154, 4758, 72, 1, 33, "Input"],
Cell[151229, 4761, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151304, 4767, 62, 1, 33, "Input"],
Cell[151369, 4770, 38, 1, 33, "Output"]
}, Open  ]],
Cell[151422, 4774, 193, 7, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[151640, 4785, 78, 1, 33, "Input"],
Cell[151721, 4788, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[151796, 4794, 132, 3, 52, "Subsubsection"],
Cell[151931, 4799, 898, 18, 185, "Text",
  Evaluatable->False],
Cell[152832, 4819, 1018, 29, 209, "Text",
  Evaluatable->False],
Cell[153853, 4850, 406, 12, 89, "Text",
  Evaluatable->False],
Cell[154262, 4864, 421, 10, 89, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[154708, 4878, 157, 6, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[154890, 4888, 64, 1, 33, "Input"],
Cell[154957, 4891, 378, 5, 109, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[155372, 4901, 62, 1, 33, "Input"],
Cell[155437, 4904, 430, 7, 109, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[155904, 4916, 76, 1, 33, "Input"],
Cell[155983, 4919, 38, 1, 33, "Output"]
}, Open  ]],
Cell[156036, 4923, 148, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[156209, 4932, 70, 1, 33, "Input"],
Cell[156282, 4935, 417, 6, 109, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[156736, 4946, 70, 1, 33, "Input"],
Cell[156809, 4949, 501, 8, 109, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[157347, 4962, 70, 1, 33, "Input"],
Cell[157420, 4965, 407, 6, 109, "Output"]
}, Open  ]],
Cell[157842, 4974, 393, 17, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[158260, 4995, 119, 2, 33, "Input"],
Cell[158382, 4999, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[158457, 5005, 119, 2, 33, "Input"],
Cell[158579, 5009, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[158654, 5015, 119, 2, 33, "Input"],
Cell[158776, 5019, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[158851, 5025, 119, 2, 33, "Input"],
Cell[158973, 5029, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[159048, 5035, 211, 4, 33, "Input"],
Cell[159262, 5041, 92, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[159391, 5047, 219, 4, 33, "Input"],
Cell[159613, 5053, 109, 2, 33, "Output"]
}, Open  ]]
}, Closed]],
Cell[159749, 5059, 81, 2, 31, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[159855, 5065, 146, 3, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[160026, 5072, 62, 1, 33, "Input"],
Cell[160091, 5075, 391, 6, 109, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[160519, 5086, 61, 1, 33, "Input"],
Cell[160583, 5089, 430, 7, 109, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161050, 5101, 75, 1, 33, "Input"],
Cell[161128, 5104, 38, 1, 33, "Output"]
}, Open  ]],
Cell[161181, 5108, 148, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[161354, 5117, 69, 1, 33, "Input"],
Cell[161426, 5120, 430, 7, 109, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[161893, 5132, 69, 1, 33, "Input"],
Cell[161965, 5135, 411, 6, 109, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[162413, 5146, 69, 1, 33, "Input"],
Cell[162485, 5149, 510, 9, 109, "Output"]
}, Open  ]],
Cell[163010, 5161, 393, 17, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[163428, 5182, 117, 2, 33, "Input"],
Cell[163548, 5186, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163623, 5192, 117, 2, 33, "Input"],
Cell[163743, 5196, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[163818, 5202, 117, 2, 33, "Input"],
Cell[163938, 5206, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164013, 5212, 117, 2, 33, "Input"],
Cell[164133, 5216, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164208, 5222, 209, 4, 33, "Input"],
Cell[164420, 5228, 113, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[164570, 5235, 217, 4, 33, "Input"],
Cell[164790, 5241, 103, 2, 33, "Output"],
Cell[164896, 5245, 81, 2, 36, "Text",
  Evaluatable->False]
}, Open  ]]
}, Closed]],
Cell[165004, 5251, 81, 2, 31, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[165110, 5257, 260, 11, 41, "Text",
  Evaluatable->False],
Cell[165373, 5270, 301, 6, 52, "Input"],

Cell[CellGroupData[{
Cell[165699, 5280, 86, 1, 33, "Input"],
Cell[165788, 5283, 49, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[165874, 5289, 166, 4, 33, "Input"],
Cell[166043, 5295, 128, 2, 33, "Output"]
}, Open  ]],
Cell[166186, 5300, 52, 1, 52, "Input"],
Cell[166241, 5303, 299, 6, 52, "Input"],

Cell[CellGroupData[{
Cell[166565, 5313, 86, 1, 33, "Input"],
Cell[166654, 5316, 49, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[166740, 5322, 165, 4, 33, "Input"],
Cell[166908, 5328, 128, 2, 33, "Output"]
}, Open  ]]
}, Closed]],
Cell[167063, 5334, 81, 2, 31, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[167169, 5340, 193, 6, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[167387, 5350, 54, 1, 33, "Input"],
Cell[167444, 5353, 257, 4, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[167738, 5362, 53, 1, 33, "Input"],
Cell[167794, 5365, 291, 5, 70, "Output"]
}, Open  ]],
Cell[168100, 5373, 224, 4, 33, "Input"],

Cell[CellGroupData[{
Cell[168349, 5381, 188, 3, 52, "Input"],
Cell[168540, 5386, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[168615, 5392, 186, 3, 52, "Input"],
Cell[168804, 5397, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[168879, 5403, 186, 3, 52, "Input"],
Cell[169068, 5408, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[169143, 5414, 363, 8, 71, "Input"],
Cell[169509, 5424, 38, 1, 70, "Output"]
}, Open  ]],
Cell[169562, 5428, 81, 2, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[169668, 5434, 395, 7, 73, "Input"],
Cell[170066, 5443, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[170141, 5449, 856, 20, 73, "Input"],
Cell[171000, 5471, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[171075, 5477, 379, 6, 73, "Input"],
Cell[171457, 5485, 38, 1, 70, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[171532, 5491, 859, 20, 73, "Input"],
Cell[172394, 5513, 38, 1, 70, "Output"]
}, Open  ]],
Cell[172447, 5517, 265, 8, 65, "Text",
  Evaluatable->False]
}, Closed]]
}, Closed]],
Cell[172739, 5529, 81, 2, 31, "Text",
  Evaluatable->False]
}, Closed]],

Cell[CellGroupData[{
Cell[172857, 5536, 53, 1, 36, "Subsection"],
Cell[172913, 5539, 421, 13, 89, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[173359, 5556, 65, 1, 33, "Input"],
Cell[173427, 5559, 1300, 21, 204, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174764, 5585, 55, 1, 33, "Input"],
Cell[174822, 5588, 83, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[174942, 5594, 55, 1, 33, "Input"],
Cell[175000, 5597, 38, 1, 33, "Output"]
}, Open  ]],
Cell[175053, 5601, 729, 26, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[175807, 5631, 67, 1, 33, "Input"],
Cell[175877, 5634, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[175952, 5640, 654, 16, 52, "Input"],
Cell[176609, 5658, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[176684, 5664, 654, 16, 52, "Input"],
Cell[177341, 5682, 38, 1, 33, "Output"]
}, Open  ]],
Cell[177394, 5686, 876, 29, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[178295, 5719, 519, 12, 52, "Input"],
Cell[178817, 5733, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[178892, 5739, 519, 12, 52, "Input"],
Cell[179414, 5753, 38, 1, 33, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[179501, 5760, 50, 1, 36, "Subsection"],
Cell[179554, 5763, 441, 16, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[180020, 5783, 166, 4, 33, "Input"],
Cell[180189, 5789, 4561, 70, 917, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[184787, 5864, 75, 1, 28, "Input"],
Cell[184865, 5867, 128, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[185030, 5874, 75, 1, 33, "Input"],
Cell[185108, 5877, 128, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[185273, 5884, 343, 10, 33, "Input"],
Cell[185619, 5896, 49, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[185705, 5902, 343, 10, 33, "Input"],
Cell[186051, 5914, 49, 1, 28, "Print"]
}, Open  ]],
Cell[186115, 5918, 591, 18, 113, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[186731, 5940, 922, 24, 54, "Input"],
Cell[187656, 5966, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[187731, 5972, 954, 24, 73, "Input"],
Cell[188688, 5998, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[188763, 6004, 1140, 30, 73, "Input"],
Cell[189906, 6036, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[189981, 6042, 1138, 30, 73, "Input"],
Cell[191122, 6074, 38, 1, 33, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[191209, 6081, 48, 1, 36, "Subsection"],
Cell[191260, 6084, 425, 16, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[191710, 6104, 123, 3, 33, "Input"],
Cell[191836, 6109, 1248, 18, 236, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[193121, 6132, 54, 1, 33, "Input"],
Cell[193178, 6135, 127, 2, 51, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[193342, 6142, 124, 3, 33, "Input"],
Cell[193469, 6147, 424, 6, 94, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[193930, 6158, 341, 10, 33, "Input"],
Cell[194274, 6170, 35, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[194346, 6176, 341, 10, 33, "Input"],
Cell[194690, 6188, 46, 1, 28, "Print"]
}, Open  ]]
}, Closed]]
}, Closed]],
Cell[194775, 6194, 81, 2, 31, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[194881, 6200, 200, 7, 106, "Section",
  Evaluatable->False],
Cell[195084, 6209, 359, 8, 89, "Text",
  Evaluatable->False],
Cell[195446, 6219, 697, 18, 113, "Text",
  Evaluatable->False],
Cell[196146, 6239, 483, 9, 113, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[196654, 6252, 89, 1, 33, "Input"],
Cell[196746, 6255, 187, 5, 63, "Output"],
Cell[196936, 6262, 37, 1, 28, "Print"]
}, Open  ]],
Cell[196988, 6266, 80, 1, 33, "Input"],
Cell[197071, 6269, 77, 1, 33, "Input"],
Cell[197151, 6272, 82, 1, 33, "Input"],
Cell[197236, 6275, 191, 6, 41, "Text",
  Evaluatable->False],
Cell[197430, 6283, 145, 3, 33, "Input"],
Cell[197578, 6288, 215, 6, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[197818, 6298, 1013, 19, 204, "Input"],
Cell[198834, 6319, 1690, 30, 402, "Output"]
}, Open  ]],
Cell[200539, 6352, 130, 5, 41, "Text",
  Evaluatable->False],
Cell[200672, 6359, 1063, 17, 166, "Input"],
Cell[201738, 6378, 167, 7, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[201930, 6389, 78, 1, 33, "Input"],
Cell[202011, 6392, 1381, 18, 394, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[203429, 6415, 62, 1, 33, "Input"],
Cell[203494, 6418, 40, 1, 33, "Output"]
}, Open  ]],
Cell[203549, 6422, 358, 7, 89, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[203932, 6433, 300, 6, 71, "Input"],
Cell[204235, 6441, 417, 7, 52, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[204689, 6453, 118, 2, 33, "Input"],
Cell[204810, 6457, 417, 7, 52, "Output"]
}, Open  ]],
Cell[205242, 6467, 154, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[205421, 6476, 270, 5, 71, "Input"],
Cell[205694, 6483, 427, 7, 52, "Output"]
}, Open  ]],
Cell[206136, 6493, 670, 12, 161, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[206831, 6509, 82, 1, 33, "Input"],
Cell[206916, 6512, 144, 2, 50, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[207097, 6519, 628, 13, 161, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[207750, 6536, 66, 1, 33, "Input"],
Cell[207819, 6539, 187, 5, 63, "Output"],
Cell[208009, 6546, 37, 1, 28, "Print"]
}, Open  ]],
Cell[208061, 6550, 161, 3, 52, "Input"],
Cell[208225, 6555, 119, 2, 33, "Input"],
Cell[208347, 6559, 133, 5, 41, "Text",
  Evaluatable->False],
Cell[208483, 6566, 48, 1, 33, "Input"]
}, Closed]],
Cell[208546, 6570, 147, 5, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[208718, 6579, 85, 1, 33, "Input"],
Cell[208806, 6582, 2154, 40, 459, "Output"]
}, Open  ]],
Cell[210975, 6625, 145, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[211145, 6634, 54, 1, 33, "Input"],
Cell[211202, 6637, 1381, 18, 394, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[212620, 6660, 41, 1, 33, "Input"],
Cell[212664, 6663, 38, 1, 33, "Output"]
}, Open  ]],
Cell[212717, 6667, 238, 6, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[212980, 6677, 165, 3, 33, "Input"],
Cell[213148, 6682, 896, 14, 211, "Output"]
}, Open  ]],
Cell[214059, 6699, 203, 6, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[214287, 6709, 106, 2, 33, "Input"],
Cell[214396, 6713, 988, 16, 215, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[215421, 6734, 67, 1, 33, "Input"],
Cell[215491, 6737, 82, 1, 33, "Output"]
}, Open  ]],
Cell[215588, 6741, 143, 5, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[215756, 6750, 221, 4, 33, "Input"],
Cell[215980, 6756, 3989, 70, 412, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[220006, 6831, 57, 1, 33, "Input"],
Cell[220066, 6834, 40, 1, 33, "Output"]
}, Open  ]],
Cell[220121, 6838, 233, 6, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[220379, 6848, 63, 1, 33, "Input"],
Cell[220445, 6851, 38, 1, 33, "Output"]
}, Open  ]],
Cell[220498, 6855, 791, 23, 137, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[221314, 6882, 153, 3, 33, "Input"],
Cell[221470, 6887, 3910, 68, 568, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[225417, 6960, 103, 2, 28, "Input"],
Cell[225523, 6964, 4290, 73, 646, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[229850, 7042, 134, 3, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[230009, 7049, 71, 1, 33, "Input"],
Cell[230083, 7052, 39, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[230159, 7058, 110, 2, 33, "Input"],
Cell[230272, 7062, 90, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[230399, 7068, 77, 1, 33, "Input"],
Cell[230479, 7071, 90, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[230606, 7077, 77, 1, 33, "Input"],
Cell[230686, 7080, 90, 1, 33, "Output"]
}, Open  ]]
}, Closed]],

Cell[CellGroupData[{
Cell[230825, 7087, 65, 1, 28, "Input"],
Cell[230893, 7090, 38, 1, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[230968, 7096, 62, 1, 33, "Input"],
Cell[231033, 7099, 15398, 271, 1770, "Output"]
}, Closed]],
Cell[246446, 7373, 377, 13, 60, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[246848, 7390, 246, 5, 33, "Input"],
Cell[247097, 7397, 23893, 408, 4204, "Output"]
}, Closed]],
Cell[271005, 7808, 321, 6, 47, "Input"],
Cell[271329, 7816, 252, 6, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[271606, 7826, 180, 3, 52, "Input"],
Cell[271789, 7831, 153, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[271979, 7838, 55, 1, 33, "Input"],
Cell[272037, 7841, 37, 1, 28, "Print"]
}, Open  ]],

Cell[CellGroupData[{
Cell[272111, 7847, 120, 2, 33, "Input"],
Cell[272234, 7851, 109, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[272380, 7858, 219, 4, 33, "Input"],
Cell[272602, 7864, 295, 5, 52, "Output"]
}, Open  ]],
Cell[272912, 7872, 81, 2, 41, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[273018, 7878, 84, 1, 33, "Input"],
Cell[273105, 7881, 572, 10, 164, "Output"]
}, Open  ]],
Cell[273692, 7894, 241, 6, 65, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[273958, 7904, 178, 4, 33, "Input"],
Cell[274139, 7910, 12068, 214, 1622, "Output"]
}, Closed]],

Cell[CellGroupData[{
Cell[286244, 8129, 102, 2, 28, "Input"],
Cell[286349, 8133, 3811, 65, 546, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[290197, 8203, 107, 2, 33, "Input"],
Cell[290307, 8207, 8267, 148, 1094, "Output"]
}, Closed]],
Cell[298589, 8358, 153, 4, 36, "Text",
  Evaluatable->False],

Cell[CellGroupData[{
Cell[298767, 8366, 127, 2, 33, "Input"],
Cell[298897, 8370, 112, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[299046, 8377, 125, 2, 33, "Input"],
Cell[299174, 8381, 112, 2, 33, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[299323, 8388, 136, 3, 33, "Input"],
Cell[299462, 8393, 879, 14, 164, "Output"]
}, Open  ]],

Cell[CellGroupData[{
Cell[300378, 8412, 136, 3, 33, "Input"],
Cell[300517, 8417, 2415, 42, 342, "Output"]
}, Open  ]],
Cell[302947, 8462, 157, 5, 41, "Text",
  Evaluatable->False],
Cell[303107, 8469, 25, 3, 55, "Text"]
}, Closed]]
}, Closed]],
Cell[303159, 8476, 81, 2, 31, "Text",
  Evaluatable->False]
}
]
*)




(***********************************************************************
End of Mathematica Notebook file.
***********************************************************************)

